aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJoshua Peek <josh@joshpeek.com>2012-07-23 15:52:49 -0500
committerJoshua Peek <josh@joshpeek.com>2012-07-23 15:52:49 -0500
commit7b6caa0f6c7603aabb5e6ed657e24aaddbeafc78 (patch)
treeec0522eae75bb04ae73d28ae3f599682a2bfdaeb
parent314f0e485227915931db361be14d308a210bedea (diff)
Rename samples subdirectories
-rw-r--r--lib/linguist/language.rb4
-rw-r--r--lib/linguist/samples.rb22
-rw-r--r--lib/linguist/samples.yml5616
-rw-r--r--samples/Apex/ArrayUtils.cls (renamed from samples/apex/ArrayUtils.cls)0
-rw-r--r--samples/Apex/BooleanUtils.cls (renamed from samples/apex/BooleanUtils.cls)0
-rw-r--r--samples/Apex/EmailUtils.cls (renamed from samples/apex/EmailUtils.cls)0
-rw-r--r--samples/Apex/GeoUtils.cls (renamed from samples/apex/GeoUtils.cls)0
-rw-r--r--samples/Apex/LanguageUtils.cls (renamed from samples/apex/LanguageUtils.cls)0
-rw-r--r--samples/Apex/TwilioAPI.cls (renamed from samples/apex/TwilioAPI.cls)0
-rw-r--r--samples/AppleScript/center.applescript (renamed from samples/applescript/center.applescript)0
-rw-r--r--samples/AppleScript/center.scpt (renamed from samples/applescript/center.scpt)0
-rw-r--r--samples/Arduino/hello.ino (renamed from samples/arduino/hello.ino)0
-rw-r--r--samples/AutoHotkey/hello.ahk (renamed from samples/autohotkey/hello.ahk)0
-rwxr-xr-xsamples/Binary/dog.o (renamed from samples/binary/dog.o)bin8648 -> 8648 bytes
-rw-r--r--samples/Binary/foo bar.jar (renamed from samples/binary/foo bar.jar)bin28 -> 28 bytes
-rw-r--r--samples/Binary/foo.bin (renamed from samples/binary/foo.bin)bin28 -> 28 bytes
-rw-r--r--samples/Binary/foo.pdf (renamed from samples/binary/foo.pdf)bin38179 -> 38179 bytes
-rw-r--r--samples/Binary/foo.png (renamed from samples/binary/foo.png)bin5570 -> 5570 bytes
-rw-r--r--samples/Binary/git.deb (renamed from samples/binary/git.deb)bin2048 -> 2048 bytes
-rwxr-xr-xsamples/Binary/git.exe (renamed from samples/binary/git.exe)bin8648 -> 8648 bytes
-rw-r--r--samples/Binary/github.po (renamed from samples/binary/github.po)0
-rw-r--r--samples/Binary/hello.pbc (renamed from samples/binary/hello.pbc)bin912 -> 912 bytes
-rw-r--r--samples/Binary/linguist.gem (renamed from samples/binary/linguist.gem)bin3072 -> 3072 bytes
-rw-r--r--samples/Binary/octocat.ai (renamed from samples/binary/octocat.ai)0
-rw-r--r--samples/Binary/octocat.png (renamed from samples/binary/octocat.png)bin5570 -> 5570 bytes
-rw-r--r--samples/Binary/octocat.psd (renamed from samples/binary/octocat.psd)bin136522 -> 136522 bytes
-rw-r--r--samples/Binary/zip (renamed from samples/binary/zip)bin28 -> 28 bytes
-rw-r--r--samples/C++/bar.h (renamed from samples/cpp/bar.h)0
-rw-r--r--samples/C++/bar.hpp (renamed from samples/cpp/bar.hpp)0
-rw-r--r--samples/C++/cuda.cu (renamed from samples/cpp/cuda.cu)0
-rw-r--r--samples/C++/env.cpp (renamed from samples/cpp/env.cpp)0
-rw-r--r--samples/C++/env.h (renamed from samples/cpp/env.h)0
-rw-r--r--samples/C++/hello.cpp (renamed from samples/cpp/hello.cpp)0
-rw-r--r--samples/C++/key.cpp (renamed from samples/cpp/key.cpp)0
-rw-r--r--samples/C++/key.h (renamed from samples/cpp/key.h)0
-rw-r--r--samples/C++/main.cpp (renamed from samples/cpp/main.cpp)0
-rw-r--r--samples/C++/scanner.cc (renamed from samples/cpp/scanner.cc)0
-rw-r--r--samples/C++/scanner.h (renamed from samples/cpp/scanner.h)0
-rw-r--r--samples/C++/utils.h (renamed from samples/cpp/utils.h)0
-rw-r--r--samples/C++/v8.cc (renamed from samples/cpp/v8.cc)0
-rw-r--r--samples/C++/v8.h (renamed from samples/cpp/v8.h)0
-rw-r--r--samples/C/blob.c (renamed from samples/c/blob.c)0
-rw-r--r--samples/C/blob.h (renamed from samples/c/blob.h)0
-rw-r--r--samples/C/cache.c (renamed from samples/c/cache.c)0
-rw-r--r--samples/C/commit.c (renamed from samples/c/commit.c)0
-rw-r--r--samples/C/commit.h (renamed from samples/c/commit.h)0
-rw-r--r--samples/C/cpu.c (renamed from samples/c/cpu.c)0
-rw-r--r--samples/C/diff.c (renamed from samples/c/diff.c)0
-rw-r--r--samples/C/git.c (renamed from samples/c/git.c)0
-rw-r--r--samples/C/hash.c (renamed from samples/c/hash.c)0
-rw-r--r--samples/C/hello.c (renamed from samples/c/hello.c)0
-rw-r--r--samples/C/hello.h (renamed from samples/c/hello.h)0
-rw-r--r--samples/C/http_parser.c (renamed from samples/c/http_parser.c)0
-rw-r--r--samples/C/http_parser.h (renamed from samples/c/http_parser.h)0
-rw-r--r--samples/C/markdown.c (renamed from samples/c/markdown.c)0
-rw-r--r--samples/C/process.c (renamed from samples/c/process.c)0
-rw-r--r--samples/C/rdiscount.c (renamed from samples/c/rdiscount.c)0
-rw-r--r--samples/C/redis.c (renamed from samples/c/redis.c)0
-rw-r--r--samples/C/yajl.c (renamed from samples/c/yajl.c)0
-rw-r--r--samples/Ceylon/Foo.ceylon (renamed from samples/ceylon/Foo.ceylon)0
-rw-r--r--samples/CoffeeScript/browser.coffee (renamed from samples/coffee/browser.coffee)0
-rw-r--r--samples/CoffeeScript/classes.coffee (renamed from samples/coffee/classes.coffee)0
-rw-r--r--samples/CoffeeScript/coffee-script.coffee (renamed from samples/coffee/coffee-script.coffee)0
-rw-r--r--samples/CoffeeScript/empty.coffee (renamed from samples/coffee/empty.coffee)0
-rw-r--r--samples/CoffeeScript/hello.coffee (renamed from samples/coffee/hello.coffee)0
-rw-r--r--samples/CoffeeScript/intro.coffee (renamed from samples/coffee/intro.coffee)0
-rw-r--r--samples/CoffeeScript/lexer.coffee (renamed from samples/coffee/lexer.coffee)0
-rw-r--r--samples/CoffeeScript/rack_application.coffee (renamed from samples/coffee/rack_application.coffee)0
-rw-r--r--samples/CoffeeScript/xipd.coffee (renamed from samples/coffee/xipd.coffee)0
-rwxr-xr-xsamples/Coq/Basics.v (renamed from samples/coq/Basics.v)0
-rwxr-xr-xsamples/Coq/Heap.v (renamed from samples/coq/Heap.v)0
-rwxr-xr-xsamples/Coq/Imp.v (renamed from samples/coq/Imp.v)0
-rwxr-xr-xsamples/Coq/Lists.v (renamed from samples/coq/Lists.v)0
-rwxr-xr-xsamples/Coq/PermutSetoid.v (renamed from samples/coq/PermutSetoid.v)0
-rwxr-xr-xsamples/Coq/Permutation.v (renamed from samples/coq/Permutation.v)0
-rwxr-xr-xsamples/Coq/Poly.v (renamed from samples/coq/Poly.v)0
-rwxr-xr-xsamples/Coq/Rel.v (renamed from samples/coq/Rel.v)0
-rwxr-xr-xsamples/Coq/Smallstep.v (renamed from samples/coq/Smallstep.v)0
-rwxr-xr-xsamples/Coq/Sorting.v (renamed from samples/coq/Sorting.v)0
-rwxr-xr-xsamples/Coq/Stlc.v (renamed from samples/coq/Stlc.v)0
-rw-r--r--samples/Coq/interval_discr.v (renamed from samples/coq/interval_discr.v)0
-rw-r--r--samples/Dart/point.dart (renamed from samples/dart/point.dart)0
-rw-r--r--samples/Delphi/program.dpr (renamed from samples/delphi/program.dpr)0
-rw-r--r--samples/Diff/dude-thing-okay--001.patch (renamed from samples/diff/dude-thing-okay--001.patch)0
-rw-r--r--samples/Emacs Lisp/dude.el (renamed from samples/emacs/dude.el)0
-rw-r--r--samples/GAS/hello.s (renamed from samples/gas/hello.s)0
-rw-r--r--samples/Gosu/Hello.gst (renamed from samples/gosu/Hello.gst)0
-rw-r--r--samples/Gosu/Hello.gsx (renamed from samples/gosu/Hello.gsx)0
-rw-r--r--samples/Gosu/Person.gs (renamed from samples/gosu/Person.gs)0
-rw-r--r--samples/Gosu/hello.gsp (renamed from samples/gosu/hello.gsp)0
-rw-r--r--samples/Gosu/hello.vark (renamed from samples/gosu/hello.vark)0
-rw-r--r--samples/Groovy Server Pages/bar.gsp (renamed from samples/gsp/bar.gsp)0
-rw-r--r--samples/Groovy Server Pages/hello-pagedirective.gsp (renamed from samples/gsp/hello-pagedirective.gsp)0
-rw-r--r--samples/Groovy Server Pages/hello-resources.gsp (renamed from samples/gsp/hello-resources.gsp)0
-rw-r--r--samples/Groovy Server Pages/hello-var.gsp (renamed from samples/gsp/hello-var.gsp)0
-rw-r--r--samples/Groovy/build.gradle (renamed from samples/groovy/build.gradle)0
-rwxr-xr-xsamples/Groovy/script.groovy (renamed from samples/groovy/script.groovy)0
-rw-r--r--samples/Haml/hello.haml (renamed from samples/haml/hello.haml)0
-rw-r--r--samples/INI/.gitconfig (renamed from samples/ini/.gitconfig)0
-rw-r--r--samples/Ioke/hello.ik (renamed from samples/ioke/hello.ik)0
-rw-r--r--samples/Java/HtmlDomParserContext.java (renamed from samples/java/HtmlDomParserContext.java)0
-rw-r--r--samples/Java/Hudson.java (renamed from samples/java/Hudson.java)0
-rw-r--r--samples/Java/NokogiriService.java (renamed from samples/java/NokogiriService.java)0
-rw-r--r--samples/Java/clojure-type.java (renamed from samples/java/clojure-type.java)0
-rw-r--r--samples/Java/clojure-util.java (renamed from samples/java/clojure-util.java)0
-rw-r--r--samples/JavaScript/bootstrap-modal.js (renamed from samples/javascript/bootstrap-modal.js)0
-rw-r--r--samples/JavaScript/classes-old.js (renamed from samples/javascript/classes-old.js)0
-rw-r--r--samples/JavaScript/classes.js (renamed from samples/javascript/classes.js)0
-rw-r--r--samples/JavaScript/dude.js (renamed from samples/javascript/dude.js)0
-rw-r--r--samples/JavaScript/empty.js (renamed from samples/javascript/empty.js)0
-rw-r--r--samples/JavaScript/hello.js (renamed from samples/javascript/hello.js)0
-rw-r--r--samples/JavaScript/http.js (renamed from samples/javascript/http.js)0
-rw-r--r--samples/JavaScript/intro-old.js (renamed from samples/javascript/intro-old.js)0
-rw-r--r--samples/JavaScript/intro.js (renamed from samples/javascript/intro.js)0
-rw-r--r--samples/JavaScript/jquery-1.4.2.min.js (renamed from samples/javascript/jquery-1.4.2.min.js)0
-rw-r--r--samples/JavaScript/jquery-1.6.1.js (renamed from samples/javascript/jquery-1.6.1.js)0
-rw-r--r--samples/JavaScript/jquery-1.6.1.min.js (renamed from samples/javascript/jquery-1.6.1.min.js)0
-rw-r--r--samples/JavaScript/jquery-1.7.2.js (renamed from samples/javascript/jquery-1.7.2.js)0
-rw-r--r--samples/JavaScript/json2_backbone.js (renamed from samples/javascript/json2_backbone.js)0
-rw-r--r--samples/JavaScript/modernizr.js (renamed from samples/javascript/modernizr.js)0
-rw-r--r--samples/JavaScript/parser.js (renamed from samples/javascript/parser.js)0
-rwxr-xr-xsamples/JavaScript/script.js (renamed from samples/javascript/script.js)0
-rw-r--r--samples/JavaScript/steelseries-min.js (renamed from samples/javascript/steelseries-min.js)0
-rw-r--r--samples/JavaScript/uglify.js (renamed from samples/javascript/uglify.js)0
-rw-r--r--samples/Julia/stockcorr.jl (renamed from samples/julia/stockcorr.jl)0
-rw-r--r--samples/Kotlin/Foo.kt (renamed from samples/kotlin/Foo.kt)0
-rw-r--r--samples/Logtalk/foo.lgt (renamed from samples/logtalk/foo.lgt)0
-rw-r--r--samples/Markdown/tender.md (renamed from samples/markdown/tender.md)0
-rw-r--r--samples/Matlab/average.m (renamed from samples/matlab/average.m)0
-rw-r--r--samples/Matlab/make_filter.m (renamed from samples/matlab/make_filter.m)0
-rw-r--r--samples/Matlab/matlab_class.m (renamed from samples/matlab/matlab_class.m)0
-rw-r--r--samples/Matlab/matlab_function.m (renamed from samples/matlab/matlab_function.m)0
-rw-r--r--samples/Matlab/matlab_script.m (renamed from samples/matlab/matlab_script.m)0
-rw-r--r--samples/Matlab/matlab_script2.m (renamed from samples/matlab/matlab_script2.m)0
-rw-r--r--samples/Nemerle/hello.n (renamed from samples/nemerle/hello.n)0
-rw-r--r--samples/Nimrod/foo.nim (renamed from samples/nimrod/foo.nim)0
-rwxr-xr-xsamples/Nu/script.nu (renamed from samples/nu/script.nu)0
-rw-r--r--samples/OCaml/Foo.ml (renamed from samples/ocaml/Foo.ml)0
-rw-r--r--samples/Objective-C/ASIHTTPRequest.h (renamed from samples/objective-c/ASIHTTPRequest.h)0
-rw-r--r--samples/Objective-C/ASIHTTPRequest.m (renamed from samples/objective-c/ASIHTTPRequest.m)0
-rw-r--r--samples/Objective-C/Foo.h (renamed from samples/objective-c/Foo.h)0
-rw-r--r--samples/Objective-C/Foo.m (renamed from samples/objective-c/Foo.m)0
-rw-r--r--samples/Objective-C/FooAppDelegate.h (renamed from samples/objective-c/FooAppDelegate.h)0
-rw-r--r--samples/Objective-C/FooAppDelegate.m (renamed from samples/objective-c/FooAppDelegate.m)0
-rw-r--r--samples/Objective-C/JSONKit.h (renamed from samples/objective-c/JSONKit.h)0
-rw-r--r--samples/Objective-C/JSONKit.m (renamed from samples/objective-c/JSONKit.m)0
-rw-r--r--samples/Objective-C/MainMenuViewController.h (renamed from samples/objective-c/MainMenuViewController.h)0
-rw-r--r--samples/Objective-C/MainMenuViewController.m (renamed from samples/objective-c/MainMenuViewController.m)0
-rw-r--r--samples/Objective-C/PlaygroundViewController.h (renamed from samples/objective-c/PlaygroundViewController.h)0
-rw-r--r--samples/Objective-C/PlaygroundViewController.m (renamed from samples/objective-c/PlaygroundViewController.m)0
-rw-r--r--samples/Objective-C/SBJsonParser.h (renamed from samples/objective-c/SBJsonParser.h)0
-rw-r--r--samples/Objective-C/SBJsonParser.m (renamed from samples/objective-c/SBJsonParser.m)0
-rw-r--r--samples/Objective-C/StyleViewController.h (renamed from samples/objective-c/StyleViewController.h)0
-rw-r--r--samples/Objective-C/StyleViewController.m (renamed from samples/objective-c/StyleViewController.m)0
-rw-r--r--samples/Objective-C/TUITableView.h (renamed from samples/objective-c/TUITableView.h)0
-rw-r--r--samples/Objective-C/TUITableView.m (renamed from samples/objective-c/TUITableView.m)0
-rw-r--r--samples/Objective-C/empty.m (renamed from samples/objective-c/empty.m)0
-rw-r--r--samples/Objective-C/hello.m (renamed from samples/objective-c/hello.m)0
-rw-r--r--samples/Opa/hello_syntax1.opa (renamed from samples/opa/hello_syntax1.opa)0
-rw-r--r--samples/Opa/hello_syntax2.opa (renamed from samples/opa/hello_syntax2.opa)0
-rw-r--r--samples/OpenCL/fft.cl (renamed from samples/opencl/fft.cl)0
-rw-r--r--samples/OpenEdge ABL/Email.cls (renamed from samples/openedge-abl/Email.cls)0
-rw-r--r--samples/OpenEdge ABL/SendEmailAlgorithm.cls (renamed from samples/openedge-abl/SendEmailAlgorithm.cls)0
-rw-r--r--samples/OpenEdge ABL/SocketReader.p (renamed from samples/openedge-abl/SocketReader.p)0
-rw-r--r--samples/OpenEdge ABL/Util.cls (renamed from samples/openedge-abl/Util.cls)0
-rw-r--r--samples/OpenEdge ABL/openedge.p (renamed from samples/openedge-abl/openedge.p)0
-rw-r--r--samples/PHP/Application.php (renamed from samples/php/Application.php)0
-rw-r--r--samples/PHP/Client.php (renamed from samples/php/Client.php)0
-rw-r--r--samples/PHP/Controller.php (renamed from samples/php/Controller.php)0
-rw-r--r--samples/PHP/Form.php (renamed from samples/php/Form.php)0
-rw-r--r--samples/PHP/Model.php (renamed from samples/php/Model.php)0
-rw-r--r--samples/PHP/drupal.module (renamed from samples/php/drupal.module)0
-rw-r--r--samples/Parrot Assembly/hello.pasm (renamed from samples/pasm/hello.pasm)0
-rw-r--r--samples/Parrot Internal Representation/hello.pir (renamed from samples/pir/hello.pir)0
-rw-r--r--samples/Perl/Ack.pm (renamed from samples/perl/Ack.pm)0
-rw-r--r--samples/Perl/Request.pm (renamed from samples/perl/Request.pm)0
-rw-r--r--samples/Perl/Response.pm (renamed from samples/perl/Response.pm)0
-rwxr-xr-xsamples/Perl/ack (renamed from samples/perl/ack)0
-rw-r--r--samples/Perl/fib.pl (renamed from samples/perl/fib.pl)0
-rw-r--r--samples/Perl/oo1.pl (renamed from samples/perl/oo1.pl)0
-rw-r--r--samples/Perl/oo2.pl (renamed from samples/perl/oo2.pl)0
-rw-r--r--samples/Perl/oo3.pl (renamed from samples/perl/oo3.pl)0
-rw-r--r--samples/Perl/perl-test.t (renamed from samples/perl/perl-test.t)0
-rwxr-xr-xsamples/Perl/script.pl (renamed from samples/perl/script.pl)0
-rw-r--r--samples/Perl/test-perl.pl (renamed from samples/perl/test-perl.pl)0
-rw-r--r--samples/Perl/test-perl2.pl (renamed from samples/perl/test-perl2.pl)0
-rw-r--r--samples/PowerShell/hello.ps1 (renamed from samples/powershell/hello.ps1)0
-rw-r--r--samples/PowerShell/hello.psm1 (renamed from samples/powershell/hello.psm1)0
-rw-r--r--samples/Prolog/test-prolog.pl (renamed from samples/prolog/test-prolog.pl)0
-rw-r--r--samples/Python/django-models-base.py (renamed from samples/python/django-models-base.py)0
-rw-r--r--samples/Python/flask-view.py (renamed from samples/python/flask-view.py)0
-rwxr-xr-xsamples/Python/script.py (renamed from samples/python/script.py)0
-rw-r--r--samples/Python/tornado-httpserver.py (renamed from samples/python/tornado-httpserver.py)0
-rw-r--r--samples/R/hello-r.R (renamed from samples/r/hello-r.R)0
-rw-r--r--samples/Racket/scribble.scrbl (renamed from samples/racket/scribble.scrbl)0
-rwxr-xr-xsamples/Racket/script.rkt (renamed from samples/racket/script.rkt)0
-rw-r--r--samples/Rebol/hello-rebol.r (renamed from samples/rebol/hello-rebol.r)0
-rw-r--r--samples/Ruby/filenames/Capfile (renamed from samples/ruby/filenames/Capfile)0
-rw-r--r--samples/Ruby/filenames/Rakefile (renamed from samples/ruby/filenames/Rakefile)0
-rw-r--r--samples/Ruby/foo.rb (renamed from samples/ruby/foo.rb)0
-rw-r--r--samples/Ruby/formula.rb (renamed from samples/ruby/formula.rb)0
-rw-r--r--samples/Ruby/grit.rb (renamed from samples/ruby/grit.rb)0
-rw-r--r--samples/Ruby/inflector.rb (renamed from samples/ruby/inflector.rb)0
-rw-r--r--samples/Ruby/jekyll.rb (renamed from samples/ruby/jekyll.rb)0
-rwxr-xr-xsamples/Ruby/macruby-script (renamed from samples/ruby/macruby-script)0
-rw-r--r--samples/Ruby/resque.rb (renamed from samples/ruby/resque.rb)0
-rwxr-xr-xsamples/Ruby/script.rake (renamed from samples/ruby/script.rake)0
-rwxr-xr-xsamples/Ruby/script.rb (renamed from samples/ruby/script.rb)0
-rw-r--r--samples/Ruby/script2.rb (renamed from samples/ruby/script2.rb)0
-rw-r--r--samples/Ruby/sinatra.rb (renamed from samples/ruby/sinatra.rb)0
-rw-r--r--samples/Ruby/wrong_shebang.rb (renamed from samples/ruby/wrong_shebang.rb)0
-rw-r--r--samples/Rust/hello.rs (renamed from samples/rust/hello.rs)0
-rw-r--r--samples/SCSS/screen.scss (renamed from samples/scss/screen.scss)0
-rw-r--r--samples/Sass/screen.sass (renamed from samples/sass/screen.sass)0
-rw-r--r--samples/Scala/build.sbt (renamed from samples/scala/build.sbt)0
-rwxr-xr-xsamples/Scala/script.scala (renamed from samples/scala/script.scala)0
-rw-r--r--samples/Scheme/asteroids.sps (renamed from samples/scheme/asteroids.sps)0
-rw-r--r--samples/Scilab/scilab_function.sci (renamed from samples/scilab/scilab_function.sci)0
-rw-r--r--samples/Scilab/scilab_script.sce (renamed from samples/scilab/scilab_script.sce)0
-rw-r--r--samples/Scilab/scilab_test.tst (renamed from samples/scilab/scilab_test.tst)0
-rw-r--r--samples/Shell/.bash_profile (renamed from samples/shell/.bash_profile)0
-rw-r--r--samples/Shell/.bashrc (renamed from samples/shell/.bashrc)0
-rw-r--r--samples/Shell/.profile (renamed from samples/shell/.profile)0
-rw-r--r--samples/Shell/.zlogin (renamed from samples/shell/.zlogin)0
-rw-r--r--samples/Shell/.zshrc (renamed from samples/shell/.zshrc)0
-rw-r--r--samples/Shell/filenames/PKGBUILD (renamed from samples/shell/filenames/PKGBUILD)0
-rwxr-xr-xsamples/Shell/rbenv-sh-shell (renamed from samples/shell/rbenv-sh-shell)0
-rwxr-xr-xsamples/Shell/rvm (renamed from samples/shell/rvm)0
-rwxr-xr-xsamples/Shell/script.bash (renamed from samples/shell/script.bash)0
-rwxr-xr-xsamples/Shell/script.sh (renamed from samples/shell/script.sh)0
-rwxr-xr-xsamples/Shell/script.zsh (renamed from samples/shell/script.zsh)0
-rw-r--r--samples/Standard ML/Foo.sig (renamed from samples/standard-ml/Foo.sig)0
-rw-r--r--samples/Standard ML/Foo.sml (renamed from samples/standard-ml/Foo.sml)0
-rw-r--r--samples/SuperCollider/BCR2000.sc (renamed from samples/supercollider/BCR2000.sc)0
-rw-r--r--samples/TeX/reedthesis.cls (renamed from samples/tex/reedthesis.cls)0
-rw-r--r--samples/Tea/foo.tea (renamed from samples/tea/foo.tea)0
-rw-r--r--samples/Text/README (renamed from samples/text/README)0
-rw-r--r--samples/Text/blank (renamed from samples/text/blank)0
-rw-r--r--samples/Text/defu.nkt (renamed from samples/text/defu.nkt)0
-rw-r--r--samples/Text/dump.sql (renamed from samples/text/dump.sql)0
-rw-r--r--samples/Text/file.json (renamed from samples/text/file.json)0
-rw-r--r--samples/Text/file.txt (renamed from samples/text/file.txt)0
-rw-r--r--samples/Text/foo.txt (renamed from samples/text/foo.txt)0
-rw-r--r--samples/Text/md (renamed from samples/text/md)0
-rwxr-xr-xsamples/Text/script.foo (renamed from samples/text/script.foo)0
-rw-r--r--samples/Text/txt (renamed from samples/text/txt)0
-rw-r--r--samples/Turing/turing.t (renamed from samples/turing/turing.t)0
-rw-r--r--samples/VHDL/foo.vhd (renamed from samples/vhdl/foo.vhd)0
-rwxr-xr-xsamples/Verilog/button_debounce.v (renamed from samples/verilog/button_debounce.v)0
-rwxr-xr-xsamples/Verilog/control.v (renamed from samples/verilog/control.v)0
-rwxr-xr-xsamples/Verilog/hex_display.v (renamed from samples/verilog/hex_display.v)0
-rwxr-xr-xsamples/Verilog/mux.v (renamed from samples/verilog/mux.v)0
-rwxr-xr-xsamples/Verilog/pipeline_registers.v (renamed from samples/verilog/pipeline_registers.v)0
-rwxr-xr-xsamples/Verilog/ps2_mouse.v (renamed from samples/verilog/ps2_mouse.v)0
-rw-r--r--samples/Verilog/sha-256-functions.v (renamed from samples/verilog/sha-256-functions.v)0
-rwxr-xr-xsamples/Verilog/sign_extender.v (renamed from samples/verilog/sign_extender.v)0
-rwxr-xr-xsamples/Verilog/sqrt_pipelined.v (renamed from samples/verilog/sqrt_pipelined.v)0
-rwxr-xr-xsamples/Verilog/t_button_debounce.v (renamed from samples/verilog/t_button_debounce.v)0
-rwxr-xr-xsamples/Verilog/t_div_pipelined.v (renamed from samples/verilog/t_div_pipelined.v)0
-rwxr-xr-xsamples/Verilog/t_sqrt_pipelined.v (renamed from samples/verilog/t_sqrt_pipelined.v)0
-rwxr-xr-xsamples/Verilog/vga.v (renamed from samples/verilog/vga.v)0
-rw-r--r--samples/VimL/.gvimrc (renamed from samples/viml/.gvimrc)0
-rw-r--r--samples/VimL/.vimrc (renamed from samples/viml/.vimrc)0
-rw-r--r--samples/Visual Basic/cApplication.cls (renamed from samples/visual-basic/cApplication.cls)0
-rw-r--r--samples/XML/module.ant (renamed from samples/xml/module.ant)0
-rw-r--r--samples/XML/module.ivy (renamed from samples/xml/module.ivy)0
-rw-r--r--samples/XML/net_docfile.xml (renamed from samples/xml/net_docfile.xml)0
-rw-r--r--samples/XQuery/xproc.xqm (renamed from samples/xquery/xproc.xqm)0
-rw-r--r--samples/XSLT/test.xslt (renamed from samples/xslt/test.xslt)0
-rw-r--r--samples/YAML/.gemrc (renamed from samples/yaml/.gemrc)0
-rw-r--r--test/test_blob.rb221
-rw-r--r--test/test_classifier.rb22
-rw-r--r--test/test_tokenizer.rb22
273 files changed, 2952 insertions, 2955 deletions
diff --git a/lib/linguist/language.rb b/lib/linguist/language.rb
index 0bcff3a..0961b79 100644
--- a/lib/linguist/language.rb
+++ b/lib/linguist/language.rb
@@ -441,8 +441,8 @@ module Linguist
end
end
- extensions = Samples::DATA['extnames'] rescue {} # TODO: BAH!
- filenames = Samples::DATA['filenames'] rescue {} # TODO: BAH!
+ extensions = Samples::DATA['extnames']
+ filenames = Samples::DATA['filenames']
popular = YAML.load_file(File.expand_path("../popular.yml", __FILE__))
YAML.load_file(File.expand_path("../languages.yml", __FILE__)).each do |name, options|
diff --git a/lib/linguist/samples.rb b/lib/linguist/samples.rb
index 5d78ae7..77d8707 100644
--- a/lib/linguist/samples.rb
+++ b/lib/linguist/samples.rb
@@ -1,6 +1,7 @@
-require 'set'
require 'yaml'
+
require 'linguist/md5'
+require 'linguist/classifier'
module Linguist
# Model for accessing classifier training data.
@@ -27,7 +28,7 @@ module Linguist
# Skip text and binary for now
# Possibly reconsider this later
- next if category == 'text' || category == 'binary'
+ next if category == 'Text' || category == 'Binary'
dirname = File.join(ROOT, category)
Dir.entries(dirname).each do |filename|
@@ -60,32 +61,29 @@ module Linguist
#
# Returns trained Classifier.
def self.data
- require 'linguist/classifier'
- require 'linguist/language'
-
db = {}
db['extnames'] = {}
db['filenames'] = {}
each do |sample|
- language = Language.find_by_alias(sample[:language])
+ language_name = sample[:language]
# TODO: For now skip empty extnames
if sample[:extname] && sample[:extname] != ""
- db['extnames'][language.name] ||= []
- if !db['extnames'][language.name].include?(sample[:extname])
- db['extnames'][language.name] << sample[:extname]
+ db['extnames'][language_name] ||= []
+ if !db['extnames'][language_name].include?(sample[:extname])
+ db['extnames'][language_name] << sample[:extname]
end
end
# TODO: For now skip empty extnames
if fn = sample[:filename]
- db['filenames'][language.name] ||= []
- db['filenames'][language.name] << fn
+ db['filenames'][language_name] ||= []
+ db['filenames'][language_name] << fn
end
data = File.read(sample[:path])
- Classifier.train!(db, language.name, data)
+ Classifier.train!(db, language_name, data)
end
db['md5'] = Linguist::MD5.hexdigest(db)
diff --git a/lib/linguist/samples.yml b/lib/linguist/samples.yml
index fa39411..cfb2b2c 100644
--- a/lib/linguist/samples.yml
+++ b/lib/linguist/samples.yml
@@ -12,18 +12,18 @@ extnames:
C:
- .c
- .h
- Ceylon:
- - .ceylon
- CoffeeScript:
- - .coffee
- Coq:
- - .v
C++:
- .h
- .hpp
- .cu
- .cpp
- .cc
+ Ceylon:
+ - .ceylon
+ CoffeeScript:
+ - .coffee
+ Coq:
+ - .v
Dart:
- .dart
Delphi:
@@ -35,11 +35,11 @@ extnames:
GAS:
- .s
Gosu:
- - .gsp
- .gst
- .gsx
- - .vark
- .gs
+ - .gsp
+ - .vark
Groovy:
- .gradle
- .groovy
@@ -69,11 +69,11 @@ extnames:
- .nim
Nu:
- .nu
+ OCaml:
+ - .ml
Objective-C:
- .h
- .m
- OCaml:
- - .ml
Opa:
- .opa
OpenCL:
@@ -81,17 +81,17 @@ extnames:
OpenEdge ABL:
- .cls
- .p
+ PHP:
+ - .php
+ - .module
Parrot Assembly:
- .pasm
+ Parrot Internal Representation:
+ - .pir
Perl:
- .pm
- .pl
- .t
- PHP:
- - .php
- - .module
- Parrot Internal Representation:
- - .pir
PowerShell:
- .ps1
- .psm1
@@ -111,6 +111,8 @@ extnames:
- .rake
Rust:
- .rs
+ SCSS:
+ - .scss
Sass:
- .sass
Scala:
@@ -122,8 +124,6 @@ extnames:
- .sci
- .sce
- .tst
- SCSS:
- - .scss
Shell:
- .bash
- .sh
@@ -133,16 +133,16 @@ extnames:
- .sml
SuperCollider:
- .sc
- Tea:
- - .tea
TeX:
- .cls
+ Tea:
+ - .tea
Turing:
- .t
- Verilog:
- - .v
VHDL:
- .vhd
+ Verilog:
+ - .v
Visual Basic:
- .cls
XML:
@@ -3332,6 +3332,896 @@ tokens:
yajl_render_error_string: 1
yajl_get_bytes_consumed: 1
yajl_free_error: 1
+ C++:
+ class: 19
+ Bar: 2
+ ! '{': 283
+ protected: 4
+ char: 32
+ ! '*name': 2
+ ;: 793
+ public: 20
+ void: 58
+ hello: 2
+ (: 842
+ ): 843
+ ! '}': 285
+ foo: 2
+ cudaArray*: 1
+ cu_array: 4
+ texture: 1
+ <float,>: 1
+ '2': 1
+ cudaReadModeElementType: 1
+ tex: 4
+ //: 457
+ cudaChannelFormatDesc: 1
+ description: 2
+ cudaCreateChannelDesc: 1
+ <float>: 1
+ cudaMallocArray: 1
+ ! '&': 74
+ width: 5
+ height: 5
+ cudaMemcpyToArray: 1
+ image: 1
+ width*height*sizeof: 1
+ float: 2
+ cudaMemcpyHostToDevice: 1
+ tex.addressMode: 2
+ cudaAddressModeClamp: 2
+ tex.filterMode: 1
+ cudaFilterModePoint: 1
+ tex.normalized: 1
+ 'false': 40
+ cudaBindTextureToArray: 1
+ dim3: 2
+ blockDim: 2
+ gridDim: 2
+ +: 40
+ blockDim.x: 2
+ ! '-': 114
+ /: 9
+ blockDim.y: 2
+ kernel: 2
+ <<: 5
+ <: 27
+ d_data: 1
+ cudaUnbindTexture: 1
+ //end: 1
+ __global__: 1
+ float*: 1
+ odata: 2
+ int: 62
+ unsigned: 16
+ x: 19
+ blockIdx.x*blockDim.x: 1
+ threadIdx.x: 1
+ y: 4
+ blockIdx.y*blockDim.y: 1
+ threadIdx.y: 1
+ if: 132
+ ! '&&': 13
+ c: 33
+ tex2D: 1
+ y*width: 1
+ /*: 9
+ ! '*/': 9
+ ! '#include': 71
+ <QCoreApplication>: 1
+ <QString>: 1
+ <QVariantMap>: 2
+ static: 56
+ Env: 13
+ ! '*env_instance': 1
+ ! '*': 13
+ 'NULL': 49
+ ! '*Env': 1
+ instance: 3
+ env_instance: 3
+ new: 2
+ return: 107
+ QObject: 2
+ QCoreApplication: 1
+ parse: 3
+ const: 91
+ ! '**envp': 1
+ ! '**env': 1
+ ! '**': 2
+ QString: 18
+ envvar: 2
+ name: 3
+ value: 3
+ indexOfEquals: 5
+ for: 9
+ env: 3
+ envp: 4
+ ! '*env': 1
+ (*: 3
+ ! '*)': 3
+ envvar.indexOf: 1
+ continue: 2
+ envvar.left: 1
+ envvar.mid: 1
+ m_map.insert: 1
+ QVariantMap: 3
+ asVariantMap: 2
+ m_map: 2
+ ! '#ifndef': 5
+ ENV_H: 2
+ ! '#define': 5
+ <QObject>: 1
+ Q_OBJECT: 1
+ ! '*instance': 1
+ private: 8
+ ! '#endif': 12
+ <iostream>: 1
+ using: 1
+ namespace: 10
+ std: 18
+ main: 2
+ cout: 1
+ endl: 1
+ <map>: 1
+ <openssl/ecdsa.h>: 1
+ <openssl/obj_mac.h>: 1
+ EC_KEY_regenerate_key: 1
+ EC_KEY: 2
+ ! '*eckey': 2
+ BIGNUM: 9
+ ! '*priv_key': 1
+ ok: 3
+ BN_CTX: 2
+ ! '*ctx': 2
+ EC_POINT: 4
+ ! '*pub_key': 1
+ eckey: 7
+ EC_GROUP: 2
+ ! '*group': 2
+ EC_KEY_get0_group: 2
+ ctx: 25
+ BN_CTX_new: 2
+ goto: 23
+ err: 25
+ pub_key: 6
+ EC_POINT_new: 4
+ group: 12
+ EC_POINT_mul: 3
+ priv_key: 2
+ EC_KEY_set_private_key: 1
+ EC_KEY_set_public_key: 2
+ EC_POINT_free: 4
+ BN_CTX_free: 2
+ ECDSA_SIG_recover_key_GFp: 3
+ ECDSA_SIG: 3
+ ! '*ecsig': 1
+ ! '*msg': 2
+ msglen: 2
+ recid: 3
+ check: 2
+ ret: 23
+ ! '*x': 1
+ ! '*e': 1
+ ! '*order': 1
+ ! '*sor': 1
+ ! '*eor': 1
+ ! '*field': 1
+ ! '*R': 1
+ ! '*O': 1
+ ! '*Q': 1
+ ! '*rr': 1
+ ! '*zero': 1
+ n: 7
+ i: 47
+ BN_CTX_start: 1
+ order: 8
+ BN_CTX_get: 8
+ EC_GROUP_get_order: 1
+ BN_copy: 1
+ BN_mul_word: 1
+ BN_add: 1
+ ecsig: 3
+ r: 9
+ field: 3
+ EC_GROUP_get_curve_GFp: 1
+ BN_cmp: 1
+ R: 6
+ EC_POINT_set_compressed_coordinates_GFp: 1
+ ! '%': 1
+ O: 5
+ EC_POINT_is_at_infinity: 1
+ Q: 5
+ EC_GROUP_get_degree: 1
+ e: 13
+ BN_bin2bn: 3
+ msg: 1
+ ! '*msglen': 1
+ BN_rshift: 1
+ zero: 3
+ BN_zero: 1
+ BN_mod_sub: 1
+ rr: 4
+ BN_mod_inverse: 1
+ sor: 3
+ BN_mod_mul: 2
+ s: 5
+ eor: 3
+ BN_CTX_end: 1
+ CKey: 26
+ SetCompressedPubKey: 4
+ EC_KEY_set_conv_form: 1
+ pkey: 14
+ POINT_CONVERSION_COMPRESSED: 1
+ fCompressedPubKey: 5
+ 'true': 31
+ Reset: 5
+ EC_KEY_new_by_curve_name: 2
+ NID_secp256k1: 2
+ throw: 4
+ key_error: 6
+ fSet: 7
+ b: 12
+ EC_KEY_dup: 1
+ b.pkey: 2
+ b.fSet: 2
+ operator: 5
+ EC_KEY_copy: 1
+ hash: 20
+ sizeof: 6
+ vchSig: 18
+ nSize: 2
+ vchSig.clear: 2
+ vchSig.resize: 2
+ bool: 89
+ SignCompact: 2
+ uint256: 10
+ vector: 14
+ <unsigned>: 19
+ fOk: 3
+ ! '*sig': 2
+ ECDSA_do_sign: 1
+ char*: 7
+ sig: 11
+ nBitsR: 3
+ BN_num_bits: 2
+ nBitsS: 3
+ nRecId: 4
+ <4;>: 1
+ keyRec: 5
+ '1': 2
+ GetPubKey: 5
+ this: 2
+ break: 30
+ BN_bn2bin: 2
+ /8: 2
+ ECDSA_SIG_free: 2
+ SetCompactSignature: 2
+ vchSig.size: 2
+ nV: 6
+ <27>: 1
+ ECDSA_SIG_new: 1
+ EC_KEY_free: 1
+ Verify: 2
+ ECDSA_verify: 1
+ VerifyCompact: 2
+ key: 1
+ key.SetCompactSignature: 1
+ key.GetPubKey: 1
+ IsValid: 4
+ fCompr: 3
+ CSecret: 4
+ secret: 2
+ GetSecret: 2
+ key2: 1
+ key2.SetSecret: 1
+ key2.GetPubKey: 1
+ BITCOIN_KEY_H: 2
+ <stdexcept>: 1
+ <vector>: 1
+ <openssl/ec.h>: 1
+ runtime_error: 2
+ explicit: 3
+ string: 1
+ str: 2
+ CKeyID: 5
+ uint160: 8
+ in: 4
+ CScriptID: 3
+ CPubKey: 11
+ vchPubKey: 6
+ friend: 4
+ vchPubKeyIn: 2
+ a: 3
+ a.vchPubKey: 3
+ b.vchPubKey: 3
+ IMPLEMENT_SERIALIZE: 1
+ READWRITE: 1
+ GetID: 1
+ Hash160: 1
+ GetHash: 1
+ Hash: 1
+ vchPubKey.begin: 1
+ vchPubKey.end: 1
+ vchPubKey.size: 3
+ ! '||': 8
+ IsCompressed: 2
+ Raw: 1
+ typedef: 5
+ secure_allocator: 2
+ CPrivKey: 3
+ EC_KEY*: 1
+ IsNull: 1
+ MakeNewKey: 1
+ fCompressed: 3
+ SetPrivKey: 1
+ vchPrivKey: 1
+ SetSecret: 1
+ vchSecret: 1
+ GetPrivKey: 1
+ SetPubKey: 1
+ Sign: 1
+ ! '#ifdef': 3
+ Q_OS_LINUX: 2
+ <QApplication>: 1
+ ! '#if': 4
+ QT_VERSION: 1
+ QT_VERSION_CHECK: 1
+ ! '#error': 2
+ Something: 1
+ is: 1
+ wrong: 1
+ with: 1
+ the: 5
+ setup.: 1
+ Please: 1
+ report: 2
+ to: 3
+ mailing: 1
+ list: 1
+ argc: 2
+ char**: 2
+ argv: 2
+ google_breakpad: 1
+ ExceptionHandler: 1
+ eh: 1
+ Utils: 4
+ exceptionHandler: 2
+ qInstallMsgHandler: 1
+ messageHandler: 2
+ QApplication: 1
+ app: 1
+ STATIC_BUILD: 1
+ Q_INIT_RESOURCE: 2
+ WebKit: 1
+ InspectorBackendStub: 1
+ app.setWindowIcon: 1
+ QIcon: 1
+ app.setApplicationName: 1
+ app.setOrganizationName: 1
+ app.setOrganizationDomain: 1
+ app.setApplicationVersion: 1
+ PHANTOMJS_VERSION_STRING: 1
+ Phantom: 1
+ phantom: 1
+ phantom.execute: 1
+ app.exec: 1
+ phantom.returnValue: 1
+ v8: 5
+ internal: 5
+ Scanner: 16
+ UnicodeCache*: 4
+ unicode_cache: 3
+ unicode_cache_: 10
+ octal_pos_: 5
+ Location: 14
+ invalid: 4
+ harmony_scoping_: 4
+ harmony_modules_: 4
+ Initialize: 4
+ Utf16CharacterStream*: 3
+ source: 6
+ source_: 7
+ Init: 3
+ has_line_terminator_before_next_: 9
+ SkipWhiteSpace: 4
+ Scan: 5
+ uc32: 19
+ ScanHexNumber: 2
+ expected_length: 4
+ ASSERT: 17
+ digits: 3
+ c0_: 64
+ d: 4
+ HexValue: 2
+ j: 4
+ PushBack: 8
+ Advance: 40
+ STATIC_ASSERT: 5
+ Token: 212
+ NUM_TOKENS: 1
+ byte: 1
+ one_char_tokens: 2
+ ILLEGAL: 120
+ LPAREN: 2
+ RPAREN: 2
+ COMMA: 2
+ COLON: 2
+ SEMICOLON: 2
+ CONDITIONAL: 2
+ LBRACK: 2
+ RBRACK: 2
+ LBRACE: 2
+ RBRACE: 2
+ BIT_NOT: 2
+ Value: 23
+ Next: 2
+ current_: 2
+ next_: 2
+ has_multiline_comment_before_next_: 5
+ static_cast: 7
+ f: 4
+ token: 61
+ <Token::Value>: 1
+ pos: 12
+ source_pos: 10
+ next_.token: 3
+ next_.location.beg_pos: 3
+ next_.location.end_pos: 4
+ current_.token: 4
+ inline: 12
+ IsByteOrderMark: 2
+ xFEFF: 1
+ xFFFE: 1
+ start_position: 2
+ while: 6
+ IsWhiteSpace: 2
+ IsLineTerminator: 6
+ SkipSingleLineComment: 6
+ WHITESPACE: 6
+ SkipMultiLineComment: 3
+ ch: 5
+ ScanHtmlComment: 3
+ LT: 2
+ next_.literal_chars: 13
+ do: 1
+ switch: 2
+ case: 32
+ ScanString: 3
+ Select: 32
+ LTE: 1
+ else: 32
+ ASSIGN_SHL: 1
+ SHL: 1
+ GTE: 1
+ ASSIGN_SAR: 1
+ ASSIGN_SHR: 1
+ SHR: 1
+ SAR: 1
+ GT: 1
+ EQ_STRICT: 1
+ EQ: 1
+ ASSIGN: 1
+ NE_STRICT: 1
+ NE: 1
+ NOT: 1
+ INC: 1
+ ASSIGN_ADD: 1
+ ADD: 1
+ DEC: 1
+ ASSIGN_SUB: 1
+ SUB: 1
+ ASSIGN_MUL: 1
+ MUL: 1
+ ASSIGN_MOD: 1
+ MOD: 1
+ ASSIGN_DIV: 1
+ DIV: 1
+ AND: 1
+ ASSIGN_BIT_AND: 1
+ BIT_AND: 1
+ OR: 1
+ ASSIGN_BIT_OR: 1
+ BIT_OR: 1
+ ASSIGN_BIT_XOR: 1
+ BIT_XOR: 1
+ IsDecimalDigit: 2
+ ScanNumber: 3
+ PERIOD: 1
+ default: 1
+ IsIdentifierStart: 2
+ ScanIdentifierOrKeyword: 2
+ EOS: 1
+ SeekForward: 4
+ current_pos: 4
+ ASSERT_EQ: 1
+ ScanEscape: 2
+ IsCarriageReturn: 2
+ IsLineFeed: 2
+ t: 6
+ u: 6
+ v: 3
+ xx: 1
+ xxx: 1
+ error: 1
+ immediately: 1
+ because: 1
+ octal: 1
+ escape: 1
+ can: 1
+ quote: 2
+ LiteralScope: 4
+ literal: 2
+ .: 2
+ X: 2
+ E: 3
+ l: 1
+ p: 1
+ w: 1
+ keyword: 1
+ valid: 1
+ and: 2
+ character: 1
+ has: 1
+ in_character_class: 2
+ AddLiteralCharAdvance: 3
+ literal.Complete: 2
+ ScanLiteralUnicodeEscape: 3
+ V8_SCANNER_H_: 2
+ enum: 3
+ ParsingFlags: 1
+ kNoParsingFlags: 1
+ kLanguageModeMask: 4
+ kAllowLazy: 1
+ kAllowNativesSyntax: 1
+ kAllowModules: 1
+ CLASSIC_MODE: 2
+ STRICT_MODE: 2
+ EXTENDED_MODE: 2
+ ! '|': 2
+ Utf16CharacterStream: 3
+ pos_: 6
+ virtual: 4
+ buffer_cursor_: 5
+ buffer_end_: 3
+ ReadBlock: 2
+ <uc32>: 1
+ kEndOfInput: 2
+ code_unit_count: 7
+ buffered_chars: 2
+ SlowSeekForward: 2
+ int32_t: 1
+ code_unit: 6
+ uc16*: 3
+ UnicodeCache: 3
+ unibrow: 11
+ Utf8InputBuffer: 2
+ <1024>: 2
+ Utf8Decoder: 2
+ StaticResource: 2
+ <Utf8Decoder>: 2
+ utf8_decoder: 1
+ utf8_decoder_: 2
+ uchar: 4
+ kIsIdentifierStart.get: 1
+ IsIdentifierPart: 1
+ kIsIdentifierPart.get: 1
+ kIsLineTerminator.get: 1
+ kIsWhiteSpace.get: 1
+ Predicate: 4
+ <IdentifierStart,>: 1
+ '128': 4
+ kIsIdentifierStart: 1
+ <IdentifierPart,>: 1
+ kIsIdentifierPart: 1
+ <unibrow::LineTerminator,>: 1
+ kIsLineTerminator: 1
+ <unibrow::WhiteSpace,>: 1
+ kIsWhiteSpace: 1
+ DISALLOW_COPY_AND_ASSIGN: 2
+ LiteralBuffer: 6
+ is_ascii_: 10
+ position_: 17
+ backing_store_: 7
+ backing_store_.length: 4
+ backing_store_.Dispose: 3
+ INLINE: 2
+ AddChar: 2
+ uint32_t: 8
+ ExpandBuffer: 2
+ kMaxAsciiCharCodeU: 1
+ <byte>: 6
+ kASCIISize: 1
+ ConvertToUtf16: 2
+ ! '*reinterpret_cast': 1
+ <uc16*>: 2
+ kUC16Size: 2
+ is_ascii: 3
+ Vector: 13
+ <const>: 10
+ uc16: 5
+ utf16_literal: 3
+ reinterpret_cast: 6
+ backing_store_.start: 5
+ ascii_literal: 3
+ length: 8
+ kInitialCapacity: 2
+ kGrowthFactory: 2
+ kMinConversionSlack: 1
+ kMaxGrowth: 2
+ MB: 1
+ NewCapacity: 3
+ min_capacity: 2
+ capacity: 3
+ Max: 1
+ new_capacity: 2
+ Min: 1
+ new_store: 6
+ New: 2
+ memcpy: 1
+ new_store.start: 3
+ new_content_size: 4
+ src: 2
+ <char*>: 1
+ dst: 2
+ Scanner*: 2
+ self: 2
+ scanner_: 5
+ complete_: 4
+ StartLiteral: 2
+ DropLiteral: 2
+ Complete: 1
+ TerminateLiteral: 2
+ struct: 2
+ beg_pos: 5
+ end_pos: 4
+ kNoOctalLocation: 1
+ scanner_contants: 1
+ current_token: 1
+ location: 4
+ current_.location: 2
+ literal_ascii_string: 1
+ ASSERT_NOT_NULL: 9
+ current_.literal_chars: 11
+ literal_utf16_string: 1
+ is_literal_ascii: 1
+ literal_length: 1
+ literal_contains_escapes: 1
+ source_length: 3
+ location.end_pos: 1
+ location.beg_pos: 1
+ STRING: 1
+ peek: 1
+ peek_location: 1
+ next_.location: 1
+ next_literal_ascii_string: 1
+ next_literal_utf16_string: 1
+ is_next_literal_ascii: 1
+ next_literal_length: 1
+ kCharacterLookaheadBufferSize: 3
+ ScanOctalEscape: 1
+ octal_position: 1
+ clear_octal_position: 1
+ HarmonyScoping: 1
+ SetHarmonyScoping: 1
+ scoping: 2
+ HarmonyModules: 1
+ SetHarmonyModules: 1
+ modules: 2
+ HasAnyLineTerminatorBeforeNext: 1
+ ScanRegExpPattern: 1
+ seen_equal: 1
+ ScanRegExpFlags: 1
+ IsIdentifier: 1
+ CharacterStream*: 1
+ buffer: 1
+ TokenDesc: 3
+ LiteralBuffer*: 2
+ literal_chars: 1
+ free_buffer: 3
+ literal_buffer1_: 3
+ literal_buffer2_: 2
+ AddLiteralChar: 2
+ tok: 2
+ next: 2
+ then: 2
+ else_: 2
+ ScanDecimalDigits: 1
+ seen_period: 1
+ ScanIdentifierSuffix: 1
+ LiteralScope*: 1
+ ScanIdentifierUnicodeEscape: 1
+ UTILS_H: 2
+ <QtGlobal>: 1
+ <QWebFrame>: 1
+ <QFile>: 1
+ QTemporaryFile: 1
+ showUsage: 1
+ QtMsgType: 1
+ type: 1
+ dump_path: 1
+ minidump_id: 1
+ void*: 1
+ context: 8
+ succeeded: 1
+ QVariant: 1
+ coffee2js: 1
+ script: 1
+ injectJsInFrame: 2
+ jsFilePath: 5
+ libraryPath: 5
+ QWebFrame: 4
+ ! '*targetFrame': 4
+ startingScript: 2
+ Encoding: 3
+ jsFileEnc: 2
+ readResourceFileUtf8: 1
+ resourceFilePath: 1
+ loadJSForDebug: 2
+ autorun: 2
+ cleanupFromDebug: 1
+ findScript: 1
+ jsFromScriptFile: 1
+ scriptPath: 1
+ enc: 1
+ This: 1
+ shouldn: 1
+ be: 1
+ instantiated: 1
+ QTemporaryFile*: 2
+ m_tempHarness: 1
+ We: 1
+ want: 1
+ make: 1
+ sure: 1
+ clean: 1
+ up: 1
+ after: 1
+ ourselves: 1
+ m_tempWrapper: 1
+ V8_DECLARE_ONCE: 1
+ init_once: 2
+ V8: 21
+ is_running_: 6
+ has_been_set_up_: 4
+ has_been_disposed_: 6
+ has_fatal_error_: 5
+ use_crankshaft_: 6
+ List: 3
+ <CallCompletedCallback>: 3
+ call_completed_callbacks_: 16
+ LazyMutex: 1
+ entropy_mutex: 1
+ LAZY_MUTEX_INITIALIZER: 1
+ EntropySource: 3
+ entropy_source: 4
+ Deserializer*: 2
+ des: 3
+ FlagList: 1
+ EnforceFlagImplications: 1
+ InitializeOncePerProcess: 4
+ Isolate: 9
+ CurrentPerIsolateThreadData: 4
+ EnterDefaultIsolate: 1
+ thread_id: 1
+ .Equals: 1
+ ThreadId: 1
+ Current: 5
+ isolate: 15
+ IsDead: 2
+ Isolate*: 6
+ IsInitialized: 1
+ SetFatalError: 2
+ TearDown: 5
+ IsDefaultIsolate: 1
+ ElementsAccessor: 2
+ LOperand: 2
+ TearDownCaches: 1
+ RegisteredExtension: 1
+ UnregisterAll: 1
+ delete: 2
+ OS: 3
+ seed_random: 2
+ uint32_t*: 2
+ state: 15
+ FLAG_random_seed: 2
+ val: 3
+ ScopedLock: 1
+ lock: 1
+ entropy_mutex.Pointer: 1
+ random: 1
+ random_base: 3
+ xFFFF: 2
+ FFFF: 1
+ SetEntropySource: 2
+ SetReturnAddressLocationResolver: 3
+ ReturnAddressLocationResolver: 2
+ resolver: 3
+ StackFrame: 1
+ Random: 3
+ Context*: 4
+ IsGlobalContext: 1
+ ByteArray*: 1
+ seed: 2
+ random_seed: 1
+ <uint32_t*>: 1
+ GetDataStartAddress: 1
+ RandomPrivate: 2
+ private_random_seed: 1
+ IdleNotification: 3
+ hint: 3
+ FLAG_use_idle_notification: 1
+ HEAP: 1
+ AddCallCompletedCallback: 2
+ CallCompletedCallback: 4
+ callback: 7
+ at: 3
+ Add: 1
+ RemoveCallCompletedCallback: 2
+ Remove: 1
+ FireCallCompletedCallback: 2
+ HandleScopeImplementer*: 1
+ handle_scope_implementer: 5
+ CallDepthIsZero: 1
+ IncrementCallDepth: 1
+ DecrementCallDepth: 1
+ union: 1
+ double: 2
+ double_value: 1
+ uint64_t: 2
+ uint64_t_value: 1
+ double_int_union: 2
+ Object*: 4
+ FillHeapNumberWithRandom: 2
+ heap_number: 4
+ random_bits: 2
+ binary_million: 3
+ '.0': 1
+ r.double_value: 3
+ r.uint64_t_value: 1
+ HeapNumber: 1
+ cast: 1
+ set_value: 1
+ InitializeOncePerProcessImpl: 3
+ SetUp: 4
+ FLAG_crankshaft: 1
+ Serializer: 1
+ enabled: 1
+ CPU: 2
+ SupportsCrankshaft: 1
+ PostSetUp: 1
+ RuntimeProfiler: 1
+ GlobalSetUp: 1
+ FLAG_stress_compaction: 1
+ FLAG_force_marking_deque_overflows: 1
+ FLAG_gc_global: 1
+ FLAG_max_new_space_size: 1
+ kPageSizeBits: 1
+ SetUpCaches: 1
+ SetUpJSCallerSavedCodeData: 1
+ SamplerRegistry: 1
+ ExternalReference: 1
+ CallOnce: 1
+ V8_V8_H_: 2
+ defined: 5
+ GOOGLE3: 1
+ DEBUG: 3
+ NDEBUG: 4
+ ! '#undef': 1
+ both: 1
+ are: 1
+ set: 1
+ Deserializer: 1
+ AllStatic: 1
+ IsRunning: 1
+ UseCrankshaft: 1
+ FatalProcessOutOfMemory: 1
+ take_snapshot: 1
+ NilValue: 1
+ kNullValue: 1
+ kUndefinedValue: 1
+ EqualityKind: 1
+ kStrictEquality: 1
+ kNonStrictEquality: 1
Ceylon:
doc: 2
by: 1
@@ -4533,125 +5423,6 @@ tokens:
app_nil_end.: 1
<: 65
execute_theorem.: 1
- Eqdep_dec.: 1
- Arith.: 2
- eq_rect_eq_nat: 2
- Q: 3
- eq_rect: 3
- h.: 1
- K_dec_set: 1
- eq_nat_dec.: 1
- Scheme: 1
- le_ind: 1
- replace: 4
- le_n: 4
- n0: 4
- refl_equal: 4
- pattern: 2
- case: 2
- trivial.: 14
- contradiction: 8
- le_Sn_n: 5
- assumption: 3
- le_S: 6
- Heq: 8
- m0: 1
- HeqS: 3
- injection: 8
- HeqS.: 2
- eq_rect_eq_nat.: 1
- IHp: 2
- dep_pair_intro: 2
- Hx: 24
- Hy: 17
- <=n),>: 1
- x=: 1
- exist: 7
- <=>: 9
- Hy.: 3
- Heq.: 6
- le_uniqueness_proof: 1
- Hy0: 1
- card: 2
- card_interval: 1
- <=n}>: 1
- proj1_sig: 1
- proj2_sig: 1
- Hp: 5
- Hq: 3
- Hpq.: 1
- Hmn.: 1
- Hmn: 1
- interval_dec: 1
- left.: 3
- dep_pair_intro.: 3
- right.: 9
- discriminate: 4
- le_Sn_le: 2
- eq_S.: 1
- Hneq.: 2
- card_inj_aux: 1
- g: 6
- False.: 1
- Hfbound: 1
- Hfinj: 1
- Hgsurj.: 1
- Hgsurj: 3
- Hfx: 2
- le_n_O_eq.: 2
- Hfbound.: 2
- Hx.: 4
- le_lt_dec: 9
- xSn: 21
- is: 4
- bounded: 1
- injective: 6
- Hlefx: 1
- Hgefx: 1
- Hlefy: 1
- Hgefy: 1
- Hfinj.: 3
- sym_not_eq.: 2
- Heqf.: 2
- Hneqy.: 2
- le_lt_trans: 2
- le_O_n.: 2
- le_neq_lt: 2
- Hneqx.: 2
- pred_inj.: 1
- lt_O_neq: 2
- neq_dep_intro: 2
- inj_restrict: 1
- Heqf: 1
- surjective: 1
- Hlep.: 3
- Hlt: 3
- Hfsurj: 2
- le_n_S: 1
- Hlep: 4
- Hneq: 7
- Heqx.: 2
- Heqx: 4
- le_not_lt: 1
- lt_trans: 4
- lt_n_Sn.: 1
- Hlt.: 1
- lt_irrefl: 2
- lt_le_trans: 1
- pose: 1
- Hneqx: 1
- Hneqy: 1
- Heqg: 1
- Hdec: 3
- Heqy: 1
- Hginj: 1
- HSnx.: 1
- HSnx: 1
- interval_discr: 1
- <=m}>: 1
- card_inj: 1
- interval_dec.: 1
- card_interval.: 2
Basics.: 2
NatList.: 2
natprod: 5
@@ -4705,21 +5476,132 @@ tokens:
rev_exercise: 1
rev_involutive.: 1
beq_nat_sym: 1
+ Omega: 1
+ SetoidList.: 1
+ Implicit: 15
+ Arguments.: 2
+ Local: 6
+ nil.: 2
+ ..: 4
+ Permut.: 1
+ eqA_equiv: 1
+ eqA.: 1
+ list_contents_app: 5
+ permut_refl: 1
+ permut_sym: 3
+ trivial.: 14
+ permut_trans: 4
+ permut_cons_eq: 3
+ meq_left: 1
+ meq_singleton: 1
+ auto.: 48
+ permut_cons: 5
+ permut_app: 1
+ l4: 3
+ specialize: 6
+ a0.: 1
+ Ha: 6
+ decide: 1
+ replace: 4
+ permut_add_inside_eq: 1
+ permut_add_cons_inside: 3
+ permut_add_inside: 1
+ permut_middle: 1
+ permut_refl.: 5
+ permut_sym_app: 1
+ do: 5
+ arith.: 8
+ permut_rev: 1
+ rev: 7
+ permut_add_cons_inside.: 1
+ app_nil_end: 1
+ results: 1
+ permut_conv_inv: 1
+ plus_reg_l.: 1
+ permut_app_inv1: 1
+ list_contents_app.: 1
+ plus_reg_l: 1
+ multiplicity: 6
+ Fact: 3
+ if_eqA_then: 1
+ if_eqA_refl: 3
+ decide_left: 1
+ Global: 4
+ if_eqA: 1
+ contradict: 3
+ transitivity: 4
+ eauto: 8
+ if_eqA_rewrite_r: 1
+ A2: 4
+ Hxx: 1
+ multiplicity_InA: 4
+ InA: 8
+ a.: 5
+ split: 15
+ right.: 9
+ IHl: 8
+ multiplicity_InA_O: 2
+ multiplicity_InA_S: 1
+ multiplicity_NoDupA: 1
+ NoDupA: 3
+ inversion_clear: 6
+ EQ: 8
+ NEQ: 1
+ omega: 2
+ Permutation: 42
+ is: 4
+ compatible: 1
+ permut_InA_InA: 3
+ multiplicity_InA.: 1
+ meq.: 2
+ permut_cons_InA: 4
+ permut_nil: 2
+ by: 9
+ Abs: 2
+ permut_length_1: 1
+ discriminate.: 1
+ permut_length_2: 1
+ P.: 5
+ permut_length_1.: 2
+ red: 7
+ ! '@if_eqA_rewrite_l': 2
+ permut_length: 1
+ length: 23
+ InA_split: 2
+ h2: 1
+ app_length.: 2
+ plus_n_Sm: 1
+ f_equal.: 1
+ app_length: 2
+ IHl1: 1
+ permut_remove_hd: 1
+ f_equal: 1
+ if_eqA_rewrite_l: 1
+ NoDupA_equivlistA_permut: 1
+ Equivalence_Reflexive.: 1
+ change: 1
+ Equivalence_Reflexive: 1
+ Forall2: 1
+ permutation_Permutation: 1
+ Heq: 8
+ permut_remove_hd_eq: 1
+ Permutation_impl_permutation: 1
+ permut_eqA: 1
+ Permut_permut.: 1
+ permut_right: 1
+ only: 3
+ parsing: 3
+ permut_tran: 1
Setoid: 1
Compare_dec: 1
ListNotations.: 1
- Implicit: 15
- Arguments.: 2
Permutation.: 1
- Permutation: 42
perm_nil: 1
perm_skip: 1
Logic.eq: 2
! '@Permutation': 6
iff: 1
! '@In': 1
- red: 7
- eauto: 8
Permutation_in.: 2
Permutation_app_tail: 1
tl: 7
@@ -4733,10 +5615,7 @@ tokens:
Permutation_app.: 1
Permutation_add_inside: 1
Permutation_app: 1
- auto.: 48
Permutation_cons_append: 1
- IHl: 8
- Local: 6
Permutation_cons_append.: 3
Permutation_app_comm: 3
app_nil_r: 2
@@ -4744,14 +5623,10 @@ tokens:
Permutation_cons_app: 2
Permutation_middle: 2
Permutation_rev: 3
- rev: 7
'1': 2
- Global: 4
! '@rev': 1
'2': 2
Permutation_length: 2
- length: 23
- transitivity: 4
! '@length': 1
Permutation_length.: 1
Permutation_ind_bis: 2
@@ -4763,10 +5638,10 @@ tokens:
eauto.: 7
Ltac: 1
break_list: 4
+ injection: 8
Permutation_nil_app_cons: 1
- l4: 3
eapply: 7
- P.: 5
+ Hp: 5
IH: 4
H6: 3
in_or_app: 1
@@ -4776,9 +5651,9 @@ tokens:
Permutation_app_inv: 2
Permutation_app_inv_l: 1
Permutation_app_inv_r: 1
- do: 5
Permutation_length_1_inv: 3
Heqm: 5
+ discriminate: 4
! '||': 2
Permutation_nil: 1
Permutation_length_1: 1
@@ -4798,27 +5673,27 @@ tokens:
N: 2
Hal: 2
Hl: 3
- by: 9
in_split: 1
- Ha: 6
H12: 5
Ha.: 1
+ Hx: 24
NoDup_remove_1: 1
eq_add_S: 3
- app_length: 2
arith: 5
+ Hy: 17
intuition: 1
NoDup_Permutation: 1
NoDup: 2
exfalso.: 1
NoDup_Permutation_bis: 2
- inversion_clear: 6
constructor.: 6
intuition.: 2
Permutation_NoDup: 1
Permutation_map: 1
Hf: 15
+ Hy.: 3
injective_bounded_surjective: 1
+ injective: 6
set: 1
seq: 2
map: 4
@@ -4828,7 +5703,6 @@ tokens:
seq_NoDup: 1
map_length: 1
in_map_iff: 1
- split: 15
nat_bijection_Permutation: 1
BD.: 1
seq_NoDup.: 1
@@ -4843,6 +5717,7 @@ tokens:
and: 1
nth: 2
adapt: 4
+ le_lt_dec: 9
adapt_injective: 1
adapt.: 2
EQ.: 2
@@ -4851,7 +5726,6 @@ tokens:
Hf.: 1
Lt.le_lt_or_eq: 3
LE.: 3
- EQ: 8
lt: 3
LT.: 5
Lt.S_pred: 3
@@ -4859,15 +5733,14 @@ tokens:
adapt_ok: 2
nth_error_app1: 1
nth_error_app2: 1
- arith.: 8
Minus.minus_Sn_m: 1
Permutation_nth_error: 2
IHP: 1
IHP2: 1
+ g: 6
Hg: 2
E.: 2
L12: 2
- app_length.: 2
plus_n_Sm.: 1
adapt_injective.: 1
nth_error_None: 4
@@ -4881,94 +5754,6 @@ tokens:
congruence.: 1
Permutation_alt.: 1
Permutation_app_swap: 1
- only: 3
- parsing: 3
- Omega: 1
- SetoidList.: 1
- nil.: 2
- ..: 4
- Permut.: 1
- eqA_equiv: 1
- eqA.: 1
- list_contents_app: 5
- permut_refl: 1
- permut_sym: 3
- permut_trans: 4
- permut_cons_eq: 3
- meq_left: 1
- meq_singleton: 1
- permut_cons: 5
- permut_app: 1
- specialize: 6
- a0.: 1
- decide: 1
- permut_add_inside_eq: 1
- permut_add_cons_inside: 3
- permut_add_inside: 1
- permut_middle: 1
- permut_refl.: 5
- permut_sym_app: 1
- permut_rev: 1
- permut_add_cons_inside.: 1
- app_nil_end: 1
- results: 1
- permut_conv_inv: 1
- plus_reg_l.: 1
- permut_app_inv1: 1
- list_contents_app.: 1
- plus_reg_l: 1
- multiplicity: 6
- Fact: 3
- if_eqA_then: 1
- if_eqA_refl: 3
- decide_left: 1
- if_eqA: 1
- contradict: 3
- if_eqA_rewrite_r: 1
- A2: 4
- Hxx: 1
- multiplicity_InA: 4
- InA: 8
- a.: 5
- multiplicity_InA_O: 2
- multiplicity_InA_S: 1
- multiplicity_NoDupA: 1
- NoDupA: 3
- NEQ: 1
- omega: 2
- compatible: 1
- permut_InA_InA: 3
- multiplicity_InA.: 1
- meq.: 2
- permut_cons_InA: 4
- permut_nil: 2
- Abs: 2
- permut_length_1: 1
- discriminate.: 1
- permut_length_2: 1
- permut_length_1.: 2
- ! '@if_eqA_rewrite_l': 2
- permut_length: 1
- InA_split: 2
- h2: 1
- plus_n_Sm: 1
- f_equal.: 1
- IHl1: 1
- permut_remove_hd: 1
- f_equal: 1
- if_eqA_rewrite_l: 1
- NoDupA_equivlistA_permut: 1
- Equivalence_Reflexive.: 1
- change: 1
- Equivalence_Reflexive: 1
- Forall2: 1
- permutation_Permutation: 1
- permut_remove_hd_eq: 1
- Permutation_impl_permutation: 1
- permut_eqA: 1
- Permut_permut.: 1
- permut_right: 1
- permut_tran: 1
Lists.: 1
X.: 4
app: 5
@@ -5080,11 +5865,16 @@ tokens:
Hmo.: 4
Hnm.: 3
IHHmo.: 1
+ lt_trans: 4
lt.: 2
transitive.: 1
+ le_S: 6
Hm: 1
+ le_Sn_le: 2
+ <=>: 9
le_S_n: 2
Sn_le_Sm__n_le_m.: 1
+ le_Sn_n: 5
not: 1
TODO: 1
Hmo: 1
@@ -5158,6 +5948,7 @@ tokens:
step: 9
ST_PlusConstConst: 3
ST_Plus1: 2
+ assumption: 3
strong_progress: 2
value_not_same_as_normal_form: 2
normal_form: 3
@@ -5184,6 +5975,7 @@ tokens:
bool_step_prop4_holds: 1
bool_step_prop4.: 2
ST_ShortCut.: 1
+ left.: 3
IHt1.: 1
t2.: 4
t3.: 2
@@ -5277,896 +6069,104 @@ tokens:
IHhas_type.: 1
IHhas_type1.: 1
IHhas_type2.: 1
- C++:
- class: 19
- Bar: 2
- ! '{': 283
- protected: 4
- char: 32
- ! '*name': 2
- ;: 793
- public: 20
- void: 58
- hello: 2
- (: 842
- ): 843
- ! '}': 285
- foo: 2
- cudaArray*: 1
- cu_array: 4
- texture: 1
- <float,>: 1
- '2': 1
- cudaReadModeElementType: 1
- tex: 4
- //: 457
- cudaChannelFormatDesc: 1
- description: 2
- cudaCreateChannelDesc: 1
- <float>: 1
- cudaMallocArray: 1
- ! '&': 74
- width: 5
- height: 5
- cudaMemcpyToArray: 1
- image: 1
- width*height*sizeof: 1
- float: 2
- cudaMemcpyHostToDevice: 1
- tex.addressMode: 2
- cudaAddressModeClamp: 2
- tex.filterMode: 1
- cudaFilterModePoint: 1
- tex.normalized: 1
- 'false': 40
- cudaBindTextureToArray: 1
- dim3: 2
- blockDim: 2
- gridDim: 2
- +: 40
- blockDim.x: 2
- ! '-': 114
- /: 9
- blockDim.y: 2
- kernel: 2
- <<: 5
- <: 27
- d_data: 1
- cudaUnbindTexture: 1
- //end: 1
- __global__: 1
- float*: 1
- odata: 2
- int: 62
- unsigned: 16
- x: 19
- blockIdx.x*blockDim.x: 1
- threadIdx.x: 1
- y: 4
- blockIdx.y*blockDim.y: 1
- threadIdx.y: 1
- if: 132
- ! '&&': 13
- c: 33
- tex2D: 1
- y*width: 1
- /*: 9
- ! '*/': 9
- ! '#include': 71
- <QCoreApplication>: 1
- <QString>: 1
- <QVariantMap>: 2
- static: 56
- Env: 13
- ! '*env_instance': 1
- ! '*': 13
- 'NULL': 49
- ! '*Env': 1
- instance: 3
- env_instance: 3
- new: 2
- return: 107
- QObject: 2
- QCoreApplication: 1
- parse: 3
- const: 91
- ! '**envp': 1
- ! '**env': 1
- ! '**': 2
- QString: 18
- envvar: 2
- name: 3
- value: 3
- indexOfEquals: 5
- for: 9
- env: 3
- envp: 4
- ! '*env': 1
- (*: 3
- ! '*)': 3
- envvar.indexOf: 1
- continue: 2
- envvar.left: 1
- envvar.mid: 1
- m_map.insert: 1
- QVariantMap: 3
- asVariantMap: 2
- m_map: 2
- ! '#ifndef': 5
- ENV_H: 2
- ! '#define': 5
- <QObject>: 1
- Q_OBJECT: 1
- ! '*instance': 1
- private: 8
- ! '#endif': 12
- <iostream>: 1
- using: 1
- namespace: 10
- std: 18
- main: 2
- cout: 1
- endl: 1
- <map>: 1
- <openssl/ecdsa.h>: 1
- <openssl/obj_mac.h>: 1
- EC_KEY_regenerate_key: 1
- EC_KEY: 2
- ! '*eckey': 2
- BIGNUM: 9
- ! '*priv_key': 1
- ok: 3
- BN_CTX: 2
- ! '*ctx': 2
- EC_POINT: 4
- ! '*pub_key': 1
- eckey: 7
- EC_GROUP: 2
- ! '*group': 2
- EC_KEY_get0_group: 2
- ctx: 25
- BN_CTX_new: 2
- goto: 23
- err: 25
- pub_key: 6
- EC_POINT_new: 4
- group: 12
- EC_POINT_mul: 3
- priv_key: 2
- EC_KEY_set_private_key: 1
- EC_KEY_set_public_key: 2
- EC_POINT_free: 4
- BN_CTX_free: 2
- ECDSA_SIG_recover_key_GFp: 3
- ECDSA_SIG: 3
- ! '*ecsig': 1
- ! '*msg': 2
- msglen: 2
- recid: 3
- check: 2
- ret: 23
- ! '*x': 1
- ! '*e': 1
- ! '*order': 1
- ! '*sor': 1
- ! '*eor': 1
- ! '*field': 1
- ! '*R': 1
- ! '*O': 1
- ! '*Q': 1
- ! '*rr': 1
- ! '*zero': 1
- n: 7
- i: 47
- BN_CTX_start: 1
- order: 8
- BN_CTX_get: 8
- EC_GROUP_get_order: 1
- BN_copy: 1
- BN_mul_word: 1
- BN_add: 1
- ecsig: 3
- r: 9
- field: 3
- EC_GROUP_get_curve_GFp: 1
- BN_cmp: 1
- R: 6
- EC_POINT_set_compressed_coordinates_GFp: 1
- ! '%': 1
- O: 5
- EC_POINT_is_at_infinity: 1
- Q: 5
- EC_GROUP_get_degree: 1
- e: 13
- BN_bin2bn: 3
- msg: 1
- ! '*msglen': 1
- BN_rshift: 1
- zero: 3
- BN_zero: 1
- BN_mod_sub: 1
- rr: 4
- BN_mod_inverse: 1
- sor: 3
- BN_mod_mul: 2
- s: 5
- eor: 3
- BN_CTX_end: 1
- CKey: 26
- SetCompressedPubKey: 4
- EC_KEY_set_conv_form: 1
- pkey: 14
- POINT_CONVERSION_COMPRESSED: 1
- fCompressedPubKey: 5
- 'true': 31
- Reset: 5
- EC_KEY_new_by_curve_name: 2
- NID_secp256k1: 2
- throw: 4
- key_error: 6
- fSet: 7
- b: 12
- EC_KEY_dup: 1
- b.pkey: 2
- b.fSet: 2
- operator: 5
- EC_KEY_copy: 1
- hash: 20
- sizeof: 6
- vchSig: 18
- nSize: 2
- vchSig.clear: 2
- vchSig.resize: 2
- bool: 89
- SignCompact: 2
- uint256: 10
- vector: 14
- <unsigned>: 19
- fOk: 3
- ! '*sig': 2
- ECDSA_do_sign: 1
- char*: 7
- sig: 11
- nBitsR: 3
- BN_num_bits: 2
- nBitsS: 3
- nRecId: 4
- <4;>: 1
- keyRec: 5
- '1': 2
- GetPubKey: 5
- this: 2
- break: 30
- BN_bn2bin: 2
- /8: 2
- ECDSA_SIG_free: 2
- SetCompactSignature: 2
- vchSig.size: 2
- nV: 6
- <27>: 1
- ECDSA_SIG_new: 1
- EC_KEY_free: 1
- Verify: 2
- ECDSA_verify: 1
- VerifyCompact: 2
- key: 1
- key.SetCompactSignature: 1
- key.GetPubKey: 1
- IsValid: 4
- fCompr: 3
- CSecret: 4
- secret: 2
- GetSecret: 2
- key2: 1
- key2.SetSecret: 1
- key2.GetPubKey: 1
- BITCOIN_KEY_H: 2
- <stdexcept>: 1
- <vector>: 1
- <openssl/ec.h>: 1
- runtime_error: 2
- explicit: 3
- string: 1
- str: 2
- CKeyID: 5
- uint160: 8
- in: 4
- CScriptID: 3
- CPubKey: 11
- vchPubKey: 6
- friend: 4
- vchPubKeyIn: 2
- a: 3
- a.vchPubKey: 3
- b.vchPubKey: 3
- IMPLEMENT_SERIALIZE: 1
- READWRITE: 1
- GetID: 1
- Hash160: 1
- GetHash: 1
- Hash: 1
- vchPubKey.begin: 1
- vchPubKey.end: 1
- vchPubKey.size: 3
- ! '||': 8
- IsCompressed: 2
- Raw: 1
- typedef: 5
- secure_allocator: 2
- CPrivKey: 3
- EC_KEY*: 1
- IsNull: 1
- MakeNewKey: 1
- fCompressed: 3
- SetPrivKey: 1
- vchPrivKey: 1
- SetSecret: 1
- vchSecret: 1
- GetPrivKey: 1
- SetPubKey: 1
- Sign: 1
- ! '#ifdef': 3
- Q_OS_LINUX: 2
- <QApplication>: 1
- ! '#if': 4
- QT_VERSION: 1
- QT_VERSION_CHECK: 1
- ! '#error': 2
- Something: 1
- is: 1
- wrong: 1
- with: 1
- the: 5
- setup.: 1
- Please: 1
- report: 2
- to: 3
- mailing: 1
- list: 1
- argc: 2
- char**: 2
- argv: 2
- google_breakpad: 1
- ExceptionHandler: 1
- eh: 1
- Utils: 4
- exceptionHandler: 2
- qInstallMsgHandler: 1
- messageHandler: 2
- QApplication: 1
- app: 1
- STATIC_BUILD: 1
- Q_INIT_RESOURCE: 2
- WebKit: 1
- InspectorBackendStub: 1
- app.setWindowIcon: 1
- QIcon: 1
- app.setApplicationName: 1
- app.setOrganizationName: 1
- app.setOrganizationDomain: 1
- app.setApplicationVersion: 1
- PHANTOMJS_VERSION_STRING: 1
- Phantom: 1
- phantom: 1
- phantom.execute: 1
- app.exec: 1
- phantom.returnValue: 1
- v8: 5
- internal: 5
- Scanner: 16
- UnicodeCache*: 4
- unicode_cache: 3
- unicode_cache_: 10
- octal_pos_: 5
- Location: 14
- invalid: 4
- harmony_scoping_: 4
- harmony_modules_: 4
- Initialize: 4
- Utf16CharacterStream*: 3
- source: 6
- source_: 7
- Init: 3
- has_line_terminator_before_next_: 9
- SkipWhiteSpace: 4
- Scan: 5
- uc32: 19
- ScanHexNumber: 2
- expected_length: 4
- ASSERT: 17
- digits: 3
- c0_: 64
- d: 4
- HexValue: 2
- j: 4
- PushBack: 8
- Advance: 40
- STATIC_ASSERT: 5
- Token: 212
- NUM_TOKENS: 1
- byte: 1
- one_char_tokens: 2
- ILLEGAL: 120
- LPAREN: 2
- RPAREN: 2
- COMMA: 2
- COLON: 2
- SEMICOLON: 2
- CONDITIONAL: 2
- LBRACK: 2
- RBRACK: 2
- LBRACE: 2
- RBRACE: 2
- BIT_NOT: 2
- Value: 23
- Next: 2
- current_: 2
- next_: 2
- has_multiline_comment_before_next_: 5
- static_cast: 7
- f: 4
- token: 61
- <Token::Value>: 1
- pos: 12
- source_pos: 10
- next_.token: 3
- next_.location.beg_pos: 3
- next_.location.end_pos: 4
- current_.token: 4
- inline: 12
- IsByteOrderMark: 2
- xFEFF: 1
- xFFFE: 1
- start_position: 2
- while: 6
- IsWhiteSpace: 2
- IsLineTerminator: 6
- SkipSingleLineComment: 6
- WHITESPACE: 6
- SkipMultiLineComment: 3
- ch: 5
- ScanHtmlComment: 3
- LT: 2
- next_.literal_chars: 13
- do: 1
- switch: 2
- case: 32
- ScanString: 3
- Select: 32
- LTE: 1
- else: 32
- ASSIGN_SHL: 1
- SHL: 1
- GTE: 1
- ASSIGN_SAR: 1
- ASSIGN_SHR: 1
- SHR: 1
- SAR: 1
- GT: 1
- EQ_STRICT: 1
- EQ: 1
- ASSIGN: 1
- NE_STRICT: 1
- NE: 1
- NOT: 1
- INC: 1
- ASSIGN_ADD: 1
- ADD: 1
- DEC: 1
- ASSIGN_SUB: 1
- SUB: 1
- ASSIGN_MUL: 1
- MUL: 1
- ASSIGN_MOD: 1
- MOD: 1
- ASSIGN_DIV: 1
- DIV: 1
- AND: 1
- ASSIGN_BIT_AND: 1
- BIT_AND: 1
- OR: 1
- ASSIGN_BIT_OR: 1
- BIT_OR: 1
- ASSIGN_BIT_XOR: 1
- BIT_XOR: 1
- IsDecimalDigit: 2
- ScanNumber: 3
- PERIOD: 1
- default: 1
- IsIdentifierStart: 2
- ScanIdentifierOrKeyword: 2
- EOS: 1
- SeekForward: 4
- current_pos: 4
- ASSERT_EQ: 1
- ScanEscape: 2
- IsCarriageReturn: 2
- IsLineFeed: 2
- t: 6
- u: 6
- v: 3
- xx: 1
- xxx: 1
- error: 1
- immediately: 1
- because: 1
- octal: 1
- escape: 1
- can: 1
- quote: 2
- LiteralScope: 4
- literal: 2
- .: 2
- X: 2
- E: 3
- l: 1
- p: 1
- w: 1
- keyword: 1
- valid: 1
- and: 2
- character: 1
- has: 1
- in_character_class: 2
- AddLiteralCharAdvance: 3
- literal.Complete: 2
- ScanLiteralUnicodeEscape: 3
- V8_SCANNER_H_: 2
- enum: 3
- ParsingFlags: 1
- kNoParsingFlags: 1
- kLanguageModeMask: 4
- kAllowLazy: 1
- kAllowNativesSyntax: 1
- kAllowModules: 1
- CLASSIC_MODE: 2
- STRICT_MODE: 2
- EXTENDED_MODE: 2
- ! '|': 2
- Utf16CharacterStream: 3
- pos_: 6
- virtual: 4
- buffer_cursor_: 5
- buffer_end_: 3
- ReadBlock: 2
- <uc32>: 1
- kEndOfInput: 2
- code_unit_count: 7
- buffered_chars: 2
- SlowSeekForward: 2
- int32_t: 1
- code_unit: 6
- uc16*: 3
- UnicodeCache: 3
- unibrow: 11
- Utf8InputBuffer: 2
- <1024>: 2
- Utf8Decoder: 2
- StaticResource: 2
- <Utf8Decoder>: 2
- utf8_decoder: 1
- utf8_decoder_: 2
- uchar: 4
- kIsIdentifierStart.get: 1
- IsIdentifierPart: 1
- kIsIdentifierPart.get: 1
- kIsLineTerminator.get: 1
- kIsWhiteSpace.get: 1
- Predicate: 4
- <IdentifierStart,>: 1
- '128': 4
- kIsIdentifierStart: 1
- <IdentifierPart,>: 1
- kIsIdentifierPart: 1
- <unibrow::LineTerminator,>: 1
- kIsLineTerminator: 1
- <unibrow::WhiteSpace,>: 1
- kIsWhiteSpace: 1
- DISALLOW_COPY_AND_ASSIGN: 2
- LiteralBuffer: 6
- is_ascii_: 10
- position_: 17
- backing_store_: 7
- backing_store_.length: 4
- backing_store_.Dispose: 3
- INLINE: 2
- AddChar: 2
- uint32_t: 8
- ExpandBuffer: 2
- kMaxAsciiCharCodeU: 1
- <byte>: 6
- kASCIISize: 1
- ConvertToUtf16: 2
- ! '*reinterpret_cast': 1
- <uc16*>: 2
- kUC16Size: 2
- is_ascii: 3
- Vector: 13
- <const>: 10
- uc16: 5
- utf16_literal: 3
- reinterpret_cast: 6
- backing_store_.start: 5
- ascii_literal: 3
- length: 8
- kInitialCapacity: 2
- kGrowthFactory: 2
- kMinConversionSlack: 1
- kMaxGrowth: 2
- MB: 1
- NewCapacity: 3
- min_capacity: 2
- capacity: 3
- Max: 1
- new_capacity: 2
- Min: 1
- new_store: 6
- New: 2
- memcpy: 1
- new_store.start: 3
- new_content_size: 4
- src: 2
- <char*>: 1
- dst: 2
- Scanner*: 2
- self: 2
- scanner_: 5
- complete_: 4
- StartLiteral: 2
- DropLiteral: 2
- Complete: 1
- TerminateLiteral: 2
- struct: 2
- beg_pos: 5
- end_pos: 4
- kNoOctalLocation: 1
- scanner_contants: 1
- current_token: 1
- location: 4
- current_.location: 2
- literal_ascii_string: 1
- ASSERT_NOT_NULL: 9
- current_.literal_chars: 11
- literal_utf16_string: 1
- is_literal_ascii: 1
- literal_length: 1
- literal_contains_escapes: 1
- source_length: 3
- location.end_pos: 1
- location.beg_pos: 1
- STRING: 1
- peek: 1
- peek_location: 1
- next_.location: 1
- next_literal_ascii_string: 1
- next_literal_utf16_string: 1
- is_next_literal_ascii: 1
- next_literal_length: 1
- kCharacterLookaheadBufferSize: 3
- ScanOctalEscape: 1
- octal_position: 1
- clear_octal_position: 1
- HarmonyScoping: 1
- SetHarmonyScoping: 1
- scoping: 2
- HarmonyModules: 1
- SetHarmonyModules: 1
- modules: 2
- HasAnyLineTerminatorBeforeNext: 1
- ScanRegExpPattern: 1
- seen_equal: 1
- ScanRegExpFlags: 1
- IsIdentifier: 1
- CharacterStream*: 1
- buffer: 1
- TokenDesc: 3
- LiteralBuffer*: 2
- literal_chars: 1
- free_buffer: 3
- literal_buffer1_: 3
- literal_buffer2_: 2
- AddLiteralChar: 2
- tok: 2
- next: 2
- then: 2
- else_: 2
- ScanDecimalDigits: 1
- seen_period: 1
- ScanIdentifierSuffix: 1
- LiteralScope*: 1
- ScanIdentifierUnicodeEscape: 1
- UTILS_H: 2
- <QtGlobal>: 1
- <QWebFrame>: 1
- <QFile>: 1
- QTemporaryFile: 1
- showUsage: 1
- QtMsgType: 1
- type: 1
- dump_path: 1
- minidump_id: 1
- void*: 1
- context: 8
- succeeded: 1
- QVariant: 1
- coffee2js: 1
- script: 1
- injectJsInFrame: 2
- jsFilePath: 5
- libraryPath: 5
- QWebFrame: 4
- ! '*targetFrame': 4
- startingScript: 2
- Encoding: 3
- jsFileEnc: 2
- readResourceFileUtf8: 1
- resourceFilePath: 1
- loadJSForDebug: 2
- autorun: 2
- cleanupFromDebug: 1
- findScript: 1
- jsFromScriptFile: 1
- scriptPath: 1
- enc: 1
- This: 1
- shouldn: 1
- be: 1
- instantiated: 1
- QTemporaryFile*: 2
- m_tempHarness: 1
- We: 1
- want: 1
- make: 1
- sure: 1
- clean: 1
- up: 1
- after: 1
- ourselves: 1
- m_tempWrapper: 1
- V8_DECLARE_ONCE: 1
- init_once: 2
- V8: 21
- is_running_: 6
- has_been_set_up_: 4
- has_been_disposed_: 6
- has_fatal_error_: 5
- use_crankshaft_: 6
- List: 3
- <CallCompletedCallback>: 3
- call_completed_callbacks_: 16
- LazyMutex: 1
- entropy_mutex: 1
- LAZY_MUTEX_INITIALIZER: 1
- EntropySource: 3
- entropy_source: 4
- Deserializer*: 2
- des: 3
- FlagList: 1
- EnforceFlagImplications: 1
- InitializeOncePerProcess: 4
- Isolate: 9
- CurrentPerIsolateThreadData: 4
- EnterDefaultIsolate: 1
- thread_id: 1
- .Equals: 1
- ThreadId: 1
- Current: 5
- isolate: 15
- IsDead: 2
- Isolate*: 6
- IsInitialized: 1
- SetFatalError: 2
- TearDown: 5
- IsDefaultIsolate: 1
- ElementsAccessor: 2
- LOperand: 2
- TearDownCaches: 1
- RegisteredExtension: 1
- UnregisterAll: 1
- delete: 2
- OS: 3
- seed_random: 2
- uint32_t*: 2
- state: 15
- FLAG_random_seed: 2
- val: 3
- ScopedLock: 1
- lock: 1
- entropy_mutex.Pointer: 1
- random: 1
- random_base: 3
- xFFFF: 2
- FFFF: 1
- SetEntropySource: 2
- SetReturnAddressLocationResolver: 3
- ReturnAddressLocationResolver: 2
- resolver: 3
- StackFrame: 1
- Random: 3
- Context*: 4
- IsGlobalContext: 1
- ByteArray*: 1
- seed: 2
- random_seed: 1
- <uint32_t*>: 1
- GetDataStartAddress: 1
- RandomPrivate: 2
- private_random_seed: 1
- IdleNotification: 3
- hint: 3
- FLAG_use_idle_notification: 1
- HEAP: 1
- AddCallCompletedCallback: 2
- CallCompletedCallback: 4
- callback: 7
- at: 3
- Add: 1
- RemoveCallCompletedCallback: 2
- Remove: 1
- FireCallCompletedCallback: 2
- HandleScopeImplementer*: 1
- handle_scope_implementer: 5
- CallDepthIsZero: 1
- IncrementCallDepth: 1
- DecrementCallDepth: 1
- union: 1
- double: 2
- double_value: 1
- uint64_t: 2
- uint64_t_value: 1
- double_int_union: 2
- Object*: 4
- FillHeapNumberWithRandom: 2
- heap_number: 4
- random_bits: 2
- binary_million: 3
- '.0': 1
- r.double_value: 3
- r.uint64_t_value: 1
- HeapNumber: 1
- cast: 1
- set_value: 1
- InitializeOncePerProcessImpl: 3
- SetUp: 4
- FLAG_crankshaft: 1
- Serializer: 1
- enabled: 1
- CPU: 2
- SupportsCrankshaft: 1
- PostSetUp: 1
- RuntimeProfiler: 1
- GlobalSetUp: 1
- FLAG_stress_compaction: 1
- FLAG_force_marking_deque_overflows: 1
- FLAG_gc_global: 1
- FLAG_max_new_space_size: 1
- kPageSizeBits: 1
- SetUpCaches: 1
- SetUpJSCallerSavedCodeData: 1
- SamplerRegistry: 1
- ExternalReference: 1
- CallOnce: 1
- V8_V8_H_: 2
- defined: 5
- GOOGLE3: 1
- DEBUG: 3
- NDEBUG: 4
- ! '#undef': 1
- both: 1
- are: 1
- set: 1
- Deserializer: 1
- AllStatic: 1
- IsRunning: 1
- UseCrankshaft: 1
- FatalProcessOutOfMemory: 1
- take_snapshot: 1
- NilValue: 1
- kNullValue: 1
- kUndefinedValue: 1
- EqualityKind: 1
- kStrictEquality: 1
- kNonStrictEquality: 1
+ Eqdep_dec.: 1
+ Arith.: 2
+ eq_rect_eq_nat: 2
+ Q: 3
+ eq_rect: 3
+ h.: 1
+ K_dec_set: 1
+ eq_nat_dec.: 1
+ Scheme: 1
+ le_ind: 1
+ le_n: 4
+ n0: 4
+ refl_equal: 4
+ pattern: 2
+ case: 2
+ contradiction: 8
+ m0: 1
+ HeqS: 3
+ HeqS.: 2
+ eq_rect_eq_nat.: 1
+ IHp: 2
+ dep_pair_intro: 2
+ <=n),>: 1
+ x=: 1
+ exist: 7
+ Heq.: 6
+ le_uniqueness_proof: 1
+ Hy0: 1
+ card: 2
+ card_interval: 1
+ <=n}>: 1
+ proj1_sig: 1
+ proj2_sig: 1
+ Hq: 3
+ Hpq.: 1
+ Hmn.: 1
+ Hmn: 1
+ interval_dec: 1
+ dep_pair_intro.: 3
+ eq_S.: 1
+ Hneq.: 2
+ card_inj_aux: 1
+ False.: 1
+ Hfbound: 1
+ Hfinj: 1
+ Hgsurj.: 1
+ Hgsurj: 3
+ Hfx: 2
+ le_n_O_eq.: 2
+ Hfbound.: 2
+ Hx.: 4
+ xSn: 21
+ bounded: 1
+ Hlefx: 1
+ Hgefx: 1
+ Hlefy: 1
+ Hgefy: 1
+ Hfinj.: 3
+ sym_not_eq.: 2
+ Heqf.: 2
+ Hneqy.: 2
+ le_lt_trans: 2
+ le_O_n.: 2
+ le_neq_lt: 2
+ Hneqx.: 2
+ pred_inj.: 1
+ lt_O_neq: 2
+ neq_dep_intro: 2
+ inj_restrict: 1
+ Heqf: 1
+ surjective: 1
+ Hlep.: 3
+ Hlt: 3
+ Hfsurj: 2
+ le_n_S: 1
+ Hlep: 4
+ Hneq: 7
+ Heqx.: 2
+ Heqx: 4
+ le_not_lt: 1
+ lt_n_Sn.: 1
+ Hlt.: 1
+ lt_irrefl: 2
+ lt_le_trans: 1
+ pose: 1
+ Hneqx: 1
+ Hneqy: 1
+ Heqg: 1
+ Hdec: 3
+ Heqy: 1
+ Hginj: 1
+ HSnx.: 1
+ HSnx: 1
+ interval_discr: 1
+ <=m}>: 1
+ card_inj: 1
+ interval_dec.: 1
+ card_interval.: 2
Dart:
class: 1
Point: 7
@@ -6288,9 +6288,6 @@ tokens:
xd: 1
.subsections_via_symbols: 1
Gosu:
- print: 4
- (: 54
- ): 55
<%!-->: 1
defined: 1
in: 3
@@ -6300,9 +6297,11 @@ tokens:
! '%': 2
! '@': 1
params: 1
+ (: 54
users: 2
Collection: 1
<User>: 1
+ ): 55
<%>: 2
for: 2
user: 1
@@ -6326,7 +6325,6 @@ tokens:
as: 3
int: 2
Relationship.valueOf: 2
- hello: 1
uses: 2
java.util.*: 1
java.io.File: 1
@@ -6373,6 +6371,7 @@ tokens:
+: 2
! '@Deprecated': 1
printPersonInfo: 1
+ print: 4
addPerson: 4
p: 5
if: 4
@@ -6422,6 +6421,7 @@ tokens:
FileWriter: 1
PersonCSVTemplate.renderToString: 1
PersonCSVTemplate.render: 1
+ hello: 1
Groovy:
task: 1
echoDirListViaAntBuilder: 1
@@ -6533,258 +6533,10 @@ tokens:
/*: 85
! '*/': 86
package: 5
- clojure.asm: 1
+ nokogiri.internals: 1
;: 598
import: 66
- java.lang.reflect.Constructor: 1
- java.lang.reflect.Method: 1
- public: 124
- class: 10
- Type: 42
- ! '{': 255
- final: 54
static: 91
- int: 52
- VOID: 5
- BOOLEAN: 6
- CHAR: 6
- BYTE: 6
- SHORT: 6
- INT: 6
- FLOAT: 6
- LONG: 7
- DOUBLE: 7
- ARRAY: 3
- OBJECT: 3
- VOID_TYPE: 3
- new: 61
- (: 724
- ): 722
- BOOLEAN_TYPE: 3
- CHAR_TYPE: 3
- BYTE_TYPE: 3
- SHORT_TYPE: 3
- INT_TYPE: 3
- FLOAT_TYPE: 3
- LONG_TYPE: 3
- DOUBLE_TYPE: 3
- //: 47
- private: 35
- sort: 18
- char: 13
- buf: 43
- 'off': 25
- len: 24
- this.sort: 2
- this.len: 2
- ! '}': 254
- this.buf: 2
- this.off: 1
- getType: 10
- String: 32
- typeDescriptor: 1
- return: 172
- typeDescriptor.toCharArray: 1
- Class: 10
- c: 21
- if: 79
- c.isPrimitive: 2
- Integer.TYPE: 2
- else: 28
- Void.TYPE: 3
- Boolean.TYPE: 2
- Byte.TYPE: 2
- Character.TYPE: 2
- Short.TYPE: 2
- Double.TYPE: 2
- Float.TYPE: 2
- getDescriptor: 11
- getObjectType: 1
- name: 10
- l: 5
- name.length: 2
- +: 79
- name.getChars: 1
- getArgumentTypes: 2
- methodDescriptor: 2
- methodDescriptor.toCharArray: 2
- size: 8
- while: 9
- 'true': 16
- car: 18
- break: 1
- args: 6
- .len: 1
- Method: 3
- method: 3
- classes: 2
- method.getParameterTypes: 1
- types: 3
- classes.length: 2
- for: 15
- i: 54
- ! '-': 12
- getReturnType: 2
- methodDescriptor.indexOf: 1
- method.getReturnType: 1
- switch: 5
- case: 46
- default: 5
- getSort: 1
- getDimensions: 3
- getElementType: 2
- getClassName: 1
- StringBuffer: 14
- b: 1
- .getClassName: 1
- b.append: 1
- b.toString: 1
- .replace: 2
- getInternalName: 2
- buf.toString: 4
- getMethodDescriptor: 2
- returnType: 1
- argumentTypes: 2
- buf.append: 21
- <: 13
- argumentTypes.length: 1
- .getDescriptor: 1
- returnType.getDescriptor: 1
- void: 20
- c.getName: 1
- getConstructorDescriptor: 1
- Constructor: 1
- parameters: 4
- c.getParameterTypes: 1
- parameters.length: 2
- .toString: 1
- m: 1
- m.getParameterTypes: 1
- m.getReturnType: 1
- d: 10
- d.isPrimitive: 1
- d.isArray: 1
- d.getComponentType: 1
- d.getName: 1
- name.charAt: 1
- getSize: 1
- ! '||': 8
- getOpcode: 1
- opcode: 17
- Opcodes.IALOAD: 1
- Opcodes.IASTORE: 1
- boolean: 29
- equals: 2
- Object: 31
- o: 12
- this: 4
- instanceof: 14
- 'false': 9
- t: 6
- t.sort: 1
- Type.OBJECT: 2
- Type.ARRAY: 2
- t.len: 1
- j: 8
- t.off: 1
- end: 4
- t.buf: 1
- hashCode: 1
- hc: 4
- ! '*': 6
- toString: 1
- clojure.lang: 1
- java.lang.ref.Reference: 1
- java.math.BigInteger: 1
- java.util.Map: 3
- java.util.concurrent.ConcurrentHashMap: 1
- java.lang.ref.SoftReference: 1
- java.lang.ref.ReferenceQueue: 1
- Util: 1
- equiv: 17
- k1: 40
- k2: 38
- 'null': 43
- Number: 9
- ! '&&': 6
- Numbers.equal: 1
- IPersistentCollection: 5
- pcequiv: 2
- k1.equals: 2
- long: 4
- double: 4
- c1: 2
- c2: 2
- .equiv: 2
- identical: 1
- classOf: 1
- x: 7
- x.getClass: 1
- compare: 1
- Numbers.compare: 1
- Comparable: 1
- .compareTo: 1
- hash: 3
- o.hashCode: 2
- hasheq: 1
- Numbers.hasheq: 1
- IHashEq: 2
- .hasheq: 1
- hashCombine: 1
- seed: 5
- //a: 1
- la: 1
- boost: 1
- e3779b9: 1
- <<: 1
- isPrimitive: 1
- isInteger: 1
- Integer: 2
- Long: 1
- BigInt: 1
- BigInteger: 1
- ret1: 2
- ret: 4
- nil: 2
- ISeq: 2
- <K,V>: 1
- clearCache: 1
- ReferenceQueue: 1
- rq: 1
- ConcurrentHashMap: 1
- K: 2
- Reference: 3
- <V>: 3
- cache: 1
- //cleanup: 1
- any: 1
- dead: 1
- entries: 1
- rq.poll: 2
- Map.Entry: 1
- e: 11
- cache.entrySet: 1
- val: 3
- e.getValue: 1
- val.get: 1
- cache.remove: 1
- e.getKey: 1
- RuntimeException: 5
- runtimeException: 2
- s: 4
- Throwable: 4
- sneakyThrow: 1
- throw: 2
- NullPointerException: 1
- Util.: 1
- <RuntimeException>: 1
- sneakyThrow0: 2
- ! '@SuppressWarnings': 1
- <T>: 1
- extends: 7
- throws: 10
- T: 2
- nokogiri.internals: 1
nokogiri.internals.NokogiriHelpers.getNokogiriClass: 1
nokogiri.internals.NokogiriHelpers.isNamespace: 1
nokogiri.internals.NokogiriHelpers.stringOrNil: 1
@@ -6807,22 +6559,33 @@ tokens:
org.w3c.dom.Document: 1
org.w3c.dom.NamedNodeMap: 1
org.w3c.dom.NodeList: 1
+ public: 124
+ class: 10
HtmlDomParserContext: 3
+ extends: 7
XmlDomParserContext: 1
+ ! '{': 255
+ (: 724
Ruby: 22
runtime: 30
IRubyObject: 14
options: 4
+ ): 722
super: 5
+ ! '}': 254
encoding: 2
! '@Override': 6
protected: 4
+ void: 20
initErrorHandler: 1
+ if: 79
options.strict: 1
errorHandler: 6
+ new: 61
NokogiriStrictErrorHandler: 1
options.noError: 2
options.noWarning: 2
+ else: 28
NokogiriNonStrictErrorHandler4NekoHtml: 1
initParser: 1
XMLParserConfiguration: 1
@@ -6839,14 +6602,19 @@ tokens:
this.errorHandler: 2
parser: 1
DOMParser: 1
+ //: 47
setProperty: 4
java_encoding: 2
setFeature: 4
+ 'true': 16
+ 'false': 9
enableDocumentFragment: 1
XmlDocument: 3
getNewEmptyDocument: 1
ThreadContext: 2
context: 8
+ args: 6
+ return: 172
XmlDocument.rbNew: 1
getNokogiriClass: 1
context.getRuntime: 3
@@ -6861,22 +6629,32 @@ tokens:
htmlDocument.setDocumentNode: 1
ruby_encoding.isNil: 1
detected_encoding: 2
+ 'null': 43
+ ! '&&': 6
detected_encoding.isNil: 1
ruby_encoding: 3
+ String: 32
charset: 2
tryGetCharsetFromHtml5MetaTag: 2
stringOrNil: 1
htmlDocument.setEncoding: 1
htmlDocument.setParsedEncoding: 1
+ private: 35
.equalsIgnoreCase: 5
document.getDocumentElement: 2
.getNodeName: 4
NodeList: 2
list: 1
.getChildNodes: 2
+ for: 15
+ int: 52
+ i: 54
+ <: 13
list.getLength: 1
+ +: 79
list.item: 2
headers: 1
+ j: 8
headers.getLength: 1
headers.item: 2
NamedNodeMap: 1
@@ -6894,21 +6672,28 @@ tokens:
attrs: 4
Augmentations: 2
augs: 4
+ throws: 10
XNIException: 2
attrs.getLength: 1
isNamespace: 1
attrs.getQName: 1
attrs.removeAttributeAt: 1
+ ! '-': 12
element.uri: 1
super.startElement: 2
NokogiriErrorHandler: 2
element_names: 3
+ boolean: 29
isValid: 2
testee: 1
+ char: 13
+ c: 21
testee.toCharArray: 1
index: 4
+ Integer: 2
.length: 1
testee.equals: 1
+ name: 10
name.rawname: 2
errorHandler.getErrors: 1
.add: 1
@@ -6937,10 +6722,12 @@ tokens:
java.text.ParseException: 1
java.util.Collections: 2
java.util.List: 1
+ java.util.Map: 3
hudson.Util.fixEmpty: 1
Hudson: 5
Jenkins: 2
transient: 2
+ final: 54
CopyOnWriteList: 4
<ItemListener>: 2
itemListeners: 2
@@ -6958,6 +6745,7 @@ tokens:
IOException: 7
InterruptedException: 2
ReactorException: 2
+ this: 4
PluginManager: 1
pluginManager: 2
getJobListeners: 1
@@ -6967,6 +6755,7 @@ tokens:
Node: 1
n: 3
getNode: 1
+ instanceof: 14
List: 3
<Slave>: 2
getSlaves: 1
@@ -7001,6 +6790,7 @@ tokens:
number: 2
and: 1
.: 1
+ ! '*': 6
! '@deprecated': 1
as: 1
of: 2
@@ -7016,6 +6806,7 @@ tokens:
your: 1
own: 1
check: 1
+ method: 3
instead: 1
relying: 1
'on': 1
@@ -7045,6 +6836,7 @@ tokens:
Messages.Hudson_NotANegativeNumber: 1
catch: 8
ParseException: 1
+ e: 11
Messages.Hudson_NotANumber: 1
FormValidation.ok: 1
isWindows: 1
@@ -7276,6 +7068,214 @@ tokens:
XsltStylesheet: 4
xsltStylesheet: 3
xsltStylesheet.clone: 1
+ clojure.asm: 1
+ java.lang.reflect.Constructor: 1
+ java.lang.reflect.Method: 1
+ Type: 42
+ VOID: 5
+ BOOLEAN: 6
+ CHAR: 6
+ BYTE: 6
+ SHORT: 6
+ INT: 6
+ FLOAT: 6
+ LONG: 7
+ DOUBLE: 7
+ ARRAY: 3
+ OBJECT: 3
+ VOID_TYPE: 3
+ BOOLEAN_TYPE: 3
+ CHAR_TYPE: 3
+ BYTE_TYPE: 3
+ SHORT_TYPE: 3
+ INT_TYPE: 3
+ FLOAT_TYPE: 3
+ LONG_TYPE: 3
+ DOUBLE_TYPE: 3
+ sort: 18
+ buf: 43
+ 'off': 25
+ len: 24
+ this.sort: 2
+ this.len: 2
+ this.buf: 2
+ this.off: 1
+ getType: 10
+ typeDescriptor: 1
+ typeDescriptor.toCharArray: 1
+ Class: 10
+ c.isPrimitive: 2
+ Integer.TYPE: 2
+ Void.TYPE: 3
+ Boolean.TYPE: 2
+ Byte.TYPE: 2
+ Character.TYPE: 2
+ Short.TYPE: 2
+ Double.TYPE: 2
+ Float.TYPE: 2
+ getDescriptor: 11
+ getObjectType: 1
+ l: 5
+ name.length: 2
+ name.getChars: 1
+ getArgumentTypes: 2
+ methodDescriptor: 2
+ methodDescriptor.toCharArray: 2
+ size: 8
+ while: 9
+ car: 18
+ break: 1
+ .len: 1
+ Method: 3
+ classes: 2
+ method.getParameterTypes: 1
+ types: 3
+ classes.length: 2
+ getReturnType: 2
+ methodDescriptor.indexOf: 1
+ method.getReturnType: 1
+ switch: 5
+ case: 46
+ default: 5
+ getSort: 1
+ getDimensions: 3
+ getElementType: 2
+ getClassName: 1
+ StringBuffer: 14
+ b: 1
+ .getClassName: 1
+ b.append: 1
+ b.toString: 1
+ .replace: 2
+ getInternalName: 2
+ buf.toString: 4
+ getMethodDescriptor: 2
+ returnType: 1
+ argumentTypes: 2
+ buf.append: 21
+ argumentTypes.length: 1
+ .getDescriptor: 1
+ returnType.getDescriptor: 1
+ c.getName: 1
+ getConstructorDescriptor: 1
+ Constructor: 1
+ parameters: 4
+ c.getParameterTypes: 1
+ parameters.length: 2
+ .toString: 1
+ m: 1
+ m.getParameterTypes: 1
+ m.getReturnType: 1
+ d: 10
+ d.isPrimitive: 1
+ d.isArray: 1
+ d.getComponentType: 1
+ d.getName: 1
+ name.charAt: 1
+ getSize: 1
+ ! '||': 8
+ getOpcode: 1
+ opcode: 17
+ Opcodes.IALOAD: 1
+ Opcodes.IASTORE: 1
+ equals: 2
+ Object: 31
+ o: 12
+ t: 6
+ t.sort: 1
+ Type.OBJECT: 2
+ Type.ARRAY: 2
+ t.len: 1
+ t.off: 1
+ end: 4
+ t.buf: 1
+ hashCode: 1
+ hc: 4
+ toString: 1
+ clojure.lang: 1
+ java.lang.ref.Reference: 1
+ java.math.BigInteger: 1
+ java.util.concurrent.ConcurrentHashMap: 1
+ java.lang.ref.SoftReference: 1
+ java.lang.ref.ReferenceQueue: 1
+ Util: 1
+ equiv: 17
+ k1: 40
+ k2: 38
+ Number: 9
+ Numbers.equal: 1
+ IPersistentCollection: 5
+ pcequiv: 2
+ k1.equals: 2
+ long: 4
+ double: 4
+ c1: 2
+ c2: 2
+ .equiv: 2
+ identical: 1
+ classOf: 1
+ x: 7
+ x.getClass: 1
+ compare: 1
+ Numbers.compare: 1
+ Comparable: 1
+ .compareTo: 1
+ hash: 3
+ o.hashCode: 2
+ hasheq: 1
+ Numbers.hasheq: 1
+ IHashEq: 2
+ .hasheq: 1
+ hashCombine: 1
+ seed: 5
+ //a: 1
+ la: 1
+ boost: 1
+ e3779b9: 1
+ <<: 1
+ isPrimitive: 1
+ isInteger: 1
+ Long: 1
+ BigInt: 1
+ BigInteger: 1
+ ret1: 2
+ ret: 4
+ nil: 2
+ ISeq: 2
+ <K,V>: 1
+ clearCache: 1
+ ReferenceQueue: 1
+ rq: 1
+ ConcurrentHashMap: 1
+ K: 2
+ Reference: 3
+ <V>: 3
+ cache: 1
+ //cleanup: 1
+ any: 1
+ dead: 1
+ entries: 1
+ rq.poll: 2
+ Map.Entry: 1
+ cache.entrySet: 1
+ val: 3
+ e.getValue: 1
+ val.get: 1
+ cache.remove: 1
+ e.getKey: 1
+ RuntimeException: 5
+ runtimeException: 2
+ s: 4
+ Throwable: 4
+ sneakyThrow: 1
+ throw: 2
+ NullPointerException: 1
+ Util.: 1
+ <RuntimeException>: 1
+ sneakyThrow0: 2
+ ! '@SuppressWarnings': 1
+ <T>: 1
+ T: 2
JavaScript:
/*: 80
! '*/': 87
@@ -10052,6 +10052,64 @@ tokens:
(: 1
puts: 1
): 1
+ OCaml:
+ (*: 2
+ ! '*)': 2
+ type: 2
+ a: 3
+ ! '-': 21
+ unit: 4
+ ): 9
+ module: 4
+ Ops: 2
+ struct: 4
+ let: 9
+ (: 7
+ ! '@': 6
+ f: 10
+ k: 21
+ ! '|': 15
+ x: 14
+ end: 4
+ open: 1
+ List: 1
+ rec: 3
+ map: 3
+ l: 8
+ match: 4
+ with: 4
+ hd: 6
+ tl: 6
+ fun: 8
+ fold: 2
+ acc: 5
+ Option: 1
+ opt: 2
+ None: 5
+ Some: 5
+ Lazy: 1
+ option: 1
+ ;: 12
+ mutable: 1
+ waiters: 5
+ ! '}': 3
+ make: 1
+ push: 4
+ cps: 7
+ ! '{': 1
+ value: 3
+ force: 1
+ l.value: 2
+ when: 1
+ l.waiters: 5
+ <->: 3
+ function: 1
+ Base.List.iter: 1
+ l.push: 1
+ <: 1
+ get_state: 1
+ lazy_from_val: 1
+ _: 1
Objective-C:
//: 771
! '#import': 53
@@ -11398,9 +11456,6 @@ tokens:
window: 1
applicationDidFinishLaunching: 1
aNotification: 1
- argc: 1
- ! '*argv': 1
- NSLog: 3
! '#include': 18
<stddef.h>: 1
<stdint.h>: 2
@@ -12672,6 +12727,7 @@ tokens:
newVisibleIndexPaths: 2
! '*indexPathsToAdd': 1
indexPathsToAdd: 3
+ NSLog: 3
invalidateHoverForView: 1
prepareForDisplay: 1
setSelected: 4
@@ -12738,64 +12794,8 @@ tokens:
newValue: 2
indexPathWithIndexes: 1
indexAtPosition: 2
- OCaml:
- (*: 2
- ! '*)': 2
- type: 2
- a: 3
- ! '-': 21
- unit: 4
- ): 9
- module: 4
- Ops: 2
- struct: 4
- let: 9
- (: 7
- ! '@': 6
- f: 10
- k: 21
- ! '|': 15
- x: 14
- end: 4
- open: 1
- List: 1
- rec: 3
- map: 3
- l: 8
- match: 4
- with: 4
- hd: 6
- tl: 6
- fun: 8
- fold: 2
- acc: 5
- Option: 1
- opt: 2
- None: 5
- Some: 5
- Lazy: 1
- option: 1
- ;: 12
- mutable: 1
- waiters: 5
- ! '}': 3
- make: 1
- push: 4
- cps: 7
- ! '{': 1
- value: 3
- force: 1
- l.value: 2
- when: 1
- l.waiters: 5
- <->: 3
- function: 1
- Base.List.iter: 1
- l.push: 1
- <: 1
- get_state: 1
- lazy_from_val: 1
- _: 1
+ argc: 1
+ ! '*argv': 1
Opa:
/*: 2
! '*/': 2
@@ -12962,7 +12962,6 @@ tokens:
OBJECT: 2
.: 13
CLASS.: 2
- MESSAGE: 1
INTERFACE: 1
email.SendEmailAlgorithm: 1
ipobjEmail: 1
@@ -13065,1132 +13064,7 @@ tokens:
CHR: 2
END.: 1
lcPostBase64Data.: 1
- Parrot Assembly:
- ! '#': 1
- /usr/bin/env: 1
- parrot: 1
- .pcc_sub: 1
- main: 2
- say: 1
- end: 1
- Perl:
- ! '#': 142
- /usr/bin/env: 1
- perl: 5
- use: 47
- warnings: 10
- ;: 446
- strict: 10
- our: 16
- VERSION: 12
- MAIN: 1
- ! '{': 376
- if: 96
- (: 328
- App: 46
- Ack: 46
- ne: 5
- main: 3
- ): 322
- die: 7
- ! '}': 385
- my: 142
- env_is_usable: 3
- for: 31
- ! '@ARGV': 6
- last: 7
- _: 56
- eq: 13
- /: 28
- ! '-': 436
- th: 1
- pt: 1
- +: 92
- t: 12
- ! '&&': 30
- _thpppt: 2
- bar: 3
- _bar: 2
- 'no': 10
- env: 54
- defined: 17
- unshift: 1
- read_ackrc: 1
- else: 18
- ! '@keys': 2
- grep: 8
- ACK_/: 1
- keys: 6
- ! '%': 44
- ENV: 5
- delete: 4
- ! '@ENV': 1
- load_colors: 1
- exists: 9
- ACK_SWITCHES: 1
- warn: 7
- show_help: 1
- exit: 4
- sub: 94
- opt: 69
- get_command_line_options: 1
- ! '|': 32
- flush: 2
- input_from_pipe: 4
- qw: 15
- f: 5
- g: 4
- l: 5
- and: 36
- show_filename: 16
- regex: 13
- build_regex: 1
- shift: 74
- nargs: 2
- s: 32
- specify: 1
- both: 1
- a: 41
- one: 5
- of: 19
- line: 7
- or: 23
- g.: 1
- foo: 7
- Defining: 2
- your: 8
- own: 2
- types: 21
- less: 2
- r: 7
- builtin: 2
- bold: 4
- green: 2
- black: 2
- on_yellow: 2
- yellow: 2
- provides: 1
- simple: 1
- compilation: 1
- mode: 1
- ! '...': 3
- has: 1
- the: 77
- ability: 1
- to: 42
- guess: 1
- what: 6
- files: 15
- you: 17
- want: 5
- search: 2
- based: 1
- 'on': 9
- major: 2
- mode.: 1
- I: 35
- spend: 1
- day: 1
- mostly: 1
- inside: 1
- TextMate: 2
- built: 1
- in: 18
- find: 3
- project: 1
- sucks: 1
- with: 12
- large: 1
- projects.: 1
- So: 1
- hacked: 1
- command: 4
- that: 10
- was: 6
- using: 4
- ack.: 1
- The: 10
- result: 1
- is: 29
- Search: 1
- Project: 1
- ack: 16
- can: 10
- it: 21
- here: 2
- L: 14
- <http://www.simplicidade.org/notes/archives/2008/03/search_in_proje.html>: 1
- this: 10
- Invalid: 2
- option: 1
- passed: 1
- badkey: 1
- dir: 3
- dir/: 1
- file: 13
- filename: 30
- n: 26
- type: 35
- i: 10
- may: 2
- not: 13
- be: 12
- negative: 1
- val: 1
- ignoring: 1
- from: 7
- ext: 7
- Permission: 1
- denied: 1
- b: 4
- str: 3
- error: 2
- y: 5
- I#7#I: 1
- ! '#I': 5
- ! '*': 8
- ! '&': 12
- /I: 1
- .: 54
- ! '*/': 1
- .#: 3
- END_OF_HELP: 2
- R: 3
- help: 6
- ! '*.*s': 1
- end: 1
- END_OF_VERSION: 1
- Binary: 2
- matches: 5
- pattern: 2
- Matched: 1
- only: 4
- hidden: 1
- start_point: 3
- 'No': 2
- such: 5
- directory: 3
- self: 92
- return: 60
- package: 7
- Repository: 3
- Basic: 4
- ! '@ISA': 1
- new: 24
- class: 6
- bless: 6
- nexted: 3
- next_resource: 2
- Resource: 1
- close: 4
- File: 20
- Next: 12
- '.40': 1
- Plugin: 1
- head1: 14
- NAME: 2
- A: 2
- container: 1
- functions: 2
- program: 2
- Version: 1
- '.94': 1
- cut: 19
- COPYRIGHT: 3
- BEGIN: 3
- fh: 7
- ! '*STDOUT': 2
- type_wanted: 4
- mappings: 13
- ignore_dirs: 4
- output_to_pipe: 5
- dir_sep_chars: 5
- is_cygwin: 3
- is_windows: 4
- Spec: 2
- Glob: 1
- Getopt: 1
- Long: 1
- _MTN: 1
- blib: 1
- CVS: 2
- RCS: 1
- SCCS: 1
- _darcs: 1
- _sgbak: 1
- _build: 1
- actionscript: 1
- as: 18
- mxml: 1
- ada: 2
- adb: 1
- ads: 1
- asm: 2
- batch: 1
- bat: 1
- cmd: 1
- binary: 2
- q: 3
- by: 3
- Perl: 2
- T: 1
- op: 1
- default: 4
- 'off': 1
- tt: 2
- tt2: 1
- ttml: 1
- vb: 2
- bas: 1
- cls: 1
- frm: 1
- ctl: 1
- resx: 1
- verilog: 1
- v: 10
- vh: 1
- sv: 1
- vhdl: 2
- vhd: 1
- vim: 2
- yaml: 2
- yml: 1
- xml: 3
- dtd: 1
- xsl: 1
- xslt: 1
- ent: 1
- while: 8
- exts: 3
- each: 3
- ref: 19
- ! '@': 15
- push: 6
- mk: 1
- mak: 1
- p: 3
- STDIN: 1
- O: 2
- /MSWin32/: 1
- quotemeta: 2
- catfile: 1
- .ackrc: 1
- _ackrc: 1
- <: 3
- after: 12
- context: 5
- B: 6
- before: 1
- C: 58
- all: 5
- break: 5
- color: 15
- colour: 2
- match: 11
- lineno: 2
- column: 2
- follow: 2
- G: 3
- group: 2
- heading: 7
- h: 2
- H: 2
- ignore: 4
- case: 6
- invert: 3
- lines: 2
- without: 2
- m: 4
- max: 7
- count: 9
- recurse: 3
- output: 7
- pager: 5
- nopager: 1
- passthru: 3
- print0: 3
- Q: 2
- literal: 1
- show: 3
- smart: 1
- sort: 2
- u: 5
- unrestricted: 2
- w: 1
- word: 1
- regexp: 1
- dirs: 4
- noignore: 1
- version: 3
- man: 3
- bundling: 1
- no_ignore_case: 2
- See: 4
- options.: 2
- must: 2
- greater: 1
- than: 3
- zero: 1
- All: 4
- options: 1
- are: 10
- invalid.: 1
- pass_through: 1
- no_auto_abbrev: 1
- set: 6
- c: 3
- add: 3
- redefine: 1
- qq: 6
- ! '{-': 3
- -}: 3
- Builtin: 2
- cannot: 2
- changed.: 2
- delete_type: 3
- Type: 1
- does: 1
- exist: 2
- creating: 1
- unless: 18
- ! '@exts': 4
- split: 3
- s/: 10
- .//: 1
- ! '||': 18
- e: 7
- Cannot: 2
- append: 1
- head2: 16
- Removes: 1
- internal: 1
- structures: 1
- containing: 5
- information: 1
- type_wanted.: 1
- Internal: 1
- ignoredir_filter: 3
- Standard: 1
- filter: 6
- pass: 2
- <File::Next>: 1
- descend_filter.: 1
- It: 3
- returns: 8
- 'true': 4
- any: 1
- ones: 1
- we: 4
- know: 1
- ignore.: 1
- remove_dir_sep: 2
- path: 16
- This: 7
- removes: 1
- trailing: 1
- separator: 2
- there: 1
- its: 1
- argument: 1
- //: 3
- filetypes: 4
- Returns: 27
- list: 3
- <$filename>: 1
- could: 2
- be.: 1
- For: 1
- example: 1
- F: 2
- <foo.pod>: 1
- filetype: 1
- will: 3
- <undef>: 1
- skipped: 2
- something: 1
- should: 3
- avoid: 1
- searching: 2
- even: 3
- under: 3
- a.: 1
- constant: 1
- TEXT: 8
- basename: 4
- .*: 1
- is_searchable: 4
- lc_basename: 4
- lc: 2
- o: 11
- open: 2
- header: 11
- <$fh>: 1
- ruby: 1
- lua: 1
- erl: 1
- hp: 1
- ython: 1
- d: 6
- d.: 1
- b/: 2
- ba: 1
- k: 3
- z: 1
- sh: 1
- /i: 2
- 'false': 2
- regular: 1
- expression: 4
- found.: 2
- www: 1
- U: 1
- tr/: 1
- x: 4
- w/: 1
- nOo_/: 1
- _get_thpppt: 1
- print: 16
- <<: 7
- ! '*I': 1
- ! '#.': 3
- I#: 1
- ! '#7': 2
- results.: 1
- when: 6
- used: 4
- interactively: 3
- Print: 1
- between: 1
- results: 6
- different: 1
- files.: 2
- Same: 4
- nogroup: 1
- noheading: 1
- nobreak: 1
- Highlight: 1
- matching: 5
- text: 2
- redirected: 1
- Windows: 1
- COLOR: 3
- Set: 1
- filenames: 1
- numbers.: 1
- Flush: 1
- immediately: 1
- non: 1
- goes: 1
- pipe: 2
- finding: 1
- Only: 1
- found: 3
- searching.: 1
- PATTERN: 1
- specified.: 1
- REGEX: 1
- but: 5
- REGEX.: 1
- Sort: 1
- lexically.: 1
- Print/search: 1
- handle: 1
- do: 5
- g/: 1
- G.: 1
- Show: 1
- which: 7
- has.: 1
- inclusion/exclusion: 1
- searched: 2
- Ignores: 1
- .svn: 1
- other: 2
- ignored: 2
- directories: 3
- name: 15
- Add/Remove: 1
- Recurse: 1
- into: 1
- subdirectories: 1
- once: 1
- VMS: 1
- vd: 1
- Term: 3
- ANSIColor: 4
- printing: 1
- qr/: 6
- last_output_line: 3
- any_output: 5
- before_context: 5
- after_context: 4
- keep_context: 4
- ! '@before': 8
- before_starts_at_line: 5
- res: 13
- next_text: 3
- has_lines: 2
- m/: 2
- regex/: 4
- next: 3
- print_match_or_context: 5
- elsif: 4
- nmatches: 21
- context_overall_output_count: 3
- print_blank_line: 1
- ! '@lines': 2
- is_binary: 1
- is_match: 4
- starting_line_no: 1
- match_start: 3
- match_end: 2
- Prints: 3
- out: 1
- around: 1
- match.: 1
- line_no: 6
- show_column: 2
- display_filename: 4
- colored: 3
- ACK_COLOR_FILENAME: 1
- print_first_filename: 1
- sep: 4
- output_func: 4
- ! '@_': 25
- print_separator: 1
- print_filename: 1
- display_line_no: 2
- ACK_COLOR_LINENO: 1
- print_line_no: 1
- regex/go: 1
- regex/Term: 1
- substr: 1
- ACK_COLOR_MATCH: 1
- /eg: 1
- z/: 1
- K/: 1
- z//: 1
- print_column_no: 1
- TOTAL_COUNT_SCOPE: 1
- total_count: 4
- get_total_count: 1
- reset_total_count: 2
- search_and_list: 3
- Optimized: 1
- lines.: 1
- ors: 6
- show_total: 3
- print_count: 2
- print_count0: 1
- filetypes_supported_set: 2
- True/False: 1
- filetypes_supported: 1
- print_files: 2
- iter: 8
- returned: 1
- iterator: 2
- <$regex>: 1
- If: 1
- <$one>: 1
- stop: 1
- first.: 1
- record: 1
- <$ors>: 1
- defaults: 2
- <"\n">: 1
- defines: 1
- filename.: 1
- show_types: 1
- join: 1
- print_files_with_matches: 2
- where: 5
- repo: 3
- Not: 1
- working: 1
- yet: 1
- thru: 1
- unchanged: 1
- ! '@results': 5
- eval: 3
- Win32: 3
- HIDDEN: 1
- SYSTEM: 1
- GetAttributes: 1
- attr: 2
- ! '@files': 2
- get_starting_points: 2
- reference: 14
- starting: 1
- argv: 4
- ! '@what': 7
- expand_filenames: 1
- reslash: 1
- _match: 4
- target: 3
- invert_flag: 2
- get_iterator: 2
- Return: 1
- starting_point: 5
- map: 5
- g_regex: 2
- undef: 2
- file_filter: 5
- g_regex/: 3
- invert_file_match: 3
- is_interesting: 2
- descend_filter: 3
- error_handler: 1
- msg: 2
- sort_files: 2
- follow_symlinks: 1
- set_up_pager: 1
- Unable: 1
- going: 1
- pipe.: 1
- exit_from_ack: 2
- Exit: 1
- application: 6
- correct: 1
- code.: 1
- otherwise: 1
- number: 1
- handed: 1
- argument.: 1
- rc: 5
- LICENSE: 2
- Copyright: 1
- Andy: 1
- Lester.: 1
- free: 2
- software: 2
- redistribute: 2
- and/or: 2
- modify: 2
- terms: 2
- Artistic: 1
- License: 1
- v2.0.: 1
- examples/benchmarks/fib.pl: 1
- Fibonacci: 2
- Benchmark: 1
- SYNOPSIS: 1
- DESCRIPTION: 1
- Calculates: 1
- Number: 1
- <n>: 1
- unspecified: 1
- fib: 4
- N: 2
- SEE: 3
- ALSO: 3
- <examples/benchmarks/fib.pir>: 1
- ..: 3
- Foo: 9
- Bar: 1
- ! '@array': 1
- hash: 12
- Plack: 7
- Request: 4
- .008_001: 1
- HTTP: 8
- Headers: 6
- Carp: 6
- Hash: 4
- MultiValue: 4
- Body: 1
- Upload: 1
- TempBuffer: 1
- URI: 15
- Escape: 4
- _deprecated: 8
- alt: 1
- method: 9
- caller: 1
- carp: 2
- croak: 2
- required: 2
- address: 5
- REMOTE_ADDR: 1
- remote_host: 3
- REMOTE_HOST: 1
- protocol: 3
- SERVER_PROTOCOL: 1
- REQUEST_METHOD: 1
- port: 1
- SERVER_PORT: 1
- user: 3
- REMOTE_USER: 1
- request_uri: 2
- REQUEST_URI: 2
- path_info: 3
- PATH_INFO: 3
- script_name: 2
- SCRIPT_NAME: 1
- scheme: 5
- secure: 4
- body: 18
- input: 5
- content_length: 3
- CONTENT_LENGTH: 1
- content_type: 3
- CONTENT_TYPE: 1
- session: 3
- session_options: 2
- logger: 4
- cookies: 8
- HTTP_COOKIE: 3
- ! '@pairs': 2
- pair: 4
- key: 10
- value: 5
- uri_unescape: 1
- query_parameters: 5
- uri: 3
- query_form: 1
- content: 7
- _parse_request_body: 3
- written: 1
- through: 2
- headers: 35
- field: 5
- HTTPS: 1
- _//: 1
- CONTENT: 1
- COOKIE: 1
- content_encoding: 4
- referer: 2
- user_agent: 2
- body_parameters: 4
- parameters: 8
- query: 4
- flatten: 2
- uploads: 4
- hostname: 1
- url_scheme: 1
- params: 2
- query_params: 1
- body_params: 1
- cookie: 5
- param: 1
- wantarray: 2
- get_all: 3
- upload: 1
- raw_uri: 1
- base: 11
- path_query: 1
- _uri_base: 1
- path_escape_class: 1
- uri_escape: 1
- psgi.url_scheme: 1
- plack.request.body: 2
- plack.request.upload: 2
- plack.request.http.body: 1
- psgix.input.buffered: 2
- psgi.input: 1
- like: 3
- doing: 1
- so: 4
- mod_perl: 1
- re: 2
- writing: 2
- web: 1
- framework: 1
- then: 1
- work: 2
- expect: 2
- to.: 1
- Creates: 1
- request: 9
- object.: 5
- ATTRIBUTES: 1
- over: 1
- item: 24
- shared: 1
- PSGI: 3
- environment: 4
- reference.: 3
- passes: 1
- during: 1
- whole: 1
- request/response: 1
- cycle.: 1
- IP: 2
- client: 1
- <REMOTE_ADDR>: 1
- remote: 1
- host: 1
- <REMOTE_HOST>: 1
- client.: 1
- empty: 2
- have: 3
- get: 6
- <address>: 1
- resolve: 1
- own.: 1
- Contains: 1
- <GET>: 1
- <POST>: 1
- <HEAD>: 1
- etc: 1
- HTTP/1.0: 1
- HTTP/1.1: 1
- current: 3
- request.: 4
- raw: 1
- undecoded: 2
- path.: 3
- You: 4
- probably: 1
- <NOT>: 1
- dispatch: 1
- requests.: 3
- <PATH_INFO>: 2
- environment.: 2
- Use: 1
- local: 1
- Similar: 1
- <path_info>: 3
- </>: 3
- empty.: 1
- In: 2
- words: 1
- virtual: 1
- req: 11
- </"DISPATCHING">: 1
- details.: 1
- <SCRIPT_NAME>: 3
- absolute: 2
- hosted.: 1
- <http>: 1
- <https>: 1
- indicating: 1
- whether: 1
- connection: 1
- https: 1
- <psgi.input>: 1
- handle.: 1
- optional: 3
- <psgix.session>: 1
- hash.: 3
- When: 2
- retrieve: 1
- store: 1
- per: 1
- data: 1
- <psgix.session.options>: 1
- <psgix.logger>: 1
- code: 9
- supposed: 1
- send: 1
- log: 1
- message: 2
- level: 1
- cookies.: 1
- Values: 1
- strings: 1
- sent: 1
- clients: 1
- decoded.: 1
- string: 4
- GET: 2
- parameters.: 2
- <Hash::MultiValue>: 5
- posted: 1
- POST: 4
- As: 1
- <query_parameters>: 2
- merged: 1
- raw_body: 1
- an: 7
- byte: 1
- object: 2
- constructed: 1
- various: 1
- values: 3
- <QUERY_STRING>: 1
- <HTTP_HOST>: 1
- <SERVER_NAME>: 1
- <SERVER_PORT>: 1
- Every: 2
- time: 3
- called: 2
- cloned: 2
- <uri>: 1
- contains: 2
- up: 2
- hosted: 1
- at.: 1
- <REMOTE_USER>: 1
- need: 1
- ugly: 1
- unsafe: 1
- anymore.: 1
- And: 1
- explicitly: 1
- multiple: 3
- same: 2
- call: 4
- <get_all>: 1
- ! '@foo': 1
- also: 2
- <get_one>: 1
- always: 4
- parameter: 2
- independent: 1
- unlike: 1
- <param>: 1
- <mixed>: 1
- '.05': 1
- later: 1
- <traditional>: 1
- mixed: 1
- either: 1
- scalar: 1
- array: 4
- depending: 2
- might: 2
- useful: 1
- already: 1
- deal: 1
- ugliness.: 1
- PARSING: 1
- BODY: 1
- MULTIPLE: 1
- OBJECTS: 1
- methods: 5
- parse: 1
- <content>: 1
- <body_parameters>: 2
- <uploads>: 2
- carefully: 1
- coded: 1
- save: 1
- parsed: 1
- well: 1
- temporary: 1
- buffer: 1
- them: 2
- times: 2
- create: 1
- objects: 3
- they: 1
- safely: 1
- won: 1
- gives: 1
- action: 1
- Note: 1
- give: 1
- assume: 1
- prefix: 1
- building: 1
- URLs: 1
- templates: 1
- redirections.: 1
- /logout: 1
- ll: 1
- full: 1
- </app/logout?signoff=1>: 1
- INCOMPATIBILITIES: 1
- '.99': 1
- many: 1
- utility: 1
- removed: 2
- deprecated: 2
- most: 1
- made: 1
- read: 1
- only.: 1
- following: 1
- <hostname>: 1
- <url_scheme>: 1
- <params>: 1
- <query_params>: 1
- <body_params>: 1
- <cookie>: 1
- <raw_uri>: 1
- They: 1
- release.: 1
- related: 1
- <parameters>: 1
- now: 3
- rather: 2
- <scalar>: 1
- insecure.: 1
- more: 1
- about: 1
- change.: 1
- had: 1
- bug: 1
- document: 2
- mismatching.: 1
- suggesting: 1
- returning: 1
- updated: 1
- alias: 1
- <CGI::Simple::Cookie>: 1
- anymore: 1
- means: 2
- <CAN>: 1
- NOT: 1
- serialized.: 1
- encoding: 1
- decoding: 1
- totally: 1
- framework.: 1
- Also: 1
- <cookies>: 1
- <strings>: 1
- CGI: 1
- Simple: 1
- Cookie: 1
- longer: 1
- write: 1
- wacky: 1
- instead: 1
- simply: 1
- AUTHORS: 1
- Tatsuhiko: 2
- Miyagawa: 2
- Kazuhiro: 1
- Osawa: 1
- Tokuhiro: 2
- Matsuno: 2
- <Plack::Response>: 1
- <HTTP::Request>: 1
- <Catalyst::Request>: 1
- library: 1
- itself.: 1
- Response: 1
- Util: 3
- Accessor: 1
- status: 9
- Scalar: 2
- location: 3
- redirect: 1
- url: 2
- finalize: 3
- clone: 1
- _finalize_cookies: 1
- /chr: 1
- /ge: 1
- //g: 1
- header_field_names: 1
- _body: 2
- blessed: 1
- overload: 1
- Method: 1
- domain: 2
- expires: 2
- HttpOnly: 1
- GMT: 1
- Hello: 2
- World: 2
- response: 2
- back: 1
- AUTHOR: 1
- <Plack::Request>: 1
- /usr/local/bin/perl: 1
- /usr/bin/perl: 1
+ MESSAGE: 1
PHP:
<: 5
php: 6
@@ -14886,175 +13760,18 @@ tokens:
_afterScaffoldSaveError: 1
scaffoldError: 2
_scaffoldError: 1
- php_help: 1
- path: 3
- arg: 1
- <h3>: 2
- About: 1
- </h3>: 2
- <p>: 1
- PHP: 19
- filter: 8
- module: 3
- adds: 2
- your: 3
- site: 3
- <a>: 4
- href=: 4
- text: 5
- formats: 1
- </a>: 4
- ability: 1
- field: 78
- format: 5
- content: 1
- comment: 1
- general: 1
- purpose: 1
- scripting: 1
- language: 2
- widely: 1
- web: 1
- development: 1
- which: 2
- Drupal: 1
- been: 1
- developed.: 1
- information: 1
- see: 1
- online: 1
- handbook: 1
- entry: 1
- ! '@filter': 1
- admin/help/filter: 1
- ! '@php': 3
- net: 1
- //www.php.net: 1
- //drupal.org/handbook/modules/php/: 1
- </p>: 1
- Uses: 1
- <dl>: 1
- <dt>: 1
- Enabling: 1
- execution: 1
- fields: 65
- </dt>: 1
- <dd>: 1
- users: 2
- proper: 1
- permissions: 1
- include: 1
- custom: 1
- executed: 1
- pages: 1
- processed.: 1
- While: 1
- powerful: 1
- flexible: 1
- feature: 1
- trusted: 3
- user: 2
- experience: 1
- it: 3
- significant: 1
- dangerous: 1
- security: 1
- risk: 1
- hands: 1
- malicious: 1
- inexperienced: 1
- user.: 1
- Even: 1
- may: 1
- accidentally: 1
- compromise: 1
- entering: 1
- malformed: 1
- incorrect: 1
- code.: 2
- Only: 1
- most: 1
- granted: 1
- permission: 1
- added: 1
- through: 1
- carefully: 1
- examined: 1
- use.: 1
- Example: 1
- snippets: 3
- found: 2
- Drupal.org.: 1
- //drupal.org/handbook/customization/php: 1
- </dd>: 1
- </dl>: 1
- settings: 2
- title: 1
- Use: 1
- restrict: 1
- eval: 4
- It: 1
- buffering: 1
- capture: 1
- both: 1
- returned: 2
- printed: 2
- text.: 1
- Unlike: 1
- we: 2
- require: 1
- surrounded: 1
- tags: 1
- other: 2
- words: 1
- evaluate: 1
- stand: 1
- alone: 1
- file.: 1
- Using: 1
- wrapper: 1
- also: 1
- ensures: 1
- evaluated: 1
- overwrite: 1
- calling: 1
- unlike: 1
- regular: 1
- call.: 1
- evaluate.: 1
- containing: 1
- followed: 1
- ! '@ingroup': 1
- php_wrappers: 1
- php_eval: 1
- global: 2
- theme_path: 5
- theme_info: 3
- conf: 2
- old_theme_path: 2
- drupal_get_path: 1
- dirname: 1
- filename: 1
- ob_start: 1
- print: 1
- ob_get_contents: 1
- ob_end_clean: 1
- _php_filter_tips: 1
- long: 2
- 'FALSE': 2
- base_url: 1
- php_filter_info: 1
- filters: 2
Field: 3
FormField: 1
ArrayAccess: 1
button: 4
+ fields: 65
DOMNode: 2
node: 4
initialize: 1
getFormNode: 1
setValues: 1
getValues: 2
+ field: 78
isDisabled: 2
FileFormField: 2
hasValue: 1
@@ -15087,6 +13804,7 @@ tokens:
extra: 1
segment: 1
Malformed: 1
+ path: 3
relational: 2
mapper: 2
DBO: 2
@@ -15094,6 +13812,7 @@ tokens:
mapping: 1
database: 4
tables: 1
+ PHP: 19
versions: 1
'5': 1
'10': 1
@@ -15182,13 +13901,17 @@ tokens:
joinTable: 2
listSources: 1
strtolower: 8
+ found: 2
+ it: 3
sets: 1
+ other: 2
than: 1
copied: 1
property: 1
object.: 1
Returns: 1
//book.cakephp.org/2.0/en/models/saving: 1
+ your: 3
data.html: 1
is_object: 3
SimpleXMLElement: 1
@@ -15214,6 +13937,7 @@ tokens:
hour: 1
min: 1
sec: 1
+ format: 5
m: 3
H: 1
describe: 1
@@ -15373,6 +14097,164 @@ tokens:
//Will: 1
cache: 1
deleting: 1
+ php_help: 1
+ arg: 1
+ <h3>: 2
+ About: 1
+ </h3>: 2
+ <p>: 1
+ filter: 8
+ module: 3
+ adds: 2
+ site: 3
+ <a>: 4
+ href=: 4
+ text: 5
+ formats: 1
+ </a>: 4
+ ability: 1
+ content: 1
+ comment: 1
+ general: 1
+ purpose: 1
+ scripting: 1
+ language: 2
+ widely: 1
+ web: 1
+ development: 1
+ which: 2
+ Drupal: 1
+ been: 1
+ developed.: 1
+ information: 1
+ see: 1
+ online: 1
+ handbook: 1
+ entry: 1
+ ! '@filter': 1
+ admin/help/filter: 1
+ ! '@php': 3
+ net: 1
+ //www.php.net: 1
+ //drupal.org/handbook/modules/php/: 1
+ </p>: 1
+ Uses: 1
+ <dl>: 1
+ <dt>: 1
+ Enabling: 1
+ execution: 1
+ </dt>: 1
+ <dd>: 1
+ users: 2
+ proper: 1
+ permissions: 1
+ include: 1
+ custom: 1
+ executed: 1
+ pages: 1
+ processed.: 1
+ While: 1
+ powerful: 1
+ flexible: 1
+ feature: 1
+ trusted: 3
+ user: 2
+ experience: 1
+ significant: 1
+ dangerous: 1
+ security: 1
+ risk: 1
+ hands: 1
+ malicious: 1
+ inexperienced: 1
+ user.: 1
+ Even: 1
+ may: 1
+ accidentally: 1
+ compromise: 1
+ entering: 1
+ malformed: 1
+ incorrect: 1
+ code.: 2
+ Only: 1
+ most: 1
+ granted: 1
+ permission: 1
+ added: 1
+ through: 1
+ carefully: 1
+ examined: 1
+ use.: 1
+ Example: 1
+ snippets: 3
+ Drupal.org.: 1
+ //drupal.org/handbook/customization/php: 1
+ </dd>: 1
+ </dl>: 1
+ settings: 2
+ title: 1
+ Use: 1
+ restrict: 1
+ eval: 4
+ It: 1
+ buffering: 1
+ capture: 1
+ both: 1
+ returned: 2
+ printed: 2
+ text.: 1
+ Unlike: 1
+ we: 2
+ require: 1
+ surrounded: 1
+ tags: 1
+ words: 1
+ evaluate: 1
+ stand: 1
+ alone: 1
+ file.: 1
+ Using: 1
+ wrapper: 1
+ also: 1
+ ensures: 1
+ evaluated: 1
+ overwrite: 1
+ calling: 1
+ unlike: 1
+ regular: 1
+ call.: 1
+ evaluate.: 1
+ containing: 1
+ followed: 1
+ ! '@ingroup': 1
+ php_wrappers: 1
+ php_eval: 1
+ global: 2
+ theme_path: 5
+ theme_info: 3
+ conf: 2
+ old_theme_path: 2
+ drupal_get_path: 1
+ dirname: 1
+ filename: 1
+ ob_start: 1
+ print: 1
+ ob_get_contents: 1
+ ob_end_clean: 1
+ _php_filter_tips: 1
+ long: 2
+ 'FALSE': 2
+ base_url: 1
+ php_filter_info: 1
+ filters: 2
+ Parrot Assembly:
+ ! '#': 1
+ /usr/bin/env: 1
+ parrot: 1
+ .pcc_sub: 1
+ main: 2
+ say: 1
+ end: 1
Parrot Internal Representation:
! '#': 1
/usr/bin/env: 1
@@ -15381,6 +14263,1124 @@ tokens:
main: 1
say: 1
.end: 1
+ Perl:
+ package: 7
+ App: 46
+ Ack: 46
+ ;: 446
+ use: 47
+ warnings: 10
+ strict: 10
+ File: 20
+ Next: 12
+ '.40': 1
+ Plugin: 1
+ Basic: 4
+ head1: 14
+ NAME: 2
+ ! '-': 436
+ A: 2
+ container: 1
+ for: 31
+ functions: 2
+ the: 77
+ ack: 16
+ program: 2
+ VERSION: 12
+ Version: 1
+ '.94': 1
+ cut: 19
+ our: 16
+ COPYRIGHT: 3
+ BEGIN: 3
+ ! '{': 376
+ ! '}': 385
+ fh: 7
+ ! '*STDOUT': 2
+ ! '%': 44
+ types: 21
+ type_wanted: 4
+ mappings: 13
+ ignore_dirs: 4
+ input_from_pipe: 4
+ output_to_pipe: 5
+ dir_sep_chars: 5
+ is_cygwin: 3
+ is_windows: 4
+ Spec: 2
+ (: 328
+ ): 322
+ Glob: 1
+ Getopt: 1
+ Long: 1
+ _MTN: 1
+ blib: 1
+ CVS: 2
+ RCS: 1
+ SCCS: 1
+ _darcs: 1
+ _sgbak: 1
+ _build: 1
+ actionscript: 1
+ qw: 15
+ as: 18
+ mxml: 1
+ ada: 2
+ adb: 1
+ ads: 1
+ asm: 2
+ s: 32
+ batch: 1
+ bat: 1
+ cmd: 1
+ binary: 2
+ q: 3
+ Binary: 2
+ files: 15
+ defined: 17
+ by: 3
+ Perl: 2
+ T: 1
+ op: 1
+ default: 4
+ 'off': 1
+ tt: 2
+ tt2: 1
+ ttml: 1
+ vb: 2
+ bas: 1
+ cls: 1
+ frm: 1
+ ctl: 1
+ resx: 1
+ verilog: 1
+ v: 10
+ vh: 1
+ sv: 1
+ vhdl: 2
+ vhd: 1
+ vim: 2
+ yaml: 2
+ yml: 1
+ xml: 3
+ dtd: 1
+ xsl: 1
+ xslt: 1
+ ent: 1
+ while: 8
+ my: 142
+ type: 35
+ exts: 3
+ each: 3
+ if: 96
+ ref: 19
+ ext: 7
+ ! '@': 15
+ push: 6
+ ! '#': 142
+ _: 56
+ mk: 1
+ mak: 1
+ not: 13
+ t: 12
+ p: 3
+ STDIN: 1
+ O: 2
+ eq: 13
+ /MSWin32/: 1
+ quotemeta: 2
+ catfile: 1
+ .ackrc: 1
+ _ackrc: 1
+ <: 3
+ ! '|': 32
+ after: 12
+ context: 5
+ i: 10
+ B: 6
+ before: 1
+ C: 58
+ a: 41
+ all: 5
+ break: 5
+ color: 15
+ colour: 2
+ match: 11
+ filename: 30
+ lineno: 2
+ column: 2
+ env: 54
+ follow: 2
+ g: 4
+ G: 3
+ group: 2
+ heading: 7
+ h: 2
+ 'no': 10
+ H: 2
+ with: 12
+ ignore: 4
+ case: 6
+ invert: 3
+ file: 13
+ lines: 2
+ l: 5
+ matches: 5
+ L: 14
+ without: 2
+ m: 4
+ max: 7
+ count: 9
+ n: 26
+ recurse: 3
+ ! '&': 12
+ output: 7
+ pager: 5
+ nopager: 1
+ passthru: 3
+ print0: 3
+ Q: 2
+ literal: 1
+ r: 7
+ R: 3
+ show: 3
+ smart: 1
+ sort: 2
+ u: 5
+ unrestricted: 2
+ w: 1
+ word: 1
+ regexp: 1
+ dirs: 4
+ noignore: 1
+ version: 3
+ help: 6
+ man: 3
+ bundling: 1
+ no_ignore_case: 2
+ See: 4
+ or: 23
+ options.: 2
+ must: 2
+ be: 12
+ greater: 1
+ than: 3
+ zero: 1
+ All: 4
+ line: 7
+ options: 1
+ are: 10
+ invalid.: 1
+ pass_through: 1
+ no_auto_abbrev: 1
+ set: 6
+ c: 3
+ add: 3
+ redefine: 1
+ and: 36
+ die: 7
+ qq: 6
+ ! '{-': 3
+ -}: 3
+ Builtin: 2
+ cannot: 2
+ changed.: 2
+ ne: 5
+ delete_type: 3
+ else: 18
+ exists: 9
+ ! '&&': 30
+ warn: 7
+ Type: 1
+ does: 1
+ exist: 2
+ creating: 1
+ ! '...': 3
+ unless: 18
+ ! '@exts': 4
+ split: 3
+ /: 28
+ s/: 10
+ .//: 1
+ ! '||': 18
+ e: 7
+ Cannot: 2
+ append: 1
+ to: 42
+ .: 54
+ return: 60
+ head2: 16
+ Removes: 1
+ from: 7
+ internal: 1
+ structures: 1
+ containing: 5
+ information: 1
+ type_wanted.: 1
+ sub: 94
+ shift: 74
+ Internal: 1
+ error: 2
+ delete: 4
+ builtin: 2
+ keys: 6
+ grep: 8
+ ignoredir_filter: 3
+ Standard: 1
+ filter: 6
+ pass: 2
+ <File::Next>: 1
+ descend_filter.: 1
+ It: 3
+ returns: 8
+ 'true': 4
+ directory: 3
+ is: 29
+ any: 1
+ of: 19
+ ones: 1
+ we: 4
+ know: 1
+ want: 5
+ ignore.: 1
+ dir: 3
+ remove_dir_sep: 2
+ path: 16
+ This: 7
+ removes: 1
+ trailing: 1
+ separator: 2
+ there: 1
+ one: 5
+ its: 1
+ argument: 1
+ //: 3
+ filetypes: 4
+ Returns: 27
+ list: 3
+ that: 10
+ I: 35
+ <$filename>: 1
+ could: 2
+ be.: 1
+ For: 1
+ example: 1
+ F: 2
+ <foo.pod>: 1
+ The: 10
+ filetype: 1
+ will: 3
+ <undef>: 1
+ can: 10
+ it: 21
+ skipped: 2
+ something: 1
+ should: 3
+ avoid: 1
+ searching: 2
+ even: 3
+ under: 3
+ a.: 1
+ constant: 1
+ TEXT: 8
+ basename: 4
+ .*: 1
+ is_searchable: 4
+ lc_basename: 4
+ lc: 2
+ +: 92
+ o: 11
+ open: 2
+ header: 11
+ <$fh>: 1
+ close: 4
+ b: 4
+ ruby: 1
+ lua: 1
+ erl: 1
+ hp: 1
+ ython: 1
+ d: 6
+ d.: 1
+ ! '*': 8
+ b/: 2
+ ba: 1
+ k: 3
+ z: 1
+ sh: 1
+ /i: 2
+ search: 2
+ 'false': 2
+ 'No': 2
+ regular: 1
+ expression: 4
+ found.: 2
+ regex: 13
+ www: 1
+ U: 1
+ y: 5
+ tr/: 1
+ x: 4
+ w/: 1
+ nOo_/: 1
+ _thpppt: 2
+ _get_thpppt: 1
+ print: 16
+ exit: 4
+ _bar: 2
+ <<: 7
+ ! '*I': 1
+ ! '#.': 3
+ .#: 3
+ I#: 1
+ ! '#I': 5
+ ! '#7': 2
+ results.: 1
+ 'on': 9
+ when: 6
+ used: 4
+ interactively: 3
+ Print: 1
+ between: 1
+ results: 6
+ different: 1
+ files.: 2
+ Same: 4
+ nogroup: 1
+ noheading: 1
+ nobreak: 1
+ Highlight: 1
+ matching: 5
+ text: 2
+ redirected: 1
+ Windows: 1
+ COLOR: 3
+ Set: 1
+ filenames: 1
+ numbers.: 1
+ flush: 2
+ Flush: 1
+ immediately: 1
+ non: 1
+ goes: 1
+ pipe: 2
+ finding: 1
+ f: 5
+ Only: 1
+ found: 3
+ searching.: 1
+ PATTERN: 1
+ specified.: 1
+ REGEX: 1
+ but: 5
+ only: 4
+ REGEX.: 1
+ Sort: 1
+ lexically.: 1
+ Print/search: 1
+ handle: 1
+ do: 5
+ g/: 1
+ G.: 1
+ Show: 1
+ which: 7
+ has.: 1
+ inclusion/exclusion: 1
+ searched: 2
+ Ignores: 1
+ .svn: 1
+ other: 2
+ ignored: 2
+ directories: 3
+ name: 15
+ Add/Remove: 1
+ Recurse: 1
+ into: 1
+ subdirectories: 1
+ END_OF_HELP: 2
+ once: 1
+ VMS: 1
+ vd: 1
+ Term: 3
+ ANSIColor: 4
+ black: 2
+ on_yellow: 2
+ bold: 4
+ green: 2
+ yellow: 2
+ printing: 1
+ qr/: 6
+ opt: 69
+ last_output_line: 3
+ any_output: 5
+ before_context: 5
+ after_context: 4
+ keep_context: 4
+ ! '@before': 8
+ before_starts_at_line: 5
+ res: 13
+ next_text: 3
+ has_lines: 2
+ m/: 2
+ regex/: 4
+ next: 3
+ print_match_or_context: 5
+ elsif: 4
+ last: 7
+ nmatches: 21
+ show_filename: 16
+ context_overall_output_count: 3
+ print_blank_line: 1
+ ! '@lines': 2
+ is_binary: 1
+ is_match: 4
+ starting_line_no: 1
+ match_start: 3
+ match_end: 2
+ Prints: 3
+ out: 1
+ around: 1
+ match.: 1
+ line_no: 6
+ show_column: 2
+ display_filename: 4
+ colored: 3
+ ENV: 5
+ ACK_COLOR_FILENAME: 1
+ print_first_filename: 1
+ sep: 4
+ output_func: 4
+ ! '@_': 25
+ print_separator: 1
+ print_filename: 1
+ display_line_no: 2
+ ACK_COLOR_LINENO: 1
+ print_line_no: 1
+ regex/go: 1
+ regex/Term: 1
+ substr: 1
+ ACK_COLOR_MATCH: 1
+ /eg: 1
+ z/: 1
+ K/: 1
+ z//: 1
+ print_column_no: 1
+ TOTAL_COUNT_SCOPE: 1
+ total_count: 4
+ get_total_count: 1
+ reset_total_count: 2
+ search_and_list: 3
+ Optimized: 1
+ lines.: 1
+ ors: 6
+ show_total: 3
+ print_count: 2
+ print_count0: 1
+ filetypes_supported_set: 2
+ True/False: 1
+ filetypes_supported: 1
+ print_files: 2
+ iter: 8
+ returned: 1
+ iterator: 2
+ <$regex>: 1
+ If: 1
+ <$one>: 1
+ stop: 1
+ first.: 1
+ record: 1
+ <$ors>: 1
+ defaults: 2
+ <"\n">: 1
+ defines: 1
+ what: 6
+ filename.: 1
+ show_types: 1
+ join: 1
+ print_files_with_matches: 2
+ where: 5
+ was: 6
+ repo: 3
+ Repository: 3
+ new: 24
+ next_resource: 2
+ Not: 1
+ working: 1
+ here: 2
+ yet: 1
+ thru: 1
+ unchanged: 1
+ ! '@results': 5
+ pattern: 2
+ eval: 3
+ Win32: 3
+ HIDDEN: 1
+ SYSTEM: 1
+ GetAttributes: 1
+ attr: 2
+ ! '@files': 2
+ get_starting_points: 2
+ ! '@ARGV': 6
+ reference: 14
+ starting: 1
+ argv: 4
+ ! '@what': 7
+ expand_filenames: 1
+ reslash: 1
+ start_point: 3
+ _match: 4
+ target: 3
+ invert_flag: 2
+ get_iterator: 2
+ Return: 1
+ starting_point: 5
+ map: 5
+ g_regex: 2
+ undef: 2
+ file_filter: 5
+ g_regex/: 3
+ invert_file_match: 3
+ is_interesting: 2
+ descend_filter: 3
+ error_handler: 1
+ msg: 2
+ sort_files: 2
+ follow_symlinks: 1
+ set_up_pager: 1
+ command: 4
+ Unable: 1
+ going: 1
+ pipe.: 1
+ exit_from_ack: 2
+ Exit: 1
+ application: 6
+ correct: 1
+ code.: 1
+ otherwise: 1
+ number: 1
+ handed: 1
+ in: 18
+ argument.: 1
+ rc: 5
+ LICENSE: 2
+ Copyright: 1
+ Andy: 1
+ Lester.: 1
+ free: 2
+ software: 2
+ you: 17
+ redistribute: 2
+ and/or: 2
+ modify: 2
+ terms: 2
+ Artistic: 1
+ License: 1
+ v2.0.: 1
+ Plack: 7
+ Request: 4
+ .008_001: 1
+ HTTP: 8
+ Headers: 6
+ Carp: 6
+ Hash: 4
+ MultiValue: 4
+ Body: 1
+ Upload: 1
+ TempBuffer: 1
+ URI: 15
+ Escape: 4
+ _deprecated: 8
+ alt: 1
+ method: 9
+ caller: 1
+ carp: 2
+ class: 6
+ croak: 2
+ required: 2
+ bless: 6
+ address: 5
+ REMOTE_ADDR: 1
+ remote_host: 3
+ REMOTE_HOST: 1
+ protocol: 3
+ SERVER_PROTOCOL: 1
+ REQUEST_METHOD: 1
+ port: 1
+ SERVER_PORT: 1
+ user: 3
+ REMOTE_USER: 1
+ request_uri: 2
+ REQUEST_URI: 2
+ path_info: 3
+ PATH_INFO: 3
+ script_name: 2
+ SCRIPT_NAME: 1
+ scheme: 5
+ secure: 4
+ body: 18
+ input: 5
+ content_length: 3
+ CONTENT_LENGTH: 1
+ content_type: 3
+ CONTENT_TYPE: 1
+ session: 3
+ session_options: 2
+ logger: 4
+ cookies: 8
+ self: 92
+ HTTP_COOKIE: 3
+ ! '@pairs': 2
+ pair: 4
+ key: 10
+ value: 5
+ uri_unescape: 1
+ query_parameters: 5
+ uri: 3
+ query_form: 1
+ content: 7
+ _parse_request_body: 3
+ written: 1
+ through: 2
+ headers: 35
+ field: 5
+ HTTPS: 1
+ _//: 1
+ CONTENT: 1
+ COOKIE: 1
+ content_encoding: 4
+ referer: 2
+ user_agent: 2
+ body_parameters: 4
+ parameters: 8
+ query: 4
+ flatten: 2
+ uploads: 4
+ hostname: 1
+ url_scheme: 1
+ params: 2
+ query_params: 1
+ body_params: 1
+ cookie: 5
+ param: 1
+ wantarray: 2
+ get_all: 3
+ upload: 1
+ raw_uri: 1
+ base: 11
+ path_query: 1
+ _uri_base: 1
+ path_escape_class: 1
+ uri_escape: 1
+ psgi.url_scheme: 1
+ plack.request.body: 2
+ plack.request.upload: 2
+ plack.request.http.body: 1
+ psgix.input.buffered: 2
+ psgi.input: 1
+ like: 3
+ doing: 1
+ so: 4
+ mod_perl: 1
+ re: 2
+ writing: 2
+ web: 1
+ framework: 1
+ then: 1
+ work: 2
+ expect: 2
+ to.: 1
+ Creates: 1
+ request: 9
+ object.: 5
+ ATTRIBUTES: 1
+ over: 1
+ item: 24
+ shared: 1
+ PSGI: 3
+ environment: 4
+ hash: 12
+ reference.: 3
+ this: 10
+ passes: 1
+ during: 1
+ whole: 1
+ request/response: 1
+ cycle.: 1
+ IP: 2
+ client: 1
+ <REMOTE_ADDR>: 1
+ remote: 1
+ host: 1
+ <REMOTE_HOST>: 1
+ client.: 1
+ may: 2
+ empty: 2
+ have: 3
+ get: 6
+ using: 4
+ <address>: 1
+ resolve: 1
+ your: 8
+ own.: 1
+ Contains: 1
+ <GET>: 1
+ <POST>: 1
+ <HEAD>: 1
+ etc: 1
+ HTTP/1.0: 1
+ HTTP/1.1: 1
+ current: 3
+ request.: 4
+ raw: 1
+ undecoded: 2
+ path.: 3
+ You: 4
+ probably: 1
+ <NOT>: 1
+ dispatch: 1
+ requests.: 3
+ <PATH_INFO>: 2
+ environment.: 2
+ Use: 1
+ local: 1
+ Similar: 1
+ <path_info>: 3
+ </>: 3
+ empty.: 1
+ In: 2
+ words: 1
+ virtual: 1
+ req: 11
+ </"DISPATCHING">: 1
+ details.: 1
+ <SCRIPT_NAME>: 3
+ absolute: 2
+ hosted.: 1
+ <http>: 1
+ <https>: 1
+ indicating: 1
+ whether: 1
+ connection: 1
+ https: 1
+ <psgi.input>: 1
+ handle.: 1
+ optional: 3
+ <psgix.session>: 1
+ hash.: 3
+ When: 2
+ retrieve: 1
+ store: 1
+ per: 1
+ data: 1
+ <psgix.session.options>: 1
+ <psgix.logger>: 1
+ code: 9
+ supposed: 1
+ send: 1
+ log: 1
+ message: 2
+ level: 1
+ cookies.: 1
+ Values: 1
+ strings: 1
+ sent: 1
+ clients: 1
+ decoded.: 1
+ string: 4
+ GET: 2
+ parameters.: 2
+ <Hash::MultiValue>: 5
+ posted: 1
+ POST: 4
+ As: 1
+ <query_parameters>: 2
+ merged: 1
+ raw_body: 1
+ an: 7
+ byte: 1
+ object: 2
+ constructed: 1
+ various: 1
+ values: 3
+ such: 5
+ <QUERY_STRING>: 1
+ <HTTP_HOST>: 1
+ <SERVER_NAME>: 1
+ <SERVER_PORT>: 1
+ Every: 2
+ time: 3
+ called: 2
+ cloned: 2
+ <uri>: 1
+ contains: 2
+ up: 2
+ hosted: 1
+ at.: 1
+ <REMOTE_USER>: 1
+ foo: 7
+ need: 1
+ ugly: 1
+ unsafe: 1
+ anymore.: 1
+ And: 1
+ explicitly: 1
+ multiple: 3
+ same: 2
+ call: 4
+ <get_all>: 1
+ ! '@foo': 1
+ also: 2
+ <get_one>: 1
+ always: 4
+ parameter: 2
+ independent: 1
+ unlike: 1
+ <param>: 1
+ <mixed>: 1
+ '.05': 1
+ later: 1
+ <traditional>: 1
+ mixed: 1
+ either: 1
+ scalar: 1
+ array: 4
+ depending: 2
+ might: 2
+ useful: 1
+ already: 1
+ deal: 1
+ ugliness.: 1
+ PARSING: 1
+ BODY: 1
+ MULTIPLE: 1
+ OBJECTS: 1
+ methods: 5
+ parse: 1
+ <content>: 1
+ <body_parameters>: 2
+ <uploads>: 2
+ carefully: 1
+ coded: 1
+ save: 1
+ parsed: 1
+ well: 1
+ temporary: 1
+ buffer: 1
+ them: 2
+ times: 2
+ create: 1
+ objects: 3
+ they: 1
+ safely: 1
+ won: 1
+ gives: 1
+ action: 1
+ Note: 1
+ give: 1
+ assume: 1
+ prefix: 1
+ building: 1
+ URLs: 1
+ templates: 1
+ redirections.: 1
+ /logout: 1
+ ll: 1
+ full: 1
+ </app/logout?signoff=1>: 1
+ INCOMPATIBILITIES: 1
+ '.99': 1
+ many: 1
+ utility: 1
+ removed: 2
+ deprecated: 2
+ most: 1
+ made: 1
+ read: 1
+ only.: 1
+ following: 1
+ <hostname>: 1
+ <url_scheme>: 1
+ <params>: 1
+ <query_params>: 1
+ <body_params>: 1
+ <cookie>: 1
+ <raw_uri>: 1
+ They: 1
+ major: 2
+ release.: 1
+ related: 1
+ <parameters>: 1
+ now: 3
+ rather: 2
+ <scalar>: 1
+ insecure.: 1
+ more: 1
+ about: 1
+ change.: 1
+ had: 1
+ bug: 1
+ document: 2
+ mismatching.: 1
+ suggesting: 1
+ returning: 1
+ updated: 1
+ alias: 1
+ <CGI::Simple::Cookie>: 1
+ anymore: 1
+ means: 2
+ <CAN>: 1
+ NOT: 1
+ serialized.: 1
+ encoding: 1
+ decoding: 1
+ totally: 1
+ framework.: 1
+ Also: 1
+ <cookies>: 1
+ <strings>: 1
+ CGI: 1
+ Simple: 1
+ Cookie: 1
+ longer: 1
+ write: 1
+ wacky: 1
+ instead: 1
+ simply: 1
+ AUTHORS: 1
+ Tatsuhiko: 2
+ Miyagawa: 2
+ Kazuhiro: 1
+ Osawa: 1
+ Tokuhiro: 2
+ Matsuno: 2
+ SEE: 3
+ ALSO: 3
+ <Plack::Response>: 1
+ <HTTP::Request>: 1
+ <Catalyst::Request>: 1
+ library: 1
+ itself.: 1
+ Response: 1
+ Util: 3
+ Accessor: 1
+ status: 9
+ Scalar: 2
+ location: 3
+ redirect: 1
+ url: 2
+ finalize: 3
+ clone: 1
+ _finalize_cookies: 1
+ /chr: 1
+ /ge: 1
+ //g: 1
+ header_field_names: 1
+ _body: 2
+ blessed: 1
+ overload: 1
+ Method: 1
+ domain: 2
+ expires: 2
+ HttpOnly: 1
+ GMT: 1
+ Hello: 2
+ World: 2
+ response: 2
+ back: 1
+ AUTHOR: 1
+ <Plack::Request>: 1
+ /usr/bin/env: 1
+ perl: 5
+ MAIN: 1
+ main: 3
+ env_is_usable: 3
+ th: 1
+ pt: 1
+ bar: 3
+ unshift: 1
+ read_ackrc: 1
+ ! '@keys': 2
+ ACK_/: 1
+ ! '@ENV': 1
+ load_colors: 1
+ ACK_SWITCHES: 1
+ show_help: 1
+ get_command_line_options: 1
+ build_regex: 1
+ nargs: 2
+ specify: 1
+ both: 1
+ g.: 1
+ Defining: 2
+ own: 2
+ less: 2
+ provides: 1
+ simple: 1
+ compilation: 1
+ mode: 1
+ has: 1
+ ability: 1
+ guess: 1
+ based: 1
+ mode.: 1
+ spend: 1
+ day: 1
+ mostly: 1
+ inside: 1
+ TextMate: 2
+ built: 1
+ find: 3
+ project: 1
+ sucks: 1
+ large: 1
+ projects.: 1
+ So: 1
+ hacked: 1
+ ack.: 1
+ result: 1
+ Search: 1
+ Project: 1
+ <http://www.simplicidade.org/notes/archives/2008/03/search_in_proje.html>: 1
+ Invalid: 2
+ option: 1
+ passed: 1
+ badkey: 1
+ dir/: 1
+ negative: 1
+ val: 1
+ ignoring: 1
+ Permission: 1
+ denied: 1
+ str: 3
+ I#7#I: 1
+ /I: 1
+ ! '*/': 1
+ ! '*.*s': 1
+ end: 1
+ END_OF_VERSION: 1
+ Matched: 1
+ hidden: 1
+ ! '@ISA': 1
+ nexted: 3
+ Resource: 1
+ examples/benchmarks/fib.pl: 1
+ Fibonacci: 2
+ Benchmark: 1
+ SYNOPSIS: 1
+ DESCRIPTION: 1
+ Calculates: 1
+ Number: 1
+ <n>: 1
+ unspecified: 1
+ fib: 4
+ N: 2
+ <examples/benchmarks/fib.pir>: 1
+ ..: 3
+ Foo: 9
+ Bar: 1
+ ! '@array': 1
+ /usr/local/bin/perl: 1
+ /usr/bin/perl: 1
PowerShell:
! '#': 2
Write: 2
@@ -17379,6 +17379,26 @@ tokens:
log: 1
;: 1
! '}': 1
+ SCSS:
+ blue: 4
+ ! '#3bbfce': 1
+ ;: 7
+ margin: 4
+ px: 1
+ .content: 1
+ ! '-': 3
+ navigation: 1
+ ! '{': 2
+ border: 2
+ color: 3
+ darken: 1
+ (: 1
+ ! '%': 1
+ ): 1
+ ! '}': 2
+ .border: 1
+ padding: 1
+ /: 2
Sass:
blue: 4
! '#3bbfce': 1
@@ -17758,26 +17778,6 @@ tokens:
disp: 1
assert_checkequal: 1
assert_checkfalse: 1
- SCSS:
- blue: 4
- ! '#3bbfce': 1
- ;: 7
- margin: 4
- px: 1
- .content: 1
- ! '-': 3
- navigation: 1
- ! '{': 2
- border: 2
- color: 3
- darken: 1
- (: 1
- ! '%': 1
- ): 1
- ! '}': 2
- .border: 1
- padding: 1
- /: 2
Shell:
export: 5
PATH: 5
@@ -18004,10 +18004,6 @@ tokens:
busAt: 1
/*: 2
! '*/': 2
- Tea:
- <%>: 1
- template: 1
- foo: 1
TeX:
! '%': 85
NeedsTeXFormat: 1
@@ -18284,6 +18280,10 @@ tokens:
major: 1
sign: 1
makebox: 6
+ Tea:
+ <%>: 1
+ template: 1
+ foo: 1
Turing:
! '%': 1
function: 1
@@ -18307,6 +18307,34 @@ tokens:
get: 1
exit: 1
when: 1
+ VHDL:
+ ! '-': 2
+ VHDL: 1
+ example: 1
+ file: 1
+ library: 1
+ ieee: 1
+ ;: 7
+ use: 1
+ ieee.std_logic_1164.all: 1
+ entity: 2
+ inverter: 2
+ is: 2
+ port: 1
+ (: 1
+ a: 2
+ in: 1
+ std_logic: 2
+ b: 2
+ out: 1
+ ): 1
+ end: 2
+ architecture: 2
+ rtl: 1
+ of: 1
+ begin: 1
+ <: 1
+ not: 1
Verilog:
////////////////////////////////////////////////////////////////////////////////: 14
//: 367
@@ -18731,34 +18759,6 @@ tokens:
.csrm_we_o: 1
.csrm_dat_o: 1
.csrm_dat_i: 1
- VHDL:
- ! '-': 2
- VHDL: 1
- example: 1
- file: 1
- library: 1
- ieee: 1
- ;: 7
- use: 1
- ieee.std_logic_1164.all: 1
- entity: 2
- inverter: 2
- is: 2
- port: 1
- (: 1
- a: 2
- in: 1
- std_logic: 2
- b: 2
- out: 1
- ): 1
- end: 2
- architecture: 2
- rtl: 1
- of: 1
- begin: 1
- <: 1
- not: 1
VimL:
'no': 1
toolbar: 1
@@ -19838,10 +19838,10 @@ language_tokens:
Arduino: 20
AutoHotkey: 3
C: 28587
+ C++: 7788
Ceylon: 50
CoffeeScript: 2340
Coq: 17450
- C++: 7788
Dart: 68
Delphi: 30
Diff: 16
@@ -19863,15 +19863,15 @@ language_tokens:
Nemerle: 17
Nimrod: 2
Nu: 6
- Objective-C: 28134
OCaml: 261
+ Objective-C: 28134
Opa: 32
OpenCL: 88
OpenEdge ABL: 717
- Parrot Assembly: 8
- Perl: 7231
PHP: 12292
+ Parrot Assembly: 8
Parrot Internal Representation: 7
+ Perl: 7231
PowerShell: 14
Prolog: 61
Python: 4357
@@ -19880,19 +19880,19 @@ language_tokens:
Rebol: 5
Ruby: 3539
Rust: 8
+ SCSS: 39
Sass: 28
Scala: 352
Scheme: 3549
Scilab: 71
- SCSS: 39
Shell: 264
Standard ML: 220
SuperCollider: 139
- Tea: 3
TeX: 1073
+ Tea: 3
Turing: 45
- Verilog: 3440
VHDL: 42
+ Verilog: 3440
VimL: 20
Visual Basic: 294
XML: 5627
@@ -19905,10 +19905,10 @@ languages:
Arduino: 1
AutoHotkey: 1
C: 18
+ C++: 14
Ceylon: 1
CoffeeScript: 9
Coq: 12
- C++: 14
Dart: 1
Delphi: 1
Diff: 1
@@ -19930,15 +19930,15 @@ languages:
Nemerle: 1
Nimrod: 1
Nu: 1
- Objective-C: 20
OCaml: 1
+ Objective-C: 20
Opa: 2
OpenCL: 1
OpenEdge ABL: 5
- Parrot Assembly: 1
- Perl: 12
PHP: 6
+ Parrot Assembly: 1
Parrot Internal Representation: 1
+ Perl: 12
PowerShell: 2
Prolog: 1
Python: 4
@@ -19947,19 +19947,19 @@ languages:
Rebol: 1
Ruby: 14
Rust: 1
+ SCSS: 1
Sass: 1
Scala: 2
Scheme: 1
Scilab: 3
- SCSS: 1
Shell: 11
Standard ML: 2
SuperCollider: 1
- Tea: 1
TeX: 1
+ Tea: 1
Turing: 1
- Verilog: 13
VHDL: 1
+ Verilog: 13
VimL: 2
Visual Basic: 1
XML: 3
@@ -19967,4 +19967,4 @@ languages:
XSLT: 1
YAML: 1
md5: !binary |-
- NThmMGEzMjkwOTY0ZWU1Mzc5NDBjMzY4NjU1OWJhMzc=
+ YTBlYmVhZmEyZjgwNDI4NDQwNzk5MGJmZWRiMWM3ZWU=
diff --git a/samples/apex/ArrayUtils.cls b/samples/Apex/ArrayUtils.cls
index b08cd51..b08cd51 100644
--- a/samples/apex/ArrayUtils.cls
+++ b/samples/Apex/ArrayUtils.cls
diff --git a/samples/apex/BooleanUtils.cls b/samples/Apex/BooleanUtils.cls
index 80a57f9..80a57f9 100644
--- a/samples/apex/BooleanUtils.cls
+++ b/samples/Apex/BooleanUtils.cls
diff --git a/samples/apex/EmailUtils.cls b/samples/Apex/EmailUtils.cls
index 320529b..320529b 100644
--- a/samples/apex/EmailUtils.cls
+++ b/samples/Apex/EmailUtils.cls
diff --git a/samples/apex/GeoUtils.cls b/samples/Apex/GeoUtils.cls
index 26faf45..26faf45 100644
--- a/samples/apex/GeoUtils.cls
+++ b/samples/Apex/GeoUtils.cls
diff --git a/samples/apex/LanguageUtils.cls b/samples/Apex/LanguageUtils.cls
index faefba6..faefba6 100644
--- a/samples/apex/LanguageUtils.cls
+++ b/samples/Apex/LanguageUtils.cls
diff --git a/samples/apex/TwilioAPI.cls b/samples/Apex/TwilioAPI.cls
index 4c49d28..4c49d28 100644
--- a/samples/apex/TwilioAPI.cls
+++ b/samples/Apex/TwilioAPI.cls
diff --git a/samples/applescript/center.applescript b/samples/AppleScript/center.applescript
index 3049271..3049271 100644
--- a/samples/applescript/center.applescript
+++ b/samples/AppleScript/center.applescript
diff --git a/samples/applescript/center.scpt b/samples/AppleScript/center.scpt
index 3049271..3049271 100644
--- a/samples/applescript/center.scpt
+++ b/samples/AppleScript/center.scpt
diff --git a/samples/arduino/hello.ino b/samples/Arduino/hello.ino
index 469cecd..469cecd 100644
--- a/samples/arduino/hello.ino
+++ b/samples/Arduino/hello.ino
diff --git a/samples/autohotkey/hello.ahk b/samples/AutoHotkey/hello.ahk
index ff963eb..ff963eb 100644
--- a/samples/autohotkey/hello.ahk
+++ b/samples/AutoHotkey/hello.ahk
diff --git a/samples/binary/dog.o b/samples/Binary/dog.o
index 4703976..4703976 100755
--- a/samples/binary/dog.o
+++ b/samples/Binary/dog.o
Binary files differ
diff --git a/samples/binary/foo bar.jar b/samples/Binary/foo bar.jar
index d3b48df..d3b48df 100644
--- a/samples/binary/foo bar.jar
+++ b/samples/Binary/foo bar.jar
Binary files differ
diff --git a/samples/binary/foo.bin b/samples/Binary/foo.bin
index d3b48df..d3b48df 100644
--- a/samples/binary/foo.bin
+++ b/samples/Binary/foo.bin
Binary files differ
diff --git a/samples/binary/foo.pdf b/samples/Binary/foo.pdf
index 68c8d29..68c8d29 100644
--- a/samples/binary/foo.pdf
+++ b/samples/Binary/foo.pdf
Binary files differ
diff --git a/samples/binary/foo.png b/samples/Binary/foo.png
index a9ec5a2..a9ec5a2 100644
--- a/samples/binary/foo.png
+++ b/samples/Binary/foo.png
Binary files differ
diff --git a/samples/binary/git.deb b/samples/Binary/git.deb
index 709e828..709e828 100644
--- a/samples/binary/git.deb
+++ b/samples/Binary/git.deb
Binary files differ
diff --git a/samples/binary/git.exe b/samples/Binary/git.exe
index 4703976..4703976 100755
--- a/samples/binary/git.exe
+++ b/samples/Binary/git.exe
Binary files differ
diff --git a/samples/binary/github.po b/samples/Binary/github.po
index 772ecc0..772ecc0 100644
--- a/samples/binary/github.po
+++ b/samples/Binary/github.po
diff --git a/samples/binary/hello.pbc b/samples/Binary/hello.pbc
index b30393e..b30393e 100644
--- a/samples/binary/hello.pbc
+++ b/samples/Binary/hello.pbc
Binary files differ
diff --git a/samples/binary/linguist.gem b/samples/Binary/linguist.gem
index 04cc759..04cc759 100644
--- a/samples/binary/linguist.gem
+++ b/samples/Binary/linguist.gem
Binary files differ
diff --git a/samples/binary/octocat.ai b/samples/Binary/octocat.ai
index b0ad88a..b0ad88a 100644
--- a/samples/binary/octocat.ai
+++ b/samples/Binary/octocat.ai
diff --git a/samples/binary/octocat.png b/samples/Binary/octocat.png
index a9ec5a2..a9ec5a2 100644
--- a/samples/binary/octocat.png
+++ b/samples/Binary/octocat.png
Binary files differ
diff --git a/samples/binary/octocat.psd b/samples/Binary/octocat.psd
index 910bd90..910bd90 100644
--- a/samples/binary/octocat.psd
+++ b/samples/Binary/octocat.psd
Binary files differ
diff --git a/samples/binary/zip b/samples/Binary/zip
index d3b48df..d3b48df 100644
--- a/samples/binary/zip
+++ b/samples/Binary/zip
Binary files differ
diff --git a/samples/cpp/bar.h b/samples/C++/bar.h
index a87343c..a87343c 100644
--- a/samples/cpp/bar.h
+++ b/samples/C++/bar.h
diff --git a/samples/cpp/bar.hpp b/samples/C++/bar.hpp
index a87343c..a87343c 100644
--- a/samples/cpp/bar.hpp
+++ b/samples/C++/bar.hpp
diff --git a/samples/cpp/cuda.cu b/samples/C++/cuda.cu
index ddef40c..ddef40c 100644
--- a/samples/cpp/cuda.cu
+++ b/samples/C++/cuda.cu
diff --git a/samples/cpp/env.cpp b/samples/C++/env.cpp
index beddc19..beddc19 100644
--- a/samples/cpp/env.cpp
+++ b/samples/C++/env.cpp
diff --git a/samples/cpp/env.h b/samples/C++/env.h
index 6d72b39..6d72b39 100644
--- a/samples/cpp/env.h
+++ b/samples/C++/env.h
diff --git a/samples/cpp/hello.cpp b/samples/C++/hello.cpp
index d36f6e6..d36f6e6 100644
--- a/samples/cpp/hello.cpp
+++ b/samples/C++/hello.cpp
diff --git a/samples/cpp/key.cpp b/samples/C++/key.cpp
index 57ab842..57ab842 100644
--- a/samples/cpp/key.cpp
+++ b/samples/C++/key.cpp
diff --git a/samples/cpp/key.h b/samples/C++/key.h
index 945c499..945c499 100644
--- a/samples/cpp/key.h
+++ b/samples/C++/key.h
diff --git a/samples/cpp/main.cpp b/samples/C++/main.cpp
index 8ca481d..8ca481d 100644
--- a/samples/cpp/main.cpp
+++ b/samples/C++/main.cpp
diff --git a/samples/cpp/scanner.cc b/samples/C++/scanner.cc
index f24af2e..f24af2e 100644
--- a/samples/cpp/scanner.cc
+++ b/samples/C++/scanner.cc
diff --git a/samples/cpp/scanner.h b/samples/C++/scanner.h
index 4de413b..4de413b 100644
--- a/samples/cpp/scanner.h
+++ b/samples/C++/scanner.h
diff --git a/samples/cpp/utils.h b/samples/C++/utils.h
index cbc993e..cbc993e 100644
--- a/samples/cpp/utils.h
+++ b/samples/C++/utils.h
diff --git a/samples/cpp/v8.cc b/samples/C++/v8.cc
index 2910a07..2910a07 100644
--- a/samples/cpp/v8.cc
+++ b/samples/C++/v8.cc
diff --git a/samples/cpp/v8.h b/samples/C++/v8.h
index 67716d8..67716d8 100644
--- a/samples/cpp/v8.h
+++ b/samples/C++/v8.h
diff --git a/samples/c/blob.c b/samples/C/blob.c
index ae320bd..ae320bd 100644
--- a/samples/c/blob.c
+++ b/samples/C/blob.c
diff --git a/samples/c/blob.h b/samples/C/blob.h
index 59b394e..59b394e 100644
--- a/samples/c/blob.h
+++ b/samples/C/blob.h
diff --git a/samples/c/cache.c b/samples/C/cache.c
index f8d8940..f8d8940 100644
--- a/samples/c/cache.c
+++ b/samples/C/cache.c
diff --git a/samples/c/commit.c b/samples/C/commit.c
index 8248a99..8248a99 100644
--- a/samples/c/commit.c
+++ b/samples/C/commit.c
diff --git a/samples/c/commit.h b/samples/C/commit.h
index d617fa3..d617fa3 100644
--- a/samples/c/commit.h
+++ b/samples/C/commit.h
diff --git a/samples/c/cpu.c b/samples/C/cpu.c
index a4eb522..a4eb522 100644
--- a/samples/c/cpu.c
+++ b/samples/C/cpu.c
diff --git a/samples/c/diff.c b/samples/C/diff.c
index 90baa95..90baa95 100644
--- a/samples/c/diff.c
+++ b/samples/C/diff.c
diff --git a/samples/c/git.c b/samples/C/git.c
index d232de9..d232de9 100644
--- a/samples/c/git.c
+++ b/samples/C/git.c
diff --git a/samples/c/hash.c b/samples/C/hash.c
index 4607569..4607569 100644
--- a/samples/c/hash.c
+++ b/samples/C/hash.c
diff --git a/samples/c/hello.c b/samples/C/hello.c
index c3ce445..c3ce445 100644
--- a/samples/c/hello.c
+++ b/samples/C/hello.c
diff --git a/samples/c/hello.h b/samples/C/hello.h
index f19e5d3..f19e5d3 100644
--- a/samples/c/hello.h
+++ b/samples/C/hello.h
diff --git a/samples/c/http_parser.c b/samples/C/http_parser.c
index 0c11eb8..0c11eb8 100644
--- a/samples/c/http_parser.c
+++ b/samples/C/http_parser.c
diff --git a/samples/c/http_parser.h b/samples/C/http_parser.h
index 8ed4180..8ed4180 100644
--- a/samples/c/http_parser.h
+++ b/samples/C/http_parser.h
diff --git a/samples/c/markdown.c b/samples/C/markdown.c
index 260483d..260483d 100644
--- a/samples/c/markdown.c
+++ b/samples/C/markdown.c
diff --git a/samples/c/process.c b/samples/C/process.c
index d3eb998..d3eb998 100644
--- a/samples/c/process.c
+++ b/samples/C/process.c
diff --git a/samples/c/rdiscount.c b/samples/C/rdiscount.c
index 86167ff..86167ff 100644
--- a/samples/c/rdiscount.c
+++ b/samples/C/rdiscount.c
diff --git a/samples/c/redis.c b/samples/C/redis.c
index b1f8338..b1f8338 100644
--- a/samples/c/redis.c
+++ b/samples/C/redis.c
diff --git a/samples/c/yajl.c b/samples/C/yajl.c
index 50bca44..50bca44 100644
--- a/samples/c/yajl.c
+++ b/samples/C/yajl.c
diff --git a/samples/ceylon/Foo.ceylon b/samples/Ceylon/Foo.ceylon
index dc35686..dc35686 100644
--- a/samples/ceylon/Foo.ceylon
+++ b/samples/Ceylon/Foo.ceylon
diff --git a/samples/coffee/browser.coffee b/samples/CoffeeScript/browser.coffee
index 5ed0bea..5ed0bea 100644
--- a/samples/coffee/browser.coffee
+++ b/samples/CoffeeScript/browser.coffee
diff --git a/samples/coffee/classes.coffee b/samples/CoffeeScript/classes.coffee
index 2b2a718..2b2a718 100644
--- a/samples/coffee/classes.coffee
+++ b/samples/CoffeeScript/classes.coffee
diff --git a/samples/coffee/coffee-script.coffee b/samples/CoffeeScript/coffee-script.coffee
index 2933aeb..2933aeb 100644
--- a/samples/coffee/coffee-script.coffee
+++ b/samples/CoffeeScript/coffee-script.coffee
diff --git a/samples/coffee/empty.coffee b/samples/CoffeeScript/empty.coffee
index e69de29..e69de29 100644
--- a/samples/coffee/empty.coffee
+++ b/samples/CoffeeScript/empty.coffee
diff --git a/samples/coffee/hello.coffee b/samples/CoffeeScript/hello.coffee
index 4b65a57..4b65a57 100644
--- a/samples/coffee/hello.coffee
+++ b/samples/CoffeeScript/hello.coffee
diff --git a/samples/coffee/intro.coffee b/samples/CoffeeScript/intro.coffee
index 0db65dd..0db65dd 100644
--- a/samples/coffee/intro.coffee
+++ b/samples/CoffeeScript/intro.coffee
diff --git a/samples/coffee/lexer.coffee b/samples/CoffeeScript/lexer.coffee
index 56e8e32..56e8e32 100644
--- a/samples/coffee/lexer.coffee
+++ b/samples/CoffeeScript/lexer.coffee
diff --git a/samples/coffee/rack_application.coffee b/samples/CoffeeScript/rack_application.coffee
index 674313b..674313b 100644
--- a/samples/coffee/rack_application.coffee
+++ b/samples/CoffeeScript/rack_application.coffee
diff --git a/samples/coffee/xipd.coffee b/samples/CoffeeScript/xipd.coffee
index 8b49f1f..8b49f1f 100644
--- a/samples/coffee/xipd.coffee
+++ b/samples/CoffeeScript/xipd.coffee
diff --git a/samples/coq/Basics.v b/samples/Coq/Basics.v
index 054fcbd..054fcbd 100755
--- a/samples/coq/Basics.v
+++ b/samples/Coq/Basics.v
diff --git a/samples/coq/Heap.v b/samples/Coq/Heap.v
index 8653640..8653640 100755
--- a/samples/coq/Heap.v
+++ b/samples/Coq/Heap.v
diff --git a/samples/coq/Imp.v b/samples/Coq/Imp.v
index 3668923..3668923 100755
--- a/samples/coq/Imp.v
+++ b/samples/Coq/Imp.v
diff --git a/samples/coq/Lists.v b/samples/Coq/Lists.v
index f09112a..f09112a 100755
--- a/samples/coq/Lists.v
+++ b/samples/Coq/Lists.v
diff --git a/samples/coq/PermutSetoid.v b/samples/Coq/PermutSetoid.v
index aed7150..aed7150 100755
--- a/samples/coq/PermutSetoid.v
+++ b/samples/Coq/PermutSetoid.v
diff --git a/samples/coq/Permutation.v b/samples/Coq/Permutation.v
index eb769b7..eb769b7 100755
--- a/samples/coq/Permutation.v
+++ b/samples/Coq/Permutation.v
diff --git a/samples/coq/Poly.v b/samples/Coq/Poly.v
index 63968cf..63968cf 100755
--- a/samples/coq/Poly.v
+++ b/samples/Coq/Poly.v
diff --git a/samples/coq/Rel.v b/samples/Coq/Rel.v
index 9449cbf..9449cbf 100755
--- a/samples/coq/Rel.v
+++ b/samples/Coq/Rel.v
diff --git a/samples/coq/Smallstep.v b/samples/Coq/Smallstep.v
index b59bdd4..b59bdd4 100755
--- a/samples/coq/Smallstep.v
+++ b/samples/Coq/Smallstep.v
diff --git a/samples/coq/Sorting.v b/samples/Coq/Sorting.v
index 22e5659..22e5659 100755
--- a/samples/coq/Sorting.v
+++ b/samples/Coq/Sorting.v
diff --git a/samples/coq/Stlc.v b/samples/Coq/Stlc.v
index 7728052..7728052 100755
--- a/samples/coq/Stlc.v
+++ b/samples/Coq/Stlc.v
diff --git a/samples/coq/interval_discr.v b/samples/Coq/interval_discr.v
index ed2c0e3..ed2c0e3 100644
--- a/samples/coq/interval_discr.v
+++ b/samples/Coq/interval_discr.v
diff --git a/samples/dart/point.dart b/samples/Dart/point.dart
index 5bb74b2..5bb74b2 100644
--- a/samples/dart/point.dart
+++ b/samples/Dart/point.dart
diff --git a/samples/delphi/program.dpr b/samples/Delphi/program.dpr
index d2d71f1..d2d71f1 100644
--- a/samples/delphi/program.dpr
+++ b/samples/Delphi/program.dpr
diff --git a/samples/diff/dude-thing-okay--001.patch b/samples/Diff/dude-thing-okay--001.patch
index d3dbba1..d3dbba1 100644
--- a/samples/diff/dude-thing-okay--001.patch
+++ b/samples/Diff/dude-thing-okay--001.patch
diff --git a/samples/emacs/dude.el b/samples/Emacs Lisp/dude.el
index 70c6117..70c6117 100644
--- a/samples/emacs/dude.el
+++ b/samples/Emacs Lisp/dude.el
diff --git a/samples/gas/hello.s b/samples/GAS/hello.s
index 278f03c..278f03c 100644
--- a/samples/gas/hello.s
+++ b/samples/GAS/hello.s
diff --git a/samples/gosu/Hello.gst b/samples/Gosu/Hello.gst
index 6addbf7..6addbf7 100644
--- a/samples/gosu/Hello.gst
+++ b/samples/Gosu/Hello.gst
diff --git a/samples/gosu/Hello.gsx b/samples/Gosu/Hello.gsx
index 2f850e9..2f850e9 100644
--- a/samples/gosu/Hello.gsx
+++ b/samples/Gosu/Hello.gsx
diff --git a/samples/gosu/Person.gs b/samples/Gosu/Person.gs
index eb8372d..eb8372d 100644
--- a/samples/gosu/Person.gs
+++ b/samples/Gosu/Person.gs
diff --git a/samples/gosu/hello.gsp b/samples/Gosu/hello.gsp
index ce47b77..ce47b77 100644
--- a/samples/gosu/hello.gsp
+++ b/samples/Gosu/hello.gsp
diff --git a/samples/gosu/hello.vark b/samples/Gosu/hello.vark
index 3fc6934..3fc6934 100644
--- a/samples/gosu/hello.vark
+++ b/samples/Gosu/hello.vark
diff --git a/samples/gsp/bar.gsp b/samples/Groovy Server Pages/bar.gsp
index 4a7eabf..4a7eabf 100644
--- a/samples/gsp/bar.gsp
+++ b/samples/Groovy Server Pages/bar.gsp
diff --git a/samples/gsp/hello-pagedirective.gsp b/samples/Groovy Server Pages/hello-pagedirective.gsp
index d632536..d632536 100644
--- a/samples/gsp/hello-pagedirective.gsp
+++ b/samples/Groovy Server Pages/hello-pagedirective.gsp
diff --git a/samples/gsp/hello-resources.gsp b/samples/Groovy Server Pages/hello-resources.gsp
index 15c0edd..15c0edd 100644
--- a/samples/gsp/hello-resources.gsp
+++ b/samples/Groovy Server Pages/hello-resources.gsp
diff --git a/samples/gsp/hello-var.gsp b/samples/Groovy Server Pages/hello-var.gsp
index b16da17..b16da17 100644
--- a/samples/gsp/hello-var.gsp
+++ b/samples/Groovy Server Pages/hello-var.gsp
diff --git a/samples/groovy/build.gradle b/samples/Groovy/build.gradle
index c1ac812..c1ac812 100644
--- a/samples/groovy/build.gradle
+++ b/samples/Groovy/build.gradle
diff --git a/samples/groovy/script.groovy b/samples/Groovy/script.groovy
index 1ee357a..1ee357a 100755
--- a/samples/groovy/script.groovy
+++ b/samples/Groovy/script.groovy
diff --git a/samples/haml/hello.haml b/samples/Haml/hello.haml
index accbf54..accbf54 100644
--- a/samples/haml/hello.haml
+++ b/samples/Haml/hello.haml
diff --git a/samples/ini/.gitconfig b/samples/INI/.gitconfig
index c583979..c583979 100644
--- a/samples/ini/.gitconfig
+++ b/samples/INI/.gitconfig
diff --git a/samples/ioke/hello.ik b/samples/Ioke/hello.ik
index 0adcd0e..0adcd0e 100644
--- a/samples/ioke/hello.ik
+++ b/samples/Ioke/hello.ik
diff --git a/samples/java/HtmlDomParserContext.java b/samples/Java/HtmlDomParserContext.java
index 6c13e3d..6c13e3d 100644
--- a/samples/java/HtmlDomParserContext.java
+++ b/samples/Java/HtmlDomParserContext.java
diff --git a/samples/java/Hudson.java b/samples/Java/Hudson.java
index aff8df4..aff8df4 100644
--- a/samples/java/Hudson.java
+++ b/samples/Java/Hudson.java
diff --git a/samples/java/NokogiriService.java b/samples/Java/NokogiriService.java
index b497675..b497675 100644
--- a/samples/java/NokogiriService.java
+++ b/samples/Java/NokogiriService.java
diff --git a/samples/java/clojure-type.java b/samples/Java/clojure-type.java
index 4cde14a..4cde14a 100644
--- a/samples/java/clojure-type.java
+++ b/samples/Java/clojure-type.java
diff --git a/samples/java/clojure-util.java b/samples/Java/clojure-util.java
index 02b5466..02b5466 100644
--- a/samples/java/clojure-util.java
+++ b/samples/Java/clojure-util.java
diff --git a/samples/javascript/bootstrap-modal.js b/samples/JavaScript/bootstrap-modal.js
index 38fd0c8..38fd0c8 100644
--- a/samples/javascript/bootstrap-modal.js
+++ b/samples/JavaScript/bootstrap-modal.js
diff --git a/samples/javascript/classes-old.js b/samples/JavaScript/classes-old.js
index 2e4353f..2e4353f 100644
--- a/samples/javascript/classes-old.js
+++ b/samples/JavaScript/classes-old.js
diff --git a/samples/javascript/classes.js b/samples/JavaScript/classes.js
index 888e02b..888e02b 100644
--- a/samples/javascript/classes.js
+++ b/samples/JavaScript/classes.js
diff --git a/samples/javascript/dude.js b/samples/JavaScript/dude.js
index 89ac059..89ac059 100644
--- a/samples/javascript/dude.js
+++ b/samples/JavaScript/dude.js
diff --git a/samples/javascript/empty.js b/samples/JavaScript/empty.js
index f5e757a..f5e757a 100644
--- a/samples/javascript/empty.js
+++ b/samples/JavaScript/empty.js
diff --git a/samples/javascript/hello.js b/samples/JavaScript/hello.js
index c1c58ec..c1c58ec 100644
--- a/samples/javascript/hello.js
+++ b/samples/JavaScript/hello.js
diff --git a/samples/javascript/http.js b/samples/JavaScript/http.js
index 92e0004..92e0004 100644
--- a/samples/javascript/http.js
+++ b/samples/JavaScript/http.js
diff --git a/samples/javascript/intro-old.js b/samples/JavaScript/intro-old.js
index f774102..f774102 100644
--- a/samples/javascript/intro-old.js
+++ b/samples/JavaScript/intro-old.js
diff --git a/samples/javascript/intro.js b/samples/JavaScript/intro.js
index 5974d26..5974d26 100644
--- a/samples/javascript/intro.js
+++ b/samples/JavaScript/intro.js
diff --git a/samples/javascript/jquery-1.4.2.min.js b/samples/JavaScript/jquery-1.4.2.min.js
index 7c24308..7c24308 100644
--- a/samples/javascript/jquery-1.4.2.min.js
+++ b/samples/JavaScript/jquery-1.4.2.min.js
diff --git a/samples/javascript/jquery-1.6.1.js b/samples/JavaScript/jquery-1.6.1.js
index 5d5a1d5..5d5a1d5 100644
--- a/samples/javascript/jquery-1.6.1.js
+++ b/samples/JavaScript/jquery-1.6.1.js
diff --git a/samples/javascript/jquery-1.6.1.min.js b/samples/JavaScript/jquery-1.6.1.min.js
index b2ac174..b2ac174 100644
--- a/samples/javascript/jquery-1.6.1.min.js
+++ b/samples/JavaScript/jquery-1.6.1.min.js
diff --git a/samples/javascript/jquery-1.7.2.js b/samples/JavaScript/jquery-1.7.2.js
index 3774ff9..3774ff9 100644
--- a/samples/javascript/jquery-1.7.2.js
+++ b/samples/JavaScript/jquery-1.7.2.js
diff --git a/samples/javascript/json2_backbone.js b/samples/JavaScript/json2_backbone.js
index ccf1225..ccf1225 100644
--- a/samples/javascript/json2_backbone.js
+++ b/samples/JavaScript/json2_backbone.js
diff --git a/samples/javascript/modernizr.js b/samples/JavaScript/modernizr.js
index 5a72b47..5a72b47 100644
--- a/samples/javascript/modernizr.js
+++ b/samples/JavaScript/modernizr.js
diff --git a/samples/javascript/parser.js b/samples/JavaScript/parser.js
index d695036..d695036 100644
--- a/samples/javascript/parser.js
+++ b/samples/JavaScript/parser.js
diff --git a/samples/javascript/script.js b/samples/JavaScript/script.js
index a399ce3..a399ce3 100755
--- a/samples/javascript/script.js
+++ b/samples/JavaScript/script.js
diff --git a/samples/javascript/steelseries-min.js b/samples/JavaScript/steelseries-min.js
index 7b05bc8..7b05bc8 100644
--- a/samples/javascript/steelseries-min.js
+++ b/samples/JavaScript/steelseries-min.js
diff --git a/samples/javascript/uglify.js b/samples/JavaScript/uglify.js
index ce01a3d..ce01a3d 100644
--- a/samples/javascript/uglify.js
+++ b/samples/JavaScript/uglify.js
diff --git a/samples/julia/stockcorr.jl b/samples/Julia/stockcorr.jl
index 58ba80a..58ba80a 100644
--- a/samples/julia/stockcorr.jl
+++ b/samples/Julia/stockcorr.jl
diff --git a/samples/kotlin/Foo.kt b/samples/Kotlin/Foo.kt
index 5929133..5929133 100644
--- a/samples/kotlin/Foo.kt
+++ b/samples/Kotlin/Foo.kt
diff --git a/samples/logtalk/foo.lgt b/samples/Logtalk/foo.lgt
index 673fab2..673fab2 100644
--- a/samples/logtalk/foo.lgt
+++ b/samples/Logtalk/foo.lgt
diff --git a/samples/markdown/tender.md b/samples/Markdown/tender.md
index 82d3a02..82d3a02 100644
--- a/samples/markdown/tender.md
+++ b/samples/Markdown/tender.md
diff --git a/samples/matlab/average.m b/samples/Matlab/average.m
index 65eef8b..65eef8b 100644
--- a/samples/matlab/average.m
+++ b/samples/Matlab/average.m
diff --git a/samples/matlab/make_filter.m b/samples/Matlab/make_filter.m
index 3ad6c5c..3ad6c5c 100644
--- a/samples/matlab/make_filter.m
+++ b/samples/Matlab/make_filter.m
diff --git a/samples/matlab/matlab_class.m b/samples/Matlab/matlab_class.m
index 7377a4d..7377a4d 100644
--- a/samples/matlab/matlab_class.m
+++ b/samples/Matlab/matlab_class.m
diff --git a/samples/matlab/matlab_function.m b/samples/Matlab/matlab_function.m
index b73502e..b73502e 100644
--- a/samples/matlab/matlab_function.m
+++ b/samples/Matlab/matlab_function.m
diff --git a/samples/matlab/matlab_script.m b/samples/Matlab/matlab_script.m
index 89f1d95..89f1d95 100644
--- a/samples/matlab/matlab_script.m
+++ b/samples/Matlab/matlab_script.m
diff --git a/samples/matlab/matlab_script2.m b/samples/Matlab/matlab_script2.m
index 8e16eca..8e16eca 100644
--- a/samples/matlab/matlab_script2.m
+++ b/samples/Matlab/matlab_script2.m
diff --git a/samples/nemerle/hello.n b/samples/Nemerle/hello.n
index 7d36714..7d36714 100644
--- a/samples/nemerle/hello.n
+++ b/samples/Nemerle/hello.n
diff --git a/samples/nimrod/foo.nim b/samples/Nimrod/foo.nim
index 58b7f62..58b7f62 100644
--- a/samples/nimrod/foo.nim
+++ b/samples/Nimrod/foo.nim
diff --git a/samples/nu/script.nu b/samples/Nu/script.nu
index 4e02da8..4e02da8 100755
--- a/samples/nu/script.nu
+++ b/samples/Nu/script.nu
diff --git a/samples/ocaml/Foo.ml b/samples/OCaml/Foo.ml
index fb9c7e9..fb9c7e9 100644
--- a/samples/ocaml/Foo.ml
+++ b/samples/OCaml/Foo.ml
diff --git a/samples/objective-c/ASIHTTPRequest.h b/samples/Objective-C/ASIHTTPRequest.h
index ed6edc8..ed6edc8 100644
--- a/samples/objective-c/ASIHTTPRequest.h
+++ b/samples/Objective-C/ASIHTTPRequest.h
diff --git a/samples/objective-c/ASIHTTPRequest.m b/samples/Objective-C/ASIHTTPRequest.m
index 8dd162c..8dd162c 100644
--- a/samples/objective-c/ASIHTTPRequest.m
+++ b/samples/Objective-C/ASIHTTPRequest.m
diff --git a/samples/objective-c/Foo.h b/samples/Objective-C/Foo.h
index 95fbbf5..95fbbf5 100644
--- a/samples/objective-c/Foo.h
+++ b/samples/Objective-C/Foo.h
diff --git a/samples/objective-c/Foo.m b/samples/Objective-C/Foo.m
index f11b1bc..f11b1bc 100644
--- a/samples/objective-c/Foo.m
+++ b/samples/Objective-C/Foo.m
diff --git a/samples/objective-c/FooAppDelegate.h b/samples/Objective-C/FooAppDelegate.h
index 24531b2..24531b2 100644
--- a/samples/objective-c/FooAppDelegate.h
+++ b/samples/Objective-C/FooAppDelegate.h
diff --git a/samples/objective-c/FooAppDelegate.m b/samples/Objective-C/FooAppDelegate.m
index 7e8710b..7e8710b 100644
--- a/samples/objective-c/FooAppDelegate.m
+++ b/samples/Objective-C/FooAppDelegate.m
diff --git a/samples/objective-c/JSONKit.h b/samples/Objective-C/JSONKit.h
index 71bd0c3..71bd0c3 100644
--- a/samples/objective-c/JSONKit.h
+++ b/samples/Objective-C/JSONKit.h
diff --git a/samples/objective-c/JSONKit.m b/samples/Objective-C/JSONKit.m
index 76a04f0..76a04f0 100644
--- a/samples/objective-c/JSONKit.m
+++ b/samples/Objective-C/JSONKit.m
diff --git a/samples/objective-c/MainMenuViewController.h b/samples/Objective-C/MainMenuViewController.h
index f646771..f646771 100644
--- a/samples/objective-c/MainMenuViewController.h
+++ b/samples/Objective-C/MainMenuViewController.h
diff --git a/samples/objective-c/MainMenuViewController.m b/samples/Objective-C/MainMenuViewController.m
index c97318b..c97318b 100644
--- a/samples/objective-c/MainMenuViewController.m
+++ b/samples/Objective-C/MainMenuViewController.m
diff --git a/samples/objective-c/PlaygroundViewController.h b/samples/Objective-C/PlaygroundViewController.h
index 9c94c56..9c94c56 100644
--- a/samples/objective-c/PlaygroundViewController.h
+++ b/samples/Objective-C/PlaygroundViewController.h
diff --git a/samples/objective-c/PlaygroundViewController.m b/samples/Objective-C/PlaygroundViewController.m
index 5d52d91..5d52d91 100644
--- a/samples/objective-c/PlaygroundViewController.m
+++ b/samples/Objective-C/PlaygroundViewController.m
diff --git a/samples/objective-c/SBJsonParser.h b/samples/Objective-C/SBJsonParser.h
index 751122f..751122f 100644
--- a/samples/objective-c/SBJsonParser.h
+++ b/samples/Objective-C/SBJsonParser.h
diff --git a/samples/objective-c/SBJsonParser.m b/samples/Objective-C/SBJsonParser.m
index d1b4b1e..d1b4b1e 100644
--- a/samples/objective-c/SBJsonParser.m
+++ b/samples/Objective-C/SBJsonParser.m
diff --git a/samples/objective-c/StyleViewController.h b/samples/Objective-C/StyleViewController.h
index c9d0093..c9d0093 100644
--- a/samples/objective-c/StyleViewController.h
+++ b/samples/Objective-C/StyleViewController.h
diff --git a/samples/objective-c/StyleViewController.m b/samples/Objective-C/StyleViewController.m
index 7018b5e..7018b5e 100644
--- a/samples/objective-c/StyleViewController.m
+++ b/samples/Objective-C/StyleViewController.m
diff --git a/samples/objective-c/TUITableView.h b/samples/Objective-C/TUITableView.h
index d7036c5..d7036c5 100644
--- a/samples/objective-c/TUITableView.h
+++ b/samples/Objective-C/TUITableView.h
diff --git a/samples/objective-c/TUITableView.m b/samples/Objective-C/TUITableView.m
index 0ec17d7..0ec17d7 100644
--- a/samples/objective-c/TUITableView.m
+++ b/samples/Objective-C/TUITableView.m
diff --git a/samples/objective-c/empty.m b/samples/Objective-C/empty.m
index e69de29..e69de29 100644
--- a/samples/objective-c/empty.m
+++ b/samples/Objective-C/empty.m
diff --git a/samples/objective-c/hello.m b/samples/Objective-C/hello.m
index 1968d76..1968d76 100644
--- a/samples/objective-c/hello.m
+++ b/samples/Objective-C/hello.m
diff --git a/samples/opa/hello_syntax1.opa b/samples/Opa/hello_syntax1.opa
index 88a9cc8..88a9cc8 100644
--- a/samples/opa/hello_syntax1.opa
+++ b/samples/Opa/hello_syntax1.opa
diff --git a/samples/opa/hello_syntax2.opa b/samples/Opa/hello_syntax2.opa
index 14c0c93..14c0c93 100644
--- a/samples/opa/hello_syntax2.opa
+++ b/samples/Opa/hello_syntax2.opa
diff --git a/samples/opencl/fft.cl b/samples/OpenCL/fft.cl
index e18c6e0..e18c6e0 100644
--- a/samples/opencl/fft.cl
+++ b/samples/OpenCL/fft.cl
diff --git a/samples/openedge-abl/Email.cls b/samples/OpenEdge ABL/Email.cls
index bd30c43..bd30c43 100644
--- a/samples/openedge-abl/Email.cls
+++ b/samples/OpenEdge ABL/Email.cls
diff --git a/samples/openedge-abl/SendEmailAlgorithm.cls b/samples/OpenEdge ABL/SendEmailAlgorithm.cls
index 8b8eecf..8b8eecf 100644
--- a/samples/openedge-abl/SendEmailAlgorithm.cls
+++ b/samples/OpenEdge ABL/SendEmailAlgorithm.cls
diff --git a/samples/openedge-abl/SocketReader.p b/samples/OpenEdge ABL/SocketReader.p
index 0f7add8..0f7add8 100644
--- a/samples/openedge-abl/SocketReader.p
+++ b/samples/OpenEdge ABL/SocketReader.p
diff --git a/samples/openedge-abl/Util.cls b/samples/OpenEdge ABL/Util.cls
index 72d1c13..72d1c13 100644
--- a/samples/openedge-abl/Util.cls
+++ b/samples/OpenEdge ABL/Util.cls
diff --git a/samples/openedge-abl/openedge.p b/samples/OpenEdge ABL/openedge.p
index d6ec595..d6ec595 100644
--- a/samples/openedge-abl/openedge.p
+++ b/samples/OpenEdge ABL/openedge.p
diff --git a/samples/php/Application.php b/samples/PHP/Application.php
index d1c2e39..d1c2e39 100644
--- a/samples/php/Application.php
+++ b/samples/PHP/Application.php
diff --git a/samples/php/Client.php b/samples/PHP/Client.php
index c57b9e3..c57b9e3 100644
--- a/samples/php/Client.php
+++ b/samples/PHP/Client.php
diff --git a/samples/php/Controller.php b/samples/PHP/Controller.php
index 6b8f195..6b8f195 100644
--- a/samples/php/Controller.php
+++ b/samples/PHP/Controller.php
diff --git a/samples/php/Form.php b/samples/PHP/Form.php
index 9e60711..9e60711 100644
--- a/samples/php/Form.php
+++ b/samples/PHP/Form.php
diff --git a/samples/php/Model.php b/samples/PHP/Model.php
index 2eecea4..2eecea4 100644
--- a/samples/php/Model.php
+++ b/samples/PHP/Model.php
diff --git a/samples/php/drupal.module b/samples/PHP/drupal.module
index 37bf9a1..37bf9a1 100644
--- a/samples/php/drupal.module
+++ b/samples/PHP/drupal.module
diff --git a/samples/pasm/hello.pasm b/samples/Parrot Assembly/hello.pasm
index 6f2efaa..6f2efaa 100644
--- a/samples/pasm/hello.pasm
+++ b/samples/Parrot Assembly/hello.pasm
diff --git a/samples/pir/hello.pir b/samples/Parrot Internal Representation/hello.pir
index 6cb35c1..6cb35c1 100644
--- a/samples/pir/hello.pir
+++ b/samples/Parrot Internal Representation/hello.pir
diff --git a/samples/perl/Ack.pm b/samples/Perl/Ack.pm
index 84eea8c..84eea8c 100644
--- a/samples/perl/Ack.pm
+++ b/samples/Perl/Ack.pm
diff --git a/samples/perl/Request.pm b/samples/Perl/Request.pm
index 23d2d3b..23d2d3b 100644
--- a/samples/perl/Request.pm
+++ b/samples/Perl/Request.pm
diff --git a/samples/perl/Response.pm b/samples/Perl/Response.pm
index c1b8a7d..c1b8a7d 100644
--- a/samples/perl/Response.pm
+++ b/samples/Perl/Response.pm
diff --git a/samples/perl/ack b/samples/Perl/ack
index 6a9c66f..6a9c66f 100755
--- a/samples/perl/ack
+++ b/samples/Perl/ack
diff --git a/samples/perl/fib.pl b/samples/Perl/fib.pl
index 287ebf1..287ebf1 100644
--- a/samples/perl/fib.pl
+++ b/samples/Perl/fib.pl
diff --git a/samples/perl/oo1.pl b/samples/Perl/oo1.pl
index 3789d38..3789d38 100644
--- a/samples/perl/oo1.pl
+++ b/samples/Perl/oo1.pl
diff --git a/samples/perl/oo2.pl b/samples/Perl/oo2.pl
index 82f2bdf..82f2bdf 100644
--- a/samples/perl/oo2.pl
+++ b/samples/Perl/oo2.pl
diff --git a/samples/perl/oo3.pl b/samples/Perl/oo3.pl
index e86a190..e86a190 100644
--- a/samples/perl/oo3.pl
+++ b/samples/Perl/oo3.pl
diff --git a/samples/perl/perl-test.t b/samples/Perl/perl-test.t
index a234f9a..a234f9a 100644
--- a/samples/perl/perl-test.t
+++ b/samples/Perl/perl-test.t
diff --git a/samples/perl/script.pl b/samples/Perl/script.pl
index bb20fbc..bb20fbc 100755
--- a/samples/perl/script.pl
+++ b/samples/Perl/script.pl
diff --git a/samples/perl/test-perl.pl b/samples/Perl/test-perl.pl
index 8371027..8371027 100644
--- a/samples/perl/test-perl.pl
+++ b/samples/Perl/test-perl.pl
diff --git a/samples/perl/test-perl2.pl b/samples/Perl/test-perl2.pl
index 55a2762..55a2762 100644
--- a/samples/perl/test-perl2.pl
+++ b/samples/Perl/test-perl2.pl
diff --git a/samples/powershell/hello.ps1 b/samples/PowerShell/hello.ps1
index eca1e76..eca1e76 100644
--- a/samples/powershell/hello.ps1
+++ b/samples/PowerShell/hello.ps1
diff --git a/samples/powershell/hello.psm1 b/samples/PowerShell/hello.psm1
index 3db82f0..3db82f0 100644
--- a/samples/powershell/hello.psm1
+++ b/samples/PowerShell/hello.psm1
diff --git a/samples/prolog/test-prolog.pl b/samples/Prolog/test-prolog.pl
index aab83d5..aab83d5 100644
--- a/samples/prolog/test-prolog.pl
+++ b/samples/Prolog/test-prolog.pl
diff --git a/samples/python/django-models-base.py b/samples/Python/django-models-base.py
index f52a626..f52a626 100644
--- a/samples/python/django-models-base.py
+++ b/samples/Python/django-models-base.py
diff --git a/samples/python/flask-view.py b/samples/Python/flask-view.py
index 5192c1c..5192c1c 100644
--- a/samples/python/flask-view.py
+++ b/samples/Python/flask-view.py
diff --git a/samples/python/script.py b/samples/Python/script.py
index bcebcd4..bcebcd4 100755
--- a/samples/python/script.py
+++ b/samples/Python/script.py
diff --git a/samples/python/tornado-httpserver.py b/samples/Python/tornado-httpserver.py
index 5667ba1..5667ba1 100644
--- a/samples/python/tornado-httpserver.py
+++ b/samples/Python/tornado-httpserver.py
diff --git a/samples/r/hello-r.R b/samples/R/hello-r.R
index 30d715c..30d715c 100644
--- a/samples/r/hello-r.R
+++ b/samples/R/hello-r.R
diff --git a/samples/racket/scribble.scrbl b/samples/Racket/scribble.scrbl
index 9c4d0e2..9c4d0e2 100644
--- a/samples/racket/scribble.scrbl
+++ b/samples/Racket/scribble.scrbl
diff --git a/samples/racket/script.rkt b/samples/Racket/script.rkt
index bc5a8ca..bc5a8ca 100755
--- a/samples/racket/script.rkt
+++ b/samples/Racket/script.rkt
diff --git a/samples/rebol/hello-rebol.r b/samples/Rebol/hello-rebol.r
index 4c1b798..4c1b798 100644
--- a/samples/rebol/hello-rebol.r
+++ b/samples/Rebol/hello-rebol.r
diff --git a/samples/ruby/filenames/Capfile b/samples/Ruby/filenames/Capfile
index 96291a7..96291a7 100644
--- a/samples/ruby/filenames/Capfile
+++ b/samples/Ruby/filenames/Capfile
diff --git a/samples/ruby/filenames/Rakefile b/samples/Ruby/filenames/Rakefile
index 9d51ff7..9d51ff7 100644
--- a/samples/ruby/filenames/Rakefile
+++ b/samples/Ruby/filenames/Rakefile
diff --git a/samples/ruby/foo.rb b/samples/Ruby/foo.rb
index 85026ed..85026ed 100644
--- a/samples/ruby/foo.rb
+++ b/samples/Ruby/foo.rb
diff --git a/samples/ruby/formula.rb b/samples/Ruby/formula.rb
index 541ee65..541ee65 100644
--- a/samples/ruby/formula.rb
+++ b/samples/Ruby/formula.rb
diff --git a/samples/ruby/grit.rb b/samples/Ruby/grit.rb
index fc84753..fc84753 100644
--- a/samples/ruby/grit.rb
+++ b/samples/Ruby/grit.rb
diff --git a/samples/ruby/inflector.rb b/samples/Ruby/inflector.rb
index 2acc6dd..2acc6dd 100644
--- a/samples/ruby/inflector.rb
+++ b/samples/Ruby/inflector.rb
diff --git a/samples/ruby/jekyll.rb b/samples/Ruby/jekyll.rb
index fd455fb..fd455fb 100644
--- a/samples/ruby/jekyll.rb
+++ b/samples/Ruby/jekyll.rb
diff --git a/samples/ruby/macruby-script b/samples/Ruby/macruby-script
index 491be11..491be11 100755
--- a/samples/ruby/macruby-script
+++ b/samples/Ruby/macruby-script
diff --git a/samples/ruby/resque.rb b/samples/Ruby/resque.rb
index 1e36524..1e36524 100644
--- a/samples/ruby/resque.rb
+++ b/samples/Ruby/resque.rb
diff --git a/samples/ruby/script.rake b/samples/Ruby/script.rake
index 96992aa..96992aa 100755
--- a/samples/ruby/script.rake
+++ b/samples/Ruby/script.rake
diff --git a/samples/ruby/script.rb b/samples/Ruby/script.rb
index 01a30f8..01a30f8 100755
--- a/samples/ruby/script.rb
+++ b/samples/Ruby/script.rb
diff --git a/samples/ruby/script2.rb b/samples/Ruby/script2.rb
index 40aeb7c..40aeb7c 100644
--- a/samples/ruby/script2.rb
+++ b/samples/Ruby/script2.rb
diff --git a/samples/ruby/sinatra.rb b/samples/Ruby/sinatra.rb
index 36ec2a2..36ec2a2 100644
--- a/samples/ruby/sinatra.rb
+++ b/samples/Ruby/sinatra.rb
diff --git a/samples/ruby/wrong_shebang.rb b/samples/Ruby/wrong_shebang.rb
index 22b4804..22b4804 100644
--- a/samples/ruby/wrong_shebang.rb
+++ b/samples/Ruby/wrong_shebang.rb
diff --git a/samples/rust/hello.rs b/samples/Rust/hello.rs
index 5579f68..5579f68 100644
--- a/samples/rust/hello.rs
+++ b/samples/Rust/hello.rs
diff --git a/samples/scss/screen.scss b/samples/SCSS/screen.scss
index 7deebf3..7deebf3 100644
--- a/samples/scss/screen.scss
+++ b/samples/SCSS/screen.scss
diff --git a/samples/sass/screen.sass b/samples/Sass/screen.sass
index 7182195..7182195 100644
--- a/samples/sass/screen.sass
+++ b/samples/Sass/screen.sass
diff --git a/samples/scala/build.sbt b/samples/Scala/build.sbt
index 16e7902..16e7902 100644
--- a/samples/scala/build.sbt
+++ b/samples/Scala/build.sbt
diff --git a/samples/scala/script.scala b/samples/Scala/script.scala
index b026d24..b026d24 100755
--- a/samples/scala/script.scala
+++ b/samples/Scala/script.scala
diff --git a/samples/scheme/asteroids.sps b/samples/Scheme/asteroids.sps
index a4ae995..a4ae995 100644
--- a/samples/scheme/asteroids.sps
+++ b/samples/Scheme/asteroids.sps
diff --git a/samples/scilab/scilab_function.sci b/samples/Scilab/scilab_function.sci
index 7c95174..7c95174 100644
--- a/samples/scilab/scilab_function.sci
+++ b/samples/Scilab/scilab_function.sci
diff --git a/samples/scilab/scilab_script.sce b/samples/Scilab/scilab_script.sce
index efa2922..efa2922 100644
--- a/samples/scilab/scilab_script.sce
+++ b/samples/Scilab/scilab_script.sce
diff --git a/samples/scilab/scilab_test.tst b/samples/Scilab/scilab_test.tst
index c48521f..c48521f 100644
--- a/samples/scilab/scilab_test.tst
+++ b/samples/Scilab/scilab_test.tst
diff --git a/samples/shell/.bash_profile b/samples/Shell/.bash_profile
index b7edb8a..b7edb8a 100644
--- a/samples/shell/.bash_profile
+++ b/samples/Shell/.bash_profile
diff --git a/samples/shell/.bashrc b/samples/Shell/.bashrc
index b7edb8a..b7edb8a 100644
--- a/samples/shell/.bashrc
+++ b/samples/Shell/.bashrc
diff --git a/samples/shell/.profile b/samples/Shell/.profile
index b7edb8a..b7edb8a 100644
--- a/samples/shell/.profile
+++ b/samples/Shell/.profile
diff --git a/samples/shell/.zlogin b/samples/Shell/.zlogin
index b7edb8a..b7edb8a 100644
--- a/samples/shell/.zlogin
+++ b/samples/Shell/.zlogin
diff --git a/samples/shell/.zshrc b/samples/Shell/.zshrc
index b7edb8a..b7edb8a 100644
--- a/samples/shell/.zshrc
+++ b/samples/Shell/.zshrc
diff --git a/samples/shell/filenames/PKGBUILD b/samples/Shell/filenames/PKGBUILD
index 854d2f1..854d2f1 100644
--- a/samples/shell/filenames/PKGBUILD
+++ b/samples/Shell/filenames/PKGBUILD
diff --git a/samples/shell/rbenv-sh-shell b/samples/Shell/rbenv-sh-shell
index a216cb2..a216cb2 100755
--- a/samples/shell/rbenv-sh-shell
+++ b/samples/Shell/rbenv-sh-shell
diff --git a/samples/shell/rvm b/samples/Shell/rvm
index 4a9e9c3..4a9e9c3 100755
--- a/samples/shell/rvm
+++ b/samples/Shell/rvm
diff --git a/samples/shell/script.bash b/samples/Shell/script.bash
index 0c2172c..0c2172c 100755
--- a/samples/shell/script.bash
+++ b/samples/Shell/script.bash
diff --git a/samples/shell/script.sh b/samples/Shell/script.sh
index e5ed467..e5ed467 100755
--- a/samples/shell/script.sh
+++ b/samples/Shell/script.sh
diff --git a/samples/shell/script.zsh b/samples/Shell/script.zsh
index ed274ab..ed274ab 100755
--- a/samples/shell/script.zsh
+++ b/samples/Shell/script.zsh
diff --git a/samples/standard-ml/Foo.sig b/samples/Standard ML/Foo.sig
index f881a5c..f881a5c 100644
--- a/samples/standard-ml/Foo.sig
+++ b/samples/Standard ML/Foo.sig
diff --git a/samples/standard-ml/Foo.sml b/samples/Standard ML/Foo.sml
index 2bbb789..2bbb789 100644
--- a/samples/standard-ml/Foo.sml
+++ b/samples/Standard ML/Foo.sml
diff --git a/samples/supercollider/BCR2000.sc b/samples/SuperCollider/BCR2000.sc
index f8f96a7..f8f96a7 100644
--- a/samples/supercollider/BCR2000.sc
+++ b/samples/SuperCollider/BCR2000.sc
diff --git a/samples/tex/reedthesis.cls b/samples/TeX/reedthesis.cls
index adddc14..adddc14 100644
--- a/samples/tex/reedthesis.cls
+++ b/samples/TeX/reedthesis.cls
diff --git a/samples/tea/foo.tea b/samples/Tea/foo.tea
index 60285e9..60285e9 100644
--- a/samples/tea/foo.tea
+++ b/samples/Tea/foo.tea
diff --git a/samples/text/README b/samples/Text/README
index 082a4aa..082a4aa 100644
--- a/samples/text/README
+++ b/samples/Text/README
diff --git a/samples/text/blank b/samples/Text/blank
index e69de29..e69de29 100644
--- a/samples/text/blank
+++ b/samples/Text/blank
diff --git a/samples/text/defu.nkt b/samples/Text/defu.nkt
index 0e8f207..0e8f207 100644
--- a/samples/text/defu.nkt
+++ b/samples/Text/defu.nkt
diff --git a/samples/text/dump.sql b/samples/Text/dump.sql
index 2e959c0..2e959c0 100644
--- a/samples/text/dump.sql
+++ b/samples/Text/dump.sql
diff --git a/samples/text/file.json b/samples/Text/file.json
index 6d95903..6d95903 100644
--- a/samples/text/file.json
+++ b/samples/Text/file.json
diff --git a/samples/text/file.txt b/samples/Text/file.txt
index e69de29..e69de29 100644
--- a/samples/text/file.txt
+++ b/samples/Text/file.txt
diff --git a/samples/text/foo.txt b/samples/Text/foo.txt
index 257cc56..257cc56 100644
--- a/samples/text/foo.txt
+++ b/samples/Text/foo.txt
diff --git a/samples/text/md b/samples/Text/md
index 3562498..3562498 100644
--- a/samples/text/md
+++ b/samples/Text/md
diff --git a/samples/text/script.foo b/samples/Text/script.foo
index f94d740..f94d740 100755
--- a/samples/text/script.foo
+++ b/samples/Text/script.foo
diff --git a/samples/text/txt b/samples/Text/txt
index 3de705a..3de705a 100644
--- a/samples/text/txt
+++ b/samples/Text/txt
diff --git a/samples/turing/turing.t b/samples/Turing/turing.t
index c68f8ee..c68f8ee 100644
--- a/samples/turing/turing.t
+++ b/samples/Turing/turing.t
diff --git a/samples/vhdl/foo.vhd b/samples/VHDL/foo.vhd
index 32ccc9b..32ccc9b 100644
--- a/samples/vhdl/foo.vhd
+++ b/samples/VHDL/foo.vhd
diff --git a/samples/verilog/button_debounce.v b/samples/Verilog/button_debounce.v
index 7803828..7803828 100755
--- a/samples/verilog/button_debounce.v
+++ b/samples/Verilog/button_debounce.v
diff --git a/samples/verilog/control.v b/samples/Verilog/control.v
index 1dd5ca9..1dd5ca9 100755
--- a/samples/verilog/control.v
+++ b/samples/Verilog/control.v
diff --git a/samples/verilog/hex_display.v b/samples/Verilog/hex_display.v
index 49331a9..49331a9 100755
--- a/samples/verilog/hex_display.v
+++ b/samples/Verilog/hex_display.v
diff --git a/samples/verilog/mux.v b/samples/Verilog/mux.v
index 1e9ce53..1e9ce53 100755
--- a/samples/verilog/mux.v
+++ b/samples/Verilog/mux.v
diff --git a/samples/verilog/pipeline_registers.v b/samples/Verilog/pipeline_registers.v
index 72970d1..72970d1 100755
--- a/samples/verilog/pipeline_registers.v
+++ b/samples/Verilog/pipeline_registers.v
diff --git a/samples/verilog/ps2_mouse.v b/samples/Verilog/ps2_mouse.v
index 17c83a0..17c83a0 100755
--- a/samples/verilog/ps2_mouse.v
+++ b/samples/Verilog/ps2_mouse.v
diff --git a/samples/verilog/sha-256-functions.v b/samples/Verilog/sha-256-functions.v
index ec064dd..ec064dd 100644
--- a/samples/verilog/sha-256-functions.v
+++ b/samples/Verilog/sha-256-functions.v
diff --git a/samples/verilog/sign_extender.v b/samples/Verilog/sign_extender.v
index 21944cc..21944cc 100755
--- a/samples/verilog/sign_extender.v
+++ b/samples/Verilog/sign_extender.v
diff --git a/samples/verilog/sqrt_pipelined.v b/samples/Verilog/sqrt_pipelined.v
index 9ceff57..9ceff57 100755
--- a/samples/verilog/sqrt_pipelined.v
+++ b/samples/Verilog/sqrt_pipelined.v
diff --git a/samples/verilog/t_button_debounce.v b/samples/Verilog/t_button_debounce.v
index 0dfc0c0..0dfc0c0 100755
--- a/samples/verilog/t_button_debounce.v
+++ b/samples/Verilog/t_button_debounce.v
diff --git a/samples/verilog/t_div_pipelined.v b/samples/Verilog/t_div_pipelined.v
index e4aa301..e4aa301 100755
--- a/samples/verilog/t_div_pipelined.v
+++ b/samples/Verilog/t_div_pipelined.v
diff --git a/samples/verilog/t_sqrt_pipelined.v b/samples/Verilog/t_sqrt_pipelined.v
index c665223..c665223 100755
--- a/samples/verilog/t_sqrt_pipelined.v
+++ b/samples/Verilog/t_sqrt_pipelined.v
diff --git a/samples/verilog/vga.v b/samples/Verilog/vga.v
index 81298a9..81298a9 100755
--- a/samples/verilog/vga.v
+++ b/samples/Verilog/vga.v
diff --git a/samples/viml/.gvimrc b/samples/VimL/.gvimrc
index d4efd33..d4efd33 100644
--- a/samples/viml/.gvimrc
+++ b/samples/VimL/.gvimrc
diff --git a/samples/viml/.vimrc b/samples/VimL/.vimrc
index 2e9f626..2e9f626 100644
--- a/samples/viml/.vimrc
+++ b/samples/VimL/.vimrc
diff --git a/samples/visual-basic/cApplication.cls b/samples/Visual Basic/cApplication.cls
index 5a58a6b..5a58a6b 100644
--- a/samples/visual-basic/cApplication.cls
+++ b/samples/Visual Basic/cApplication.cls
diff --git a/samples/xml/module.ant b/samples/XML/module.ant
index 8f3a10d..8f3a10d 100644
--- a/samples/xml/module.ant
+++ b/samples/XML/module.ant
diff --git a/samples/xml/module.ivy b/samples/XML/module.ivy
index 0185531..0185531 100644
--- a/samples/xml/module.ivy
+++ b/samples/XML/module.ivy
diff --git a/samples/xml/net_docfile.xml b/samples/XML/net_docfile.xml
index 4cda7b9..4cda7b9 100644
--- a/samples/xml/net_docfile.xml
+++ b/samples/XML/net_docfile.xml
diff --git a/samples/xquery/xproc.xqm b/samples/XQuery/xproc.xqm
index 13257b2..13257b2 100644
--- a/samples/xquery/xproc.xqm
+++ b/samples/XQuery/xproc.xqm
diff --git a/samples/xslt/test.xslt b/samples/XSLT/test.xslt
index 234a079..234a079 100644
--- a/samples/xslt/test.xslt
+++ b/samples/XSLT/test.xslt
diff --git a/samples/yaml/.gemrc b/samples/YAML/.gemrc
index 821e54a..821e54a 100644
--- a/samples/yaml/.gemrc
+++ b/samples/YAML/.gemrc
diff --git a/test/test_blob.rb b/test/test_blob.rb
index 2bf580e..2bdc1cb 100644
--- a/test/test_blob.rb
+++ b/test/test_blob.rb
@@ -34,63 +34,63 @@ class TestBlob < Test::Unit::TestCase
end
def test_mime_type
- assert_equal "application/octet-stream", blob("binary/dog.o").mime_type
- assert_equal "application/ogg", blob("binary/foo.ogg").mime_type
- assert_equal "application/postscript", blob("binary/octocat.ai").mime_type
- assert_equal "application/x-ruby", blob("ruby/grit.rb").mime_type
- assert_equal "application/x-sh", blob("shell/script.sh").mime_type
- assert_equal "application/xml", blob("xml/bar.xml").mime_type
- assert_equal "text/plain", blob("text/README").mime_type
+ assert_equal "application/octet-stream", blob("Binary/dog.o").mime_type
+ assert_equal "application/ogg", blob("Binary/foo.ogg").mime_type
+ assert_equal "application/postscript", blob("Binary/octocat.ai").mime_type
+ assert_equal "application/x-ruby", blob("Ruby/grit.rb").mime_type
+ assert_equal "application/x-sh", blob("Shell/script.sh").mime_type
+ assert_equal "application/xml", blob("XML/bar.xml").mime_type
+ assert_equal "text/plain", blob("Text/README").mime_type
end
def test_content_type
- assert_equal "application/octet-stream", blob("binary/dog.o").content_type
- assert_equal "application/ogg", blob("binary/foo.ogg").content_type
- assert_equal "application/pdf", blob("binary/foo.pdf").content_type
- assert_equal "image/png", blob("binary/foo.png").content_type
- assert_equal "text/plain; charset=iso-8859-2", blob("text/README").content_type
- assert_equal "text/plain; charset=iso-8859-1", blob("perl/script.pl").content_type
- assert_equal "text/plain; charset=iso-8859-1", blob("python/script.py").content_type
- assert_equal "text/plain; charset=iso-8859-1", blob("ruby/script.rb").content_type
- assert_equal "text/plain; charset=iso-8859-1", blob("shell/script.sh").content_type
+ assert_equal "application/octet-stream", blob("Binary/dog.o").content_type
+ assert_equal "application/ogg", blob("Binary/foo.ogg").content_type
+ assert_equal "application/pdf", blob("Binary/foo.pdf").content_type
+ assert_equal "image/png", blob("Binary/foo.png").content_type
+ assert_equal "text/plain; charset=iso-8859-2", blob("Text/README").content_type
+ assert_equal "text/plain; charset=iso-8859-1", blob("Perl/script.pl").content_type
+ assert_equal "text/plain; charset=iso-8859-1", blob("Python/script.py").content_type
+ assert_equal "text/plain; charset=iso-8859-1", blob("Ruby/script.rb").content_type
+ assert_equal "text/plain; charset=iso-8859-1", blob("Shell/script.sh").content_type
end
def test_disposition
- assert_equal "attachment; filename=foo+bar.jar", blob("binary/foo bar.jar").disposition
- assert_equal "attachment; filename=foo.bin", blob("binary/foo.bin").disposition
- assert_equal "attachment; filename=linguist.gem", blob("binary/linguist.gem").disposition
- assert_equal "attachment; filename=octocat.ai", blob("binary/octocat.ai").disposition
- assert_equal "inline", blob("text/README").disposition
- assert_equal "inline", blob("text/foo.txt").disposition
- assert_equal "inline", blob("ruby/grit.rb").disposition
- assert_equal "inline", blob("binary/octocat.png").disposition
+ assert_equal "attachment; filename=foo+bar.jar", blob("Binary/foo bar.jar").disposition
+ assert_equal "attachment; filename=foo.bin", blob("Binary/foo.bin").disposition
+ assert_equal "attachment; filename=linguist.gem", blob("Binary/linguist.gem").disposition
+ assert_equal "attachment; filename=octocat.ai", blob("Binary/octocat.ai").disposition
+ assert_equal "inline", blob("Text/README").disposition
+ assert_equal "inline", blob("Text/foo.txt").disposition
+ assert_equal "inline", blob("Ruby/grit.rb").disposition
+ assert_equal "inline", blob("Binary/octocat.png").disposition
end
def test_data
- assert_equal "module Foo\nend\n", blob("ruby/foo.rb").data
+ assert_equal "module Foo\nend\n", blob("Ruby/foo.rb").data
end
def test_lines
- assert_equal ["module Foo", "end", ""], blob("ruby/foo.rb").lines
+ assert_equal ["module Foo", "end", ""], blob("Ruby/foo.rb").lines
end
def test_size
- assert_equal 15, blob("ruby/foo.rb").size
+ assert_equal 15, blob("Ruby/foo.rb").size
end
def test_loc
- assert_equal 3, blob("ruby/foo.rb").loc
+ assert_equal 3, blob("Ruby/foo.rb").loc
end
def test_sloc
- assert_equal 2, blob("ruby/foo.rb").sloc
+ assert_equal 2, blob("Ruby/foo.rb").sloc
end
def test_encoding
- assert_equal "ISO-8859-2", blob("text/README").encoding
- assert_equal "ISO-8859-1", blob("text/dump.sql").encoding
- assert_equal "UTF-8", blob("text/foo.txt").encoding
- assert_nil blob("binary/dog.o").encoding
+ assert_equal "ISO-8859-2", blob("Text/README").encoding
+ assert_equal "ISO-8859-1", blob("Text/dump.sql").encoding
+ assert_equal "UTF-8", blob("Text/foo.txt").encoding
+ assert_nil blob("Binary/dog.o").encoding
end
def test_binary
@@ -101,91 +101,91 @@ class TestBlob < Test::Unit::TestCase
end
assert large_blob.binary?
- assert blob("binary/git.deb").binary?
- assert blob("binary/git.exe").binary?
- assert blob("binary/hello.pbc").binary?
- assert blob("binary/linguist.gem").binary?
- assert blob("binary/octocat.ai").binary?
- assert blob("binary/octocat.png").binary?
- assert blob("binary/zip").binary?
- assert !blob("text/README").binary?
- assert !blob("text/file.txt").binary?
- assert !blob("ruby/foo.rb").binary?
- assert !blob("perl/script.pl").binary?
+ assert blob("Binary/git.deb").binary?
+ assert blob("Binary/git.exe").binary?
+ assert blob("Binary/hello.pbc").binary?
+ assert blob("Binary/linguist.gem").binary?
+ assert blob("Binary/octocat.ai").binary?
+ assert blob("Binary/octocat.png").binary?
+ assert blob("Binary/zip").binary?
+ assert !blob("Text/README").binary?
+ assert !blob("Text/file.txt").binary?
+ assert !blob("Ruby/foo.rb").binary?
+ assert !blob("Perl/script.pl").binary?
end
def test_text
- assert blob("text/README").text?
- assert blob("text/dump.sql").text?
- assert blob("text/file.json").text?
- assert blob("text/file.txt").text?
- assert blob("text/md").text?
- assert blob("shell/script.sh").text?
- assert blob("text/txt").text?
+ assert blob("Text/README").text?
+ assert blob("Text/dump.sql").text?
+ assert blob("Text/file.json").text?
+ assert blob("Text/file.txt").text?
+ assert blob("Text/md").text?
+ assert blob("Shell/script.sh").text?
+ assert blob("Text/txt").text?
end
def test_image
- assert blob("binary/octocat.gif").image?
- assert blob("binary/octocat.jpeg").image?
- assert blob("binary/octocat.jpg").image?
- assert blob("binary/octocat.png").image?
- assert !blob("binary/octocat.ai").image?
- assert !blob("binary/octocat.psd").image?
+ assert blob("Binary/octocat.gif").image?
+ assert blob("Binary/octocat.jpeg").image?
+ assert blob("Binary/octocat.jpg").image?
+ assert blob("Binary/octocat.png").image?
+ assert !blob("Binary/octocat.ai").image?
+ assert !blob("Binary/octocat.psd").image?
end
def test_viewable
- assert blob("text/README").viewable?
- assert blob("ruby/foo.rb").viewable?
- assert blob("perl/script.pl").viewable?
- assert !blob("binary/linguist.gem").viewable?
- assert !blob("binary/octocat.ai").viewable?
- assert !blob("binary/octocat.png").viewable?
+ assert blob("Text/README").viewable?
+ assert blob("Ruby/foo.rb").viewable?
+ assert blob("Perl/script.pl").viewable?
+ assert !blob("Binary/linguist.gem").viewable?
+ assert !blob("Binary/octocat.ai").viewable?
+ assert !blob("Binary/octocat.png").viewable?
end
def test_generated
- assert !blob("text/README").generated?
+ assert !blob("Text/README").generated?
# Xcode project files
- assert blob("xml/MainMenu.xib").generated?
- assert blob("binary/MainMenu.nib").generated?
- assert blob("xml/project.pbxproj").generated?
+ assert blob("XML/MainMenu.xib").generated?
+ assert blob("Binary/MainMenu.nib").generated?
+ assert blob("XML/project.pbxproj").generated?
# Gemfile.locks
assert blob("Gemfile.lock").generated?
# Generated .NET Docfiles
- assert blob("xml/net_docfile.xml").generated?
+ assert blob("XML/net_docfile.xml").generated?
# Long line
- assert !blob("javascript/uglify.js").generated?
+ assert !blob("JavaScript/uglify.js").generated?
# Inlined JS, but mostly code
- assert !blob("javascript/json2_backbone.js").generated?
+ assert !blob("JavaScript/json2_backbone.js").generated?
# Minified JS
- assert !blob("javascript/jquery-1.6.1.js").generated?
- assert blob("javascript/jquery-1.6.1.min.js").generated?
- assert blob("javascript/jquery-1.4.2.min.js").generated?
+ assert !blob("JavaScript/jquery-1.6.1.js").generated?
+ assert blob("JavaScript/jquery-1.6.1.min.js").generated?
+ assert blob("JavaScript/jquery-1.4.2.min.js").generated?
# CoffeeScript-generated JS
# TODO
# PEG.js-generated parsers
- assert blob("javascript/parser.js").generated?
+ assert blob("JavaScript/parser.js").generated?
# These examples are too basic to tell
- assert !blob("javascript/empty.js").generated?
- assert !blob("javascript/hello.js").generated?
+ assert !blob("JavaScript/empty.js").generated?
+ assert !blob("JavaScript/hello.js").generated?
- assert blob("javascript/intro-old.js").generated?
- assert blob("javascript/classes-old.js").generated?
+ assert blob("JavaScript/intro-old.js").generated?
+ assert blob("JavaScript/classes-old.js").generated?
- assert blob("javascript/intro.js").generated?
- assert blob("javascript/classes.js").generated?
+ assert blob("JavaScript/intro.js").generated?
+ assert blob("JavaScript/classes.js").generated?
end
def test_vendored
- assert !blob("text/README").vendored?
+ assert !blob("Text/README").vendored?
assert !blob("ext/extconf.rb").vendored?
# Node depedencies
@@ -266,47 +266,46 @@ class TestBlob < Test::Unit::TestCase
end
def test_indexable
- assert blob("text/file.txt").indexable?
- assert blob("ruby/foo.rb").indexable?
- assert !blob("text/defu.nkt").indexable?
- assert !blob("text/dump.sql").indexable?
- assert !blob("binary/github.po").indexable?
- assert !blob("binary/linguist.gem").indexable?
+ assert blob("Text/file.txt").indexable?
+ assert blob("Ruby/foo.rb").indexable?
+ assert !blob("Text/defu.nkt").indexable?
+ assert !blob("Text/dump.sql").indexable?
+ assert !blob("Binary/github.po").indexable?
+ assert !blob("Binary/linguist.gem").indexable?
end
def test_language
Samples.each do |sample|
- blob = blob(sample[:path])
- language = Linguist::Language.find_by_alias(sample[:language])
- assert_equal language, blob.language, blob.name
+ blob = blob(sample[:path])
+ assert_equal sample[:language], blob.language.name, blob.name
end
end
def test_lexer
- assert_equal Lexer['Ruby'], blob("ruby/foo.rb").lexer
+ assert_equal Lexer['Ruby'], blob("Ruby/foo.rb").lexer
end
def test_shebang_script
- assert_equal 'sh', script_blob("shell/script.sh").shebang_script
- assert_equal 'bash', script_blob("shell/script.bash").shebang_script
- assert_equal 'zsh', script_blob("shell/script.zsh").shebang_script
- assert_equal 'perl', script_blob("perl/script.pl").shebang_script
- assert_equal 'ruby', script_blob("ruby/script.rb").shebang_script
- assert_equal 'ruby', script_blob("ruby/script2.rb").shebang_script
- assert_equal 'python', script_blob("python/script.py").shebang_script
- assert_equal 'node', script_blob("javascript/script.js").shebang_script
- assert_equal 'groovy', script_blob("groovy/script.groovy").shebang_script
- assert_equal 'macruby', script_blob("ruby/macruby-script").shebang_script
- assert_equal 'rake', script_blob("ruby/script.rake").shebang_script
- assert_equal 'foo', script_blob("text/script.foo").shebang_script
- assert_equal 'nush', script_blob("nu/script.nu").shebang_script
- assert_equal 'scala', script_blob("scala/script.scala").shebang_script
- assert_equal 'racket', script_blob("racket/script.rkt").shebang_script
- assert_equal nil, script_blob("ruby/foo.rb").shebang_script
+ assert_equal 'sh', script_blob("Shell/script.sh").shebang_script
+ assert_equal 'bash', script_blob("Shell/script.bash").shebang_script
+ assert_equal 'zsh', script_blob("Shell/script.zsh").shebang_script
+ assert_equal 'perl', script_blob("Perl/script.pl").shebang_script
+ assert_equal 'ruby', script_blob("Ruby/script.rb").shebang_script
+ assert_equal 'ruby', script_blob("Ruby/script2.rb").shebang_script
+ assert_equal 'python', script_blob("Python/script.py").shebang_script
+ assert_equal 'node', script_blob("JavaScript/script.js").shebang_script
+ assert_equal 'groovy', script_blob("Groovy/script.groovy").shebang_script
+ assert_equal 'macruby', script_blob("Ruby/macruby-script").shebang_script
+ assert_equal 'rake', script_blob("Ruby/script.rake").shebang_script
+ assert_equal 'foo', script_blob("Text/script.foo").shebang_script
+ assert_equal 'nush', script_blob("Nu/script.nu").shebang_script
+ assert_equal 'scala', script_blob("Scala/script.scala").shebang_script
+ assert_equal 'racket', script_blob("Racket/script.rkt").shebang_script
+ assert_equal nil, script_blob("Ruby/foo.rb").shebang_script
end
def test_colorize
- assert_equal <<-HTML, blob("ruby/foo.rb").colorize
+ assert_equal <<-HTML, blob("Ruby/foo.rb").colorize
<div class="highlight"><pre><span class="k">module</span> <span class="nn">Foo</span>
<span class="k">end</span>
</pre>
@@ -315,18 +314,18 @@ class TestBlob < Test::Unit::TestCase
end
def test_colorize_without_wrapper
- assert_equal <<-HTML, blob("ruby/foo.rb").colorize_without_wrapper
+ assert_equal <<-HTML, blob("Ruby/foo.rb").colorize_without_wrapper
<span class="k">module</span> <span class="nn">Foo</span>
<span class="k">end</span>
HTML
end
def test_colorize_does_skip_minified_files
- assert_nil blob("javascript/jquery-1.6.1.min.js").colorize
+ assert_nil blob("JavaScript/jquery-1.6.1.min.js").colorize
end
# Pygments.rb was taking exceeding long on this particular file
def test_colorize_doesnt_blow_up_with_files_with_high_ratio_of_long_lines
- assert_nil blob("javascript/steelseries-min.js").colorize
+ assert_nil blob("JavaScript/steelseries-min.js").colorize
end
end
diff --git a/test/test_classifier.rb b/test/test_classifier.rb
index e36bdbf..a24c5ba 100644
--- a/test/test_classifier.rb
+++ b/test/test_classifier.rb
@@ -18,28 +18,28 @@ class TestClassifier < Test::Unit::TestCase
def test_classify
db = {}
- Classifier.train! db, "Ruby", fixture("ruby/foo.rb")
- Classifier.train! db, "Objective-C", fixture("objective-c/Foo.h")
- Classifier.train! db, "Objective-C", fixture("objective-c/Foo.m")
+ Classifier.train! db, "Ruby", fixture("Ruby/foo.rb")
+ Classifier.train! db, "Objective-C", fixture("Objective-C/Foo.h")
+ Classifier.train! db, "Objective-C", fixture("Objective-C/Foo.m")
- results = Classifier.classify(db, fixture("objective-c/hello.m"))
+ results = Classifier.classify(db, fixture("Objective-C/hello.m"))
assert_equal "Objective-C", results.first[0]
- tokens = Tokenizer.tokenize(fixture("objective-c/hello.m"))
+ tokens = Tokenizer.tokenize(fixture("Objective-C/hello.m"))
results = Classifier.classify(db, tokens)
assert_equal "Objective-C", results.first[0]
end
def test_restricted_classify
db = {}
- Classifier.train! db, "Ruby", fixture("ruby/foo.rb")
- Classifier.train! db, "Objective-C", fixture("objective-c/Foo.h")
- Classifier.train! db, "Objective-C", fixture("objective-c/Foo.m")
+ Classifier.train! db, "Ruby", fixture("Ruby/foo.rb")
+ Classifier.train! db, "Objective-C", fixture("Objective-C/Foo.h")
+ Classifier.train! db, "Objective-C", fixture("Objective-C/Foo.m")
- results = Classifier.classify(db, fixture("objective-c/hello.m"), ["Objective-C"])
+ results = Classifier.classify(db, fixture("Objective-C/hello.m"), ["Objective-C"])
assert_equal "Objective-C", results.first[0]
- results = Classifier.classify(db, fixture("objective-c/hello.m"), ["Ruby"])
+ results = Classifier.classify(db, fixture("Objective-C/hello.m"), ["Ruby"])
assert_equal "Ruby", results.first[0]
end
@@ -54,7 +54,7 @@ class TestClassifier < Test::Unit::TestCase
def test_classify_ambiguous_languages
Samples.each do |sample|
- language = Linguist::Language.find_by_alias(sample[:language])
+ language = Linguist::Language.find_by_name(sample[:language])
next unless language.overrides.any?
extname = File.extname(sample[:path])
diff --git a/test/test_tokenizer.rb b/test/test_tokenizer.rb
index 420c776..644a2c3 100644
--- a/test/test_tokenizer.rb
+++ b/test/test_tokenizer.rb
@@ -65,28 +65,28 @@ class TestTokenizer < Test::Unit::TestCase
end
def test_c_tokens
- assert_equal %w(#ifndef HELLO_H #define HELLO_H void hello \( \) ; #endif), tokenize(:"c/hello.h")
- assert_equal %w(#include <stdio.h> int main \( \) { printf \( \) ; return ; }), tokenize(:"c/hello.c")
+ assert_equal %w(#ifndef HELLO_H #define HELLO_H void hello \( \) ; #endif), tokenize(:"C/hello.h")
+ assert_equal %w(#include <stdio.h> int main \( \) { printf \( \) ; return ; }), tokenize(:"C/hello.c")
end
def test_cpp_tokens
- assert_equal %w(class Bar { protected char *name ; public void hello \( \) ; }), tokenize(:"cpp/bar.h")
- assert_equal %w(#include <iostream> using namespace std ; int main \( \) { cout << << endl ; }), tokenize(:"cpp/hello.cpp")
+ assert_equal %w(class Bar { protected char *name ; public void hello \( \) ; }), tokenize(:"C++/bar.h")
+ assert_equal %w(#include <iostream> using namespace std ; int main \( \) { cout << << endl ; }), tokenize(:"C++/hello.cpp")
end
def test_objective_c_tokens
- assert_equal %w(#import <Foundation/Foundation.h> @interface Foo NSObject { } @end), tokenize(:"objective-c/Foo.h")
- assert_equal %w(#import @implementation Foo @end), tokenize(:"objective-c/Foo.m")
- assert_equal %w(#import <Cocoa/Cocoa.h> int main \( int argc char *argv \) { NSLog \( @ \) ; return ; }), tokenize(:"objective-c/hello.m")
+ assert_equal %w(#import <Foundation/Foundation.h> @interface Foo NSObject { } @end), tokenize(:"Objective-C/Foo.h")
+ assert_equal %w(#import @implementation Foo @end), tokenize(:"Objective-C/Foo.m")
+ assert_equal %w(#import <Cocoa/Cocoa.h> int main \( int argc char *argv \) { NSLog \( @ \) ; return ; }), tokenize(:"Objective-C/hello.m")
end
def test_javascript_tokens
- assert_equal %w( \( function \( \) { console.log \( \) ; } \) .call \( this \) ;), tokenize(:"javascript/hello.js")
+ assert_equal %w( \( function \( \) { console.log \( \) ; } \) .call \( this \) ;), tokenize(:"JavaScript/hello.js")
end
def test_ruby_tokens
- assert_equal %w(module Foo end), tokenize(:"ruby/foo.rb")
- assert_equal %w(# /usr/bin/env ruby puts), tokenize(:"ruby/script.rb")
- assert_equal %w(task default do puts end), tokenize(:"ruby/filenames/Rakefile")
+ assert_equal %w(module Foo end), tokenize(:"Ruby/foo.rb")
+ assert_equal %w(# /usr/bin/env ruby puts), tokenize(:"Ruby/script.rb")
+ assert_equal %w(task default do puts end), tokenize(:"Ruby/filenames/Rakefile")
end
end